@@ -1,22 +1,17 @@
-#  Copyright (c) 2005-19, Enthought, Inc.
-#  All rights reserved.
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/07/2004
+# Thanks for using Enthought open source!
 
 """ Defines the abstract Editor class, which represents an editing control for
     an object trait in a Traits-based user interface.
 """
 
-
-
 from contextlib import contextmanager
 from functools import partial
 
@@ -38,7 +33,6 @@ from traits.api import (
     Undefined,
     cached_property,
 )
-
 from traits.trait_base import not_none, xgetattr, xsetattr
 
 from .editor_factory import EditorFactory
@@ -49,15 +43,13 @@ from .undo import UndoItem
 
 from .item import Item
 
-
-
 # Reference to an EditorFactory object
 factory_trait = Instance(EditorFactory)
 
 
 class Editor(HasPrivateTraits):
-    """ Represents an editing control for an object trait in a Traits-based
-        user interface.
+    """Represents an editing control for an object trait in a Traits-based
+    user interface.
     """
 
     #: The UI (user interface) this editor is part of:
@@ -141,7 +133,7 @@ class Editor(HasPrivateTraits):
     # -- Abstract methods ---------------------------------------------------
 
     def init(self, parent):
-        """ Create and initialize the underlying toolkit widget.
+        """Create and initialize the underlying toolkit widget.
 
         This method must be overriden by subclasses.  Implementations must
         ensure that the :attr:`control` trait is set to an appropriate
@@ -155,33 +147,52 @@ class Editor(HasPrivateTraits):
         raise NotImplementedError("This method must be overriden.")
 
     def update_editor(self):
-        """ Updates the editor when the value changes externally to the editor.
+        """Updates the editor when the value changes externally to the editor.
 
         This should normally be overridden in a subclass.
         """
         pass
 
     def error(self, excp):
-        """ Handles an error that occurs while setting the object's trait value.
-
-        This should normally be overridden in a subclass.
+        """Handles an error that occurs while setting the object's trait value.
 
         Parameters
         ----------
         excp : Exception
             The exception which occurred.
         """
-        pass
+        from pyface.api import information
+
+        information(
+            parent=self.get_control_widget(),
+            title=self.description + " value error",
+            message=str(excp),
+            text_format='plain',
+        )
 
     def set_focus(self):
-        """ Assigns focus to the editor's underlying toolkit widget.
+        """Assigns focus to the editor's underlying toolkit widget.
 
         This method must be overriden by subclasses.
         """
         raise NotImplementedError("This method must be overriden.")
 
+    def set_tooltip_text(self, control, text):
+        """Sets the tooltip for a toolkit control to the provided text.
+
+        This method must be overriden by subclasses.
+
+        Parameters
+        ----------
+        text : str
+            The text to use for the tooltip.
+        control : toolkit control
+            The toolkit control that is having the tooltip set.
+        """
+        raise NotImplementedError("This method must be overriden.")
+
     def string_value(self, value, format_func=None):
-        """ Returns the text representation of a specified object trait value.
+        """Returns the text representation of a specified object trait value.
 
         This simply delegates to the factory's `string_value` method.
         Sub-classes may choose to override the default implementation.
@@ -196,7 +207,7 @@ class Editor(HasPrivateTraits):
         return self.factory.string_value(value, format_func)
 
     def restore_prefs(self, prefs):
-        """ Restores saved user preference information for the editor.
+        """Restores saved user preference information for the editor.
 
         Editors with state may choose to override this. It will only be used
         if the editor has an `id` value.
@@ -209,7 +220,7 @@ class Editor(HasPrivateTraits):
         pass
 
     def save_prefs(self):
-        """ Returns any user preference information for the editor.
+        """Returns any user preference information for the editor.
 
         Editors with state may choose to override this. It will only be used
         if the editor has an `id` value.
@@ -225,7 +236,7 @@ class Editor(HasPrivateTraits):
     # -- Editor life-cycle methods ------------------------------------------
 
     def prepare(self, parent):
-        """ Finish setting up the editor.
+        """Finish setting up the editor.
 
         Parameters
         ----------
@@ -242,7 +253,7 @@ class Editor(HasPrivateTraits):
         self.update_editor()
 
     def dispose(self):
-        """ Disposes of the contents of an editor.
+        """Disposes of the contents of an editor.
 
         This disconnects any synchronised values and resets references
         to other objects.
@@ -272,7 +283,7 @@ class Editor(HasPrivateTraits):
     # -- Undo/redo methods --------------------------------------------------
 
     def log_change(self, undo_factory, *undo_args):
-        """ Logs a change made in the editor with undo/redo history.
+        """Logs a change made in the editor with undo/redo history.
 
         Parameters
         ----------
@@ -298,7 +309,7 @@ class Editor(HasPrivateTraits):
                         history.extend(item)
 
     def get_undo_item(self, object, name, old_value, new_value):
-        """ Creates an undo history entry.
+        """Creates an undo history entry.
 
         Can be overridden in a subclass for special value types.
 
@@ -327,7 +338,7 @@ class Editor(HasPrivateTraits):
         is_list=False,
         is_event=False,
     ):
-        """ Synchronize an editor trait and a user object trait.
+        """Synchronize an editor trait and a user object trait.
 
         Also sets the initial value of the editor trait from the
         user object trait (for modes 'from' and 'both'), and the initial
@@ -390,7 +401,7 @@ class Editor(HasPrivateTraits):
     # -- Utility methods -----------------------------------------------------
 
     def parse_extended_name(self, name):
-        """ Extract the object, name and a getter from an extended name
+        """Extract the object, name and a getter from an extended name
 
         Parameters
         ----------
@@ -413,11 +424,78 @@ class Editor(HasPrivateTraits):
 
         return (object, name, partial(xgetattr, object, name))
 
+    def set_tooltip(self, control=None):
+        """Sets the tooltip for a specified toolkit control.
+
+        This uses the tooltip_text method to get the text to use.
+
+        Parameters
+        ----------
+        control : optional toolkit control
+            The toolkit control that is having the tooltip set.  If None
+            then the editor's control is used.
+
+        Returns
+        -------
+        tooltip_set : bool
+            Whether or not a tooltip value could be set.
+        """
+        text = self.tooltip_text()
+        if text is None:
+            return False
+
+        if control is None:
+            control = self.control
+
+        self.set_tooltip_text(control, text)
+
+        return True
+
+    def tooltip_text(self):
+        """Get the text for a tooltip, checking various sources.
+
+        This checks for text from, in order:
+
+        - the editor's description trait
+        - the base trait's 'tooltip' metadata
+        - the base trait's 'desc' metadata
+
+        Returns
+        -------
+        text : str or None
+            The text for the tooltip, or None if no suitable text can
+            be found.
+        """
+
+        if self.description:
+            return self.description
+
+        base_trait = self.object.base_trait(self.name)
+
+        text = base_trait.tooltip
+        if text is not None:
+            return text
+
+        text = base_trait.desc
+        if text is not None:
+            return "Specifies " + text
+
+        return None
+
+    def get_control_widget(self):
+        """Get the concrete widget for the control.
+
+        The default implementation returns the control, however some editors
+        in some backends may store a layout or sizer instead of a proper widget
+        or control, which may not be suitable for certain usages.
+        """
+        return self.control
+
     # -- Utility context managers --------------------------------------------
 
     @contextmanager
     def no_trait_update(self, name):
-        """ Context manager that blocks updates from the named trait. """
+        """Context manager that blocks updates from the named trait."""
         if name in self._no_trait_update:
             yield
             return
@@ -430,7 +508,7 @@ class Editor(HasPrivateTraits):
 
     @contextmanager
     def raise_to_debug(self):
-        """ Context manager that uses raise to debug to raise exceptions. """
+        """Context manager that uses raise to debug to raise exceptions."""
         try:
             yield
         except Exception:
@@ -440,7 +518,7 @@ class Editor(HasPrivateTraits):
 
     @contextmanager
     def updating_value(self):
-        """ Context manager to handle updating value. """
+        """Context manager to handle updating value."""
         if self.updating:
             yield
             return
@@ -456,9 +534,8 @@ class Editor(HasPrivateTraits):
     # ------------------------------------------------------------------------
 
     def __init__(self, parent, **traits):
-        """ Initializes the editor object.
-        """
-        super(HasPrivateTraits, self).__init__(**traits)
+        """Initializes the editor object."""
+        super().__init__(**traits)
         try:
             self.old_value = getattr(self.object, self.name)
         except AttributeError:
@@ -477,7 +554,7 @@ class Editor(HasPrivateTraits):
     # ------------------------------------------------------------------------
 
     def _update_editor(self, object, name, old_value, new_value):
-        """ Performs updates when the object trait changes.
+        """Performs updates when the object trait changes.
 
         This is designed to be used as a trait listener.
         """
@@ -514,7 +591,7 @@ class Editor(HasPrivateTraits):
             self.ui.modified = True
 
             if self.updating:
-                    self.log_change(
+                self.log_change(
                     self.get_undo_item, object, name, old_value, new_value
                 )
 
@@ -524,7 +601,7 @@ class Editor(HasPrivateTraits):
             self.update_editor()
 
     def _sync_values(self):
-        """ Initialize and synchronize editor and factory traits
+        """Initialize and synchronize editor and factory traits
 
         Initializes and synchronizes (as needed) editor traits with the
         value of corresponding factory traits.  The name of the factory
@@ -581,11 +658,11 @@ class Editor(HasPrivateTraits):
                     bool(self_trait.is_list),
                     self_trait.type == "event",
                 )
-            elif value is not Undefined:
+            elif mode != "to" and value is not Undefined:
                 setattr(self, name, value)
 
     def _bind_from(self, key, user_object, xuser_name, editor_name, is_list):
-        """ Bind trait change handlers from a user object to the editor.
+        """Bind trait change handlers from a user object to the editor.
 
         Parameters
         ----------
@@ -629,7 +706,7 @@ class Editor(HasPrivateTraits):
             self._user_to.append((user_object, items, user_list_modified))
 
     def _bind_to(self, key, user_object, xuser_name, editor_name, is_list):
-        """ Bind trait change handlers from a user object to the editor.
+        """Bind trait change handlers from a user object to the editor.
 
         Parameters
         ----------
@@ -671,7 +748,7 @@ class Editor(HasPrivateTraits):
             )
 
     def __set_value(self, value):
-        """ Set the value of the trait the editor is editing.
+        """Set the value of the trait the editor is editing.
 
         This calls the appropriate setattr method on the handler to perform
         the actual change.
@@ -691,31 +768,11 @@ class Editor(HasPrivateTraits):
                 self.error(excp)
                 raise
 
-    def _str(self, value):
-        """ Returns the text representation of a specified value.
-
-        This is a convenience method to cover the differences between Python
-        2 and Python 3 strings.
-
-        Parameters
-        ----------
-        value : any
-            The value to be represented as a string.
-
-        Returns
-        -------
-        string : unicode
-            The string of the value, as an appropriate text type for Python 2
-            or 3.
-        """
-        # In Unicode!
-        return str(value)
-
     # -- Traits property getters and setters --------------------------------
 
     @cached_property
     def _get_context_object(self):
-        """ Returns the context object the editor is using
+        """Returns the context object the editor is using
 
         In some cases a proxy object is edited rather than an object directly
         in the context, in which case we return ``self.object``.
@@ -731,22 +788,19 @@ class Editor(HasPrivateTraits):
 
     @cached_property
     def _get_extended_name(self):
-        """ Returns the extended trait name being edited.
-        """
+        """Returns the extended trait name being edited."""
         return ("%s.%s" % (self.object_name, self.name)).split(".", 1)[1]
 
     def _get_value_trait(self):
-        """ Returns the trait the editor is editing (Property implementation).
-        """
+        """Returns the trait the editor is editing (Property implementation)."""
         return self.object.trait(self.name)
 
     def _get_value(self):
-        """ Returns the value of the trait the editor is editing.
-        """
+        """Returns the value of the trait the editor is editing."""
         return getattr(self.object, self.name, Undefined)
 
     def _set_value(self, value):
-        """ Set the value of the trait the editor is editing.
+        """Set the value of the trait the editor is editing.
 
         Dispatches via the TraitsUI Undo/Redo mechanisms to make change
         reversible, if desired.
@@ -755,6 +809,5 @@ class Editor(HasPrivateTraits):
             self.ui.do_undoable(self.__set_value, value)
 
     def _get_str_value(self):
-        """ Returns the text representation of the object trait.
-        """
+        """Returns the text representation of the object trait."""
         return self.string_value(getattr(self.object, self.name, Undefined))
