@@ -1,31 +1,24 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2008, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Judah De Paula
-#  Date:   10/7/2008
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ A Traits UI editor that wraps a WX calendar panel.
 """
 
-
 from traits.trait_types import Bool, Instance, Int, Enum, Str
-from ..ui_traits import AView
-from ..editor_factory import EditorFactory
+
+from traitsui.editor_factory import EditorFactory
+from traitsui.ui_traits import AView
 
 
 class CellFormat(object):
-    """ Styling attributes for calendar widget cells.
+    """Styling attributes for calendar widget cells.
 
     Encapsulates some common visual attributes to set on the cells of a
     calendar widget.  All attributes default to None, which means that they
@@ -60,8 +53,7 @@ class CellFormat(object):
 
 
 class DateEditor(EditorFactory):
-    """ Editor factory for date/time editors.
-    """
+    """Editor factory for date/time editors."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
