@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,7 +15,7 @@ traits user interface toolkits.
 import os
 import sys
 
-from traits.api import Any, Range, Enum, Bool
+from traits.api import Any, Range, Enum, Bool, Str
 
 from traitsui.editor_factory import EditorWithListFactory
 from traitsui.toolkit import toolkit_object
@@ -32,8 +32,7 @@ CompletionMode = Enum("inline", "popup")
 
 
 class EnumEditor(EditorWithListFactory):
-    """ Editor factory for enumeration editors.
-    """
+    """Editor factory for enumeration editors."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -54,12 +53,18 @@ class EnumEditor(EditorWithListFactory):
     #: Completion mode for editors with text-entry (Qt only):
     completion_mode = CompletionMode
 
+    #: Whether values trait contains separators (Qt only)
+    use_separator = Bool(False)
+
+    #: The separator string used in values trait (Qt only)
+    separator = Str("")
+
     # -------------------------------------------------------------------------
     #  'Editor' factory methods:
     # -------------------------------------------------------------------------
 
     def _get_custom_editor_class(self):
-        """ Returns the editor class to use for "custom" style views.
+        """Returns the editor class to use for "custom" style views.
         Overridden to return the editor class for the specified mode.
         """
         editor_file_name = os.path.basename(
