@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -52,8 +52,7 @@ editor_trait = Instance(EditorFactory)
 
 
 class ListEditor(EditorFactory):
-    """ Editor factory for list editors.
-    """
+    """Editor factory for list editors."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
