@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -17,8 +17,7 @@ from traitsui.editor_factory import EditorFactory
 
 
 class ProgressEditor(EditorFactory):
-    """ Editor factory for code editors.
-    """
+    """Editor factory for code editors."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
