@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -58,6 +58,5 @@ class ScrubberEditor(BasicEditorFactory):
     text_color = Color("black")
 
     def _get_klass(self):
-        """ Returns the toolkit-specific editor class to be instantiated.
-        """
+        """Returns the toolkit-specific editor class to be instantiated."""
         return toolkit_object("scrubber_editor:_ScrubberEditor")
