@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -17,8 +17,7 @@ from traitsui.editor_factory import EditorWithListFactory
 
 
 class SetEditor(EditorWithListFactory):
-    """ Editor factory for editors for sets.
-    """
+    """Editor factory for editors for sets."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
