@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -11,7 +11,8 @@
 """ Editor that displays an interactive Python shell.
 """
 
-from traits.api import Bool, Str, Event, Property
+from traits.api import Bool, Str, Event, Property, observe
+from traits.observation.api import match
 
 from traitsui.basic_editor_factory import BasicEditorFactory
 from traitsui.editor import Editor
@@ -19,8 +20,7 @@ from traitsui.toolkit import toolkit_object
 
 
 class _ShellEditor(Editor):
-    """ Base class for an editor that displays an interactive Python shell.
-    """
+    """Base class for an editor that displays an interactive Python shell."""
 
     #: An event fired to execute a command in the shell.
     command_to_execute = Event()
@@ -36,8 +36,8 @@ class _ShellEditor(Editor):
     # -------------------------------------------------------------------------
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         # Moving the import here, since PythonShell is implemented in the
         # Pyface backend packages, and we want to delay loading this toolkit
@@ -45,19 +45,28 @@ class _ShellEditor(Editor):
         from pyface.python_shell import PythonShell
 
         locals = None
+        self._base_locals = None
         value = self.value
         if self.factory.share and isinstance(value, dict):
             locals = value
-        self._shell = shell = PythonShell(parent, locals=locals)
+        self._shell = shell = PythonShell(parent)
         self.control = shell.control
+        if locals:
+            for item in locals.items():
+                shell.bind(*item)
         if locals is None:
             object = self.object
             shell.bind("self", object)
-            shell.on_trait_change(
+            shell.observe(
                 self.update_object, "command_executed", dispatch="ui"
             )
             if not isinstance(value, dict):
-                object.on_trait_change(self.update_any, dispatch="ui")
+                self._any_trait_observer = lambda name, ctrait: True
+                object.observe(
+                    self.update_any,
+                    match(self._any_trait_observer),
+                    dispatch="ui",
+                )
             else:
                 self._base_locals = locals = {}
                 for name in self._shell.interpreter().locals.keys():
@@ -74,8 +83,7 @@ class _ShellEditor(Editor):
         self.set_tooltip()
 
     def update_object(self, event):
-        """ Handles the user entering input data in the edit control.
-        """
+        """Handles the user entering input data in the edit control."""
         locals = self._shell.interpreter().locals
         base_locals = self._base_locals
         if base_locals is None:
@@ -98,8 +106,8 @@ class _ShellEditor(Editor):
         self.command_executed = True
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         if self.factory.share:
             value = self.value
@@ -117,10 +125,11 @@ class _ShellEditor(Editor):
                 for name, value in dic.items():
                     locals[name] = value
 
-    def update_any(self, object, name, old, new):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+    def update_any(self, event):
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
+        name, new = event.name, event.new
         locals = self._shell.interpreter().locals
         if self._base_locals is None:
             locals[name] = new
@@ -128,19 +137,27 @@ class _ShellEditor(Editor):
             self.value[name] = new
 
     def dispose(self):
-        """ Disposes of the contents of an editor.
-        """
-        self._shell.on_trait_change(
-            self.update_object, "command_executed", remove=True
-        )
-        if self._base_locals is None:
-            self.object.on_trait_change(self.update_any, remove=True)
+        """Disposes of the contents of an editor."""
+        if not (self.factory.share and isinstance(self.value, dict)):
+            self._shell.observe(
+                self.update_object,
+                "command_executed",
+                remove=True,
+                dispatch="ui",
+            )
+            if self._base_locals is None:
+                self.object.observe(
+                    self.update_any,
+                    match(self._any_trait_observer),
+                    remove=True,
+                    dispatch="ui",
+                )
 
         super().dispose()
 
     def restore_prefs(self, prefs):
-        """ Restores any saved user preference information associated with the
-            editor.
+        """Restores any saved user preference information associated with the
+        editor.
         """
         shell = self._shell
         try:
@@ -151,8 +168,7 @@ class _ShellEditor(Editor):
             pass
 
     def save_prefs(self):
-        """ Returns any user preference information associated with the editor.
-        """
+        """Returns any user preference information associated with the editor."""
         history, history_index = self._shell.get_history()
         return {"history": history, "history_index": history_index}
 
@@ -162,16 +178,17 @@ class _ShellEditor(Editor):
 
     # Trait change handlers --------------------------------------------------
 
-    def _command_to_execute_fired(self, command):
-        """ Handles the 'command_to_execute' trait being fired.
-        """
+    @observe("command_to_execute")
+    def _execute_command(self, event):
+        """Handles the 'command_to_execute' trait being fired."""
         # Show the command. A 'hidden' command should be executed directly on
         # the namespace trait!
+        command = event.new
         self._shell.execute_command(command, hidden=False)
 
 
 class ShellEditor(BasicEditorFactory):
-    """ Editor factory for shell editors. """
+    """Editor factory for shell editors."""
 
     #: The editor class to be instantiated.
     klass = Property()
@@ -188,8 +205,7 @@ class ShellEditor(BasicEditorFactory):
     command_executed = Str()
 
     def _get_klass(self):
-        """ Returns the toolkit-specific editor class to be used in the UI.
-        """
+        """Returns the toolkit-specific editor class to be used in the UI."""
         return toolkit_object("shell_editor:_ShellEditor")
 
 
