@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -12,11 +12,12 @@
 """
 
 
-
 from .checkbox_column import CheckboxColumn
 from .edit_column import EditColumn
 from .has_dynamic_views import (
-    DynamicView, DynamicViewSubElement, HasDynamicViews
+    DynamicView,
+    DynamicViewSubElement,
+    HasDynamicViews,
 )
 from .progress_column import ProgressColumn
 from .saving import CanSaveMixin, SaveHandler
