@@ -1,18 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2016, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Corran Webster
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ A column class for for the TableEditor that displays progress bars. """
 
@@ -22,7 +16,7 @@ from traitsui.table_column import ObjectColumn
 
 
 class ProgressColumn(ObjectColumn):
-    """ A column which displays trait values as a progress bar
+    """A column which displays trait values as a progress bar
 
     Progress values must be an integer value between the maximum and minimum
     values.  By default it is assumed to be a percentage.
@@ -42,9 +36,10 @@ class ProgressColumn(ObjectColumn):
     text_visible = Bool(True)
 
     def __init__(self, **traits):
-        super(ProgressColumn, self).__init__(**traits)
+        super().__init__(**traits)
 
         from traitsui.toolkit import toolkit_object
+
         ProgressRenderer = toolkit_object(
             'extra.progress_renderer:ProgressRenderer'
         )
@@ -52,8 +47,7 @@ class ProgressColumn(ObjectColumn):
         self.renderer = ProgressRenderer()
 
     def is_editable(self, object):
-        """ Returns whether the column is editable for a specified object.
-        """
+        """Returns whether the column is editable for a specified object."""
         # Progress columns are always read-only
         return False
 
@@ -64,7 +58,7 @@ class ProgressColumn(ObjectColumn):
         return self.maximum
 
     def get_text_visible(self):
-        """ Whether or not to display text in column.
+        """Whether or not to display text in column.
 
         Note, may not render on some platforms (eg. OS X) due to
         the rendering style.
