@@ -1,26 +1,18 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/07/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines functions and classes used to create pop-up file dialogs for
     opening and saving files.
 """
 
 
-
 from os import R_OK, W_OK, access, mkdir
 
 from os.path import (
@@ -95,8 +87,7 @@ MAX_SIZE = 16 * 1024 * 1024
 
 
 class IFileDialogModel(Interface):
-    """ Defines a model extension to a file dialog.
-    """
+    """Defines a model extension to a file dialog."""
 
     #: The name of the currently selected file:
     file_name = File()
@@ -108,8 +99,7 @@ class IFileDialogModel(Interface):
 
 
 class IFileDialogView(Interface):
-    """ Defines a visual extension to a file dialog.
-    """
+    """Defines a visual extension to a file dialog."""
 
     #: The view to display:
     view = AView
@@ -124,8 +114,8 @@ class IFileDialogView(Interface):
 
 
 class IFileDialogExtension(IFileDialogModel, IFileDialogView):
-    """ Defines a (convenience) union of the IFileDialogModel and
-        IFileDialogView interfaces.
+    """Defines a (convenience) union of the IFileDialogModel and
+    IFileDialogView interfaces.
     """
 
 
@@ -147,8 +137,7 @@ class MFileDialogModel(HasPrivateTraits):
 
 
 class MFileDialogView(HasPrivateTraits):
-    """ Defines a visual extension to a file dialog.
-    """
+    """Defines a visual extension to a file dialog."""
 
     #: The view to display:
     view = AView
@@ -162,26 +151,25 @@ default_view = MFileDialogView()
 
 
 class MFileDialogExtension(MFileDialogModel, MFileDialogView):
-    """ Defines a (convenience) union of the MFileDialogModel and
-        MFileDialogView mix-in classes.
+    """Defines a (convenience) union of the MFileDialogModel and
+    MFileDialogView mix-in classes.
     """
 
 
 class FileInfo(MFileDialogModel):
-    """ Defines a file dialog extension that display various file information.
-    """
+    """Defines a file dialog extension that display various file information."""
 
     #: The size of the file:
-    size = Property(depends_on="file_name")
+    size = Property(observe="file_name")
 
     #: Last file access time:
-    atime = Property(depends_on="file_name")
+    atime = Property(observe="file_name")
 
     #: List file modification time:
-    mtime = Property(depends_on="file_name")
+    mtime = Property(observe="file_name")
 
     #: File creation time (or last metadata change time):
-    ctime = Property(depends_on="file_name")
+    ctime = Property(observe="file_name")
 
     # -- Traits View Definitions ----------------------------------------------
 
@@ -234,11 +222,10 @@ class FileInfo(MFileDialogModel):
 
 
 class TextInfo(MFileDialogModel):
-    """ Defines a file dialog extension that displays a file's contents as text.
-    """
+    """Defines a file dialog extension that displays a file's contents as text."""
 
     #: The file's text content:
-    text = Property(depends_on="file_name")
+    text = Property(observe="file_name")
 
     # -- Traits View Definitions ----------------------------------------------
 
@@ -266,18 +253,18 @@ class TextInfo(MFileDialogModel):
 
 
 class ImageInfo(MFileDialogModel):
-    """ Defines a file dialog extension that display an image file's dimensions
-        and content.
+    """Defines a file dialog extension that display an image file's dimensions
+    and content.
     """
 
     #: The ImageResource object for the current file:
-    image = Property(depends_on="file_name")
+    image = Property(observe="file_name")
 
     #: The width of the current image:
-    width = Property(depends_on="image")
+    width = Property(observe="image")
 
     #: The height of the current image:
-    height = Property(depends_on="image")
+    height = Property(observe="image")
 
     # -- Traits View Definitions ----------------------------------------------
 
@@ -326,8 +313,7 @@ class ImageInfo(MFileDialogModel):
 
 
 class CreateDirHandler(Handler):
-    """ Controller for the 'create new directory' popup.
-    """
+    """Controller for the 'create new directory' popup."""
 
     #: The name for the new directory to be created:
     dir_name = Str()
@@ -368,8 +354,7 @@ class CreateDirHandler(Handler):
     # -- Handler Event Handlers -----------------------------------------------
 
     def handler_ok_changed(self, info):
-        """ Handles the user clicking the OK button.
-        """
+        """Handles the user clicking the OK button."""
         dir = info.object.file_name
         if not isdir(dir):
             dir = dirname(dir)
@@ -393,14 +378,12 @@ class CreateDirHandler(Handler):
             )
 
     def handler_cancel_changed(self, info):
-        """ Handles the user clicking the Cancel button.
-        """
+        """Handles the user clicking the Cancel button."""
         info.ui.dispose(False)
 
 
 class FileExistsHandler(Handler):
-    """ Controller for the 'file already exists' popup.
-    """
+    """Controller for the 'file already exists' popup."""
 
     #: The current status message:
     message = Str()
@@ -434,21 +417,18 @@ class FileExistsHandler(Handler):
     # -- Handler Event Handlers -----------------------------------------------
 
     def handler_ok_changed(self, info):
-        """ Handles the user clicking the OK button.
-        """
+        """Handles the user clicking the OK button."""
         parent = info.ui.parent
         info.ui.dispose(True)
         parent.dispose(True)
 
     def handler_cancel_changed(self, info):
-        """ Handles the user clicking the Cancel button.
-        """
+        """Handles the user clicking the Cancel button."""
         info.ui.dispose(False)
 
 
 class OpenFileDialog(Handler):
-    """ Defines the model and handler for the open file dialog.
-    """
+    """Defines the model and handler for the open file dialog."""
 
     #: The starting and current file path:
     file_name = File()
@@ -486,10 +466,10 @@ class OpenFileDialog(Handler):
     is_save_file = Bool(False)
 
     #: Is the currently specified file name valid?
-    is_valid_file = Property(depends_on="file_name")
+    is_valid_file = Property(observe="file_name")
 
     #: Can a directory be created now?
-    can_create_dir = Property(depends_on="file_name")
+    can_create_dir = Property(observe="file_name")
 
     #: The OK, Cancel and create directory buttons:
     ok = Button("OK")
@@ -499,8 +479,7 @@ class OpenFileDialog(Handler):
     # -- Handler Class Method Overrides ---------------------------------------
 
     def init_info(self, info):
-        """ Handles the UIInfo object being initialized during view start-up.
-        """
+        """Handles the UIInfo object being initialized during view start-up."""
         self.info = info
 
     # -- Property Implementations ---------------------------------------------
@@ -518,21 +497,18 @@ class OpenFileDialog(Handler):
     # -- Handler Event Handlers -----------------------------------------------
 
     def object_ok_changed(self, info):
-        """ Handles the user clicking the OK button.
-        """
+        """Handles the user clicking the OK button."""
         if self.is_save_file and exists(self.file_name):
             do_later(self._file_already_exists)
         else:
             info.ui.dispose(True)
 
     def object_cancel_changed(self, info):
-        """ Handles the user clicking the Cancel button.
-        """
+        """Handles the user clicking the Cancel button."""
         info.ui.dispose(False)
 
     def object_create_changed(self, info):
-        """ Handles the user clicking the create directory button.
-        """
+        """Handles the user clicking the create directory button."""
         if not isdir(self.file_name):
             self.file_name = dirname(self.file_name)
 
@@ -543,16 +519,14 @@ class OpenFileDialog(Handler):
     # -- Traits Event Handlers ------------------------------------------------
 
     def _dclick_changed(self):
-        """ Handles the user double-clicking a file name in the file tree view.
-        """
+        """Handles the user double-clicking a file name in the file tree view."""
         if self.is_valid_file:
             self.object_ok_changed(self.info)
 
     # -- Private Methods ------------------------------------------------------
 
     def open_file_view(self):
-        """ Returns the file dialog view to use.
-        """
+        """Returns the file dialog view to use."""
         # Set up the default file dialog view and size information:
         item = Item(
             "file_name",
@@ -668,8 +642,8 @@ class OpenFileDialog(Handler):
         )
 
     def _file_already_exists(self):
-        """ Handles prompting the user when the selected file already exists,
-            and the dialog is a 'save file' dialog.
+        """Handles prompting the user when the selected file already exists,
+        and the dialog is a 'save file' dialog.
         """
         feh = FileExistsHandler(
             message=(
@@ -690,8 +664,8 @@ class OpenFileDialog(Handler):
 
 
 def open_file(**traits):
-    """ Returns a file name to open or an empty string if the user cancels the
-        operation.
+    """Returns a file name to open or an empty string if the user cancels the
+    operation.
     """
     fd = OpenFileDialog(**traits)
     if fd.edit_traits(view="open_file_view").result:
@@ -701,10 +675,10 @@ def open_file(**traits):
 
 
 def save_file(**traits):
-    """ Returns a file name to save to or an empty string if the user cancels
-        the operation. In the case where the file selected already exists, the
-        user will be prompted if they want to overwrite the file before the
-        selected file name is returned.
+    """Returns a file name to save to or an empty string if the user cancels
+    the operation. In the case where the file selected already exists, the
+    user will be prompted if they want to overwrite the file before the
+    selected file name is returned.
     """
     traits.setdefault("title", "Save File")
     traits["is_save_file"] = True
