@@ -1,26 +1,18 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/07/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the Item class, which is used to represent a single item within
     a Traits-based user interface.
 """
 
 
-
 import re
 
 from traits.api import (
@@ -45,7 +37,6 @@ from .ui_traits import ContainerDelegate, EditorStyle
 from .editor_factory import EditorFactory
 
 
-
 # Pattern of all digits:
 all_digits = re.compile(r"\d+")
 
@@ -71,7 +62,7 @@ Padding = Range(-15, 15, 0, desc="amount of padding to add around item")
 
 
 class Item(ViewSubElement):
-    """ An element in a Traits-based user interface.
+    """An element in a Traits-based user interface.
 
     Magic:
 
@@ -158,12 +149,6 @@ class Item(ViewSubElement):
     #: any extra space available in the group?
     springy = Bool(False)
 
-    #: Should the item use any extra space along its Group's non-layout
-    #: orientation? For example, in a vertical group, should an item expand
-    #: horizontally to the full width of the group? If left to the default value
-    #: of Undefined, the decision will be left up to the associated item editor.
-    full_size = Bool(Undefined)
-
     #: Should the item's label use emphasized text? If the label is not shown,
     #: this attribute is ignored.
     emphasized = Bool(False)
@@ -184,15 +169,27 @@ class Item(ViewSubElement):
     #: the widget is not visible (and disappears if it was previously visible).
     #: If the value evaluates to True, the widget becomes visible. All
     #: **visible_when** conditions are checked each time that any trait value
-    #: is edited in the display. Therefore, you can use **visible_when**
-    #: conditions to hide or show widgets in response to user input.
+    #: on an object in the UI's context is changed. Therefore, you can use
+    #: **visible_when** conditions to hide or show widgets in response to user
+    #: input. Be aware that this only applies to traits in the UI's context. As
+    #: a result, changes to nested traits that don't also change a trait on
+    #: some object in the context may not trigger the expression to be checked.
+    #: Additionally, the expression needs to be a valid python expression given
+    #: the context. i.e. eval(visible_when, globals=globals(), locals=context)
+    #: should succeed.
     visible_when = Str()
 
     #: Pre-condition for enabling the item. If the expression evaluates to False,
     #: the widget is disabled, that is, it does not accept input. All
     #: **enabled_when** conditions are checked each time that any trait value
-    #: is edited in the display. Therefore, you can use **enabled_when**
-    #: conditions to enable or disable widgets in response to user input.
+    #: on an object in the UI's context is changed. Therefore, you can use
+    #: **enabled_when** conditions to enable or disable widgets in response to
+    #: user input. Be aware that this only applies to traits in the UI's
+    #: context. As a result, changes to nested traits that don't also change a
+    #: trait on some object in the context may not trigger the expression to be
+    #: checked. Additionally, the expression needs to be a valid python
+    #: expression given the context. i.e.
+    #: eval(enabled_when, globals=globals(), locals=context) should succeed.
     enabled_when = Str()
 
     #: Amount of extra space, in pixels, to add around the item. Values must be
@@ -261,9 +258,8 @@ class Item(ViewSubElement):
     invalid = Str()
 
     def __init__(self, value=None, **traits):
-        """ Initializes the item object.
-        """
-        super(Item, self).__init__(**traits)
+        """Initializes the item object."""
+        super().__init__(**traits)
 
         if value is None:
             return
@@ -291,14 +287,13 @@ class Item(ViewSubElement):
             self.name = value
 
     def is_includable(self):
-        """ Returns a Boolean indicating whether the object is replaceable by an
-            Include object.
+        """Returns a Boolean indicating whether the object is replaceable by an
+        Include object.
         """
         return self.id != ""
 
     def is_spacer(self):
-        """ Returns True if the item represents a spacer or separator.
-        """
+        """Returns True if the item represents a spacer or separator."""
         name = self.name.strip()
 
         return (
@@ -308,8 +303,7 @@ class Item(ViewSubElement):
         )
 
     def get_help(self, ui):
-        """ Gets the help text associated with the Item in a specified UI.
-        """
+        """Gets the help text associated with the Item in a specified UI."""
         # Return 'None' if the Item is a separator or spacer:
         if self.is_spacer():
             return None
@@ -323,7 +317,7 @@ class Item(ViewSubElement):
         return object.base_trait(self.name).get_help()
 
     def get_label(self, ui):
-        """ Gets the label to use for a specified Item.
+        """Gets the label to use for a specified Item.
 
         If not specified, the label is set as the name of the
         corresponding trait, replacing '_' with ' ', and capitalizing
@@ -365,16 +359,14 @@ class Item(ViewSubElement):
         return tlabel(object, name, label)
 
     def get_id(self):
-        """ Returns an ID used to identify the item.
-        """
+        """Returns an ID used to identify the item."""
         if self.id != "":
             return self.id
 
         return self.name
 
     def _parse_size(self, value):
-        """ Parses a '<width,height>' value from the string definition.
-        """
+        """Parses a '<width,height>' value from the string definition."""
         match = size_pat.match(value)
         if match is not None:
             data = match.group(2)
@@ -389,8 +381,7 @@ class Item(ViewSubElement):
         return value
 
     def _parse_tooltip(self, value):
-        """ Parses a *tooltip* value from the string definition.
-        """
+        """Parses a *tooltip* value from the string definition."""
         match = tooltip_pat.match(value)
         if match is not None:
             self.tooltip = match.group(2)
@@ -399,15 +390,13 @@ class Item(ViewSubElement):
         return value
 
     def _set_float(self, name, value):
-        """ Sets a specified trait to a specified string converted to a float.
-        """
+        """Sets a specified trait to a specified string converted to a float."""
         value = value.strip()
         if value != "":
             setattr(self, name, float(value))
 
     def __repr__(self):
-        """ Returns a "pretty print" version of the Item.
-        """
+        """Returns a "pretty print" version of the Item."""
 
         options = self._repr_options(
             "id", "object", "label", "style", "show_label", "width", "height"
@@ -427,8 +416,7 @@ class Item(ViewSubElement):
 
 
 class UItem(Item):
-    """ An Item that has no label.
-    """
+    """An Item that has no label."""
 
     show_label = Bool(False)
 
@@ -439,8 +427,7 @@ class UItem(Item):
 
 
 class Custom(Item):
-    """ An Item using a 'custom' style.
-    """
+    """An Item using a 'custom' style."""
 
     style = EditorStyle("custom")
 
@@ -451,8 +438,7 @@ class Custom(Item):
 
 
 class UCustom(Custom):
-    """ An Item using a 'custom' style with no label.
-    """
+    """An Item using a 'custom' style with no label."""
 
     show_label = Bool(False)
 
@@ -463,8 +449,7 @@ class UCustom(Custom):
 
 
 class Readonly(Item):
-    """ An Item using a 'readonly' style.
-    """
+    """An Item using a 'readonly' style."""
 
     style = EditorStyle("readonly")
 
@@ -475,8 +460,7 @@ class Readonly(Item):
 
 
 class UReadonly(Readonly):
-    """ An Item using a 'readonly' style with no label.
-    """
+    """An Item using a 'readonly' style with no label."""
 
     show_label = Bool(False)
 
@@ -487,11 +471,10 @@ class UReadonly(Readonly):
 
 
 class Label(Item):
-    """ An item that is a label.
-    """
+    """An item that is a label."""
 
     def __init__(self, label, **traits):
-        super(Label, self).__init__(label=label, **traits)
+        super().__init__(label=label, **traits)
 
 
 # -------------------------------------------------------------------------
@@ -500,8 +483,7 @@ class Label(Item):
 
 
 class Heading(Label):
-    """ An item that is a fancy label.
-    """
+    """An item that is a fancy label."""
 
     #: Override the 'style' trait to default to the fancy 'custom' style:
     style = Constant("custom")
@@ -513,8 +495,7 @@ class Heading(Label):
 
 
 class Spring(Item):
-    """ An item that is a layout "spring".
-    """
+    """An item that is a layout "spring"."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
