@@ -1,28 +1,20 @@
-# -------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2008, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   02/29/2008
-#
-# -------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """  Defines adapter interfaces for use with the ListStrEditor.
 """
 
-
-
 from traits.api import (
     Any,
     Bool,
+    Dict,
     Enum,
     Event,
     HasPrivateTraits,
@@ -30,7 +22,7 @@ from traits.api import (
     Interface,
     List,
     Str,
-    on_trait_change,
+    observe,
     provides,
 )
 from .toolkit_traits import Color
@@ -91,8 +83,8 @@ class AnIListStrAdapter(HasPrivateTraits):
 
 
 class ListStrAdapter(HasPrivateTraits):
-    """ The base class for adapting list items to values that can be edited
-        by a ListStrEditor.
+    """The base class for adapting list items to values that can be edited
+    by a ListStrEditor.
     """
 
     # Trait Definitions ------------------------------------------------------
@@ -140,13 +132,16 @@ class ListStrAdapter(HasPrivateTraits):
     #: The current value (if any).
     value = Any()
 
+    #: The tooltip information for a item.
+    tooltip = Str(update=True)
+
     #: List of optional delegated adapters.
     adapters = List(IListStrAdapter, update=True)
 
     # -- Private Trait Definitions --------------------------------------------
 
     #: Cache of attribute handlers.
-    cache = Any({})
+    cache = Dict()
 
     #: Event fired when the cache is flushed.
     cache_flushed = Event(update=True)
@@ -154,75 +149,84 @@ class ListStrAdapter(HasPrivateTraits):
     # -- Adapter methods that are sensitive to item type ----------------------
 
     def get_can_edit(self, object, trait, index):
-        """ Returns whether the user can edit a specified *object.trait[index]*
-            list item. A True result indicates the value can be edited, while
-            a False result indicates that it cannot be edited.
+        """Returns whether the user can edit a specified *object.trait[index]*
+        list item. A True result indicates the value can be edited, while
+        a False result indicates that it cannot be edited.
         """
         return self._result_for("get_can_edit", object, trait, index)
 
     def get_drag(self, object, trait, index):
-        """ Returns the 'drag' value for a specified *object.trait[index]*
-            list item. A result of *None* means that the item cannot be dragged.
+        """Returns the 'drag' value for a specified *object.trait[index]*
+        list item. A result of *None* means that the item cannot be
+        dragged.
         """
         return self._result_for("get_drag", object, trait, index)
 
     def get_can_drop(self, object, trait, index, value):
-        """ Returns whether the specified *value* can be dropped on the
-            specified *object.trait[index]* list item. A value of **True** means
-            the *value* can be dropped; and a value of **False** indicates that
-            it cannot be dropped.
+        """Returns whether the specified *value* can be dropped on the
+        specified *object.trait[index]* list item. A value of **True**
+        means the *value* can be dropped; and a value of **False**
+        indicates that it cannot be dropped.
         """
         return self._result_for("get_can_drop", object, trait, index, value)
 
     def get_dropped(self, object, trait, index, value):
-        """ Returns how to handle a specified *value* being dropped on a
-            specified *object.trait[index]* list item. The possible return
-            values are:
+        """Returns how to handle a specified *value* being dropped on a
+        specified *object.trait[index]* list item. The possible return
+        values are:
 
-            'before'
-                Insert the specified *value* before the dropped on item.
-            'after'
-                Insert the specified *value* after the dropped on item.
+        'before'
+            Insert the specified *value* before the dropped on item.
+        'after'
+            Insert the specified *value* after the dropped on item.
         """
         return self._result_for("get_dropped", object, trait, index, value)
 
     def get_text_color(self, object, trait, index):
-        """ Returns the text color for a specified *object.trait[index]* list
-            item. A result of None means use the default list item text color.
+        """Returns the text color for a specified *object.trait[index]* list
+        item. A result of None means use the default list item text color.
         """
         return self._result_for("get_text_color", object, trait, index)
 
     def get_bg_color(self, object, trait, index):
-        """ Returns the background color for a specified *object.trait[index]*
-            list item. A result of None means use the default list item
-            background color.
+        """Returns the background color for a specified *object.trait[index]*
+        list item. A result of None means use the default list item
+        background color.
         """
         return self._result_for("get_bg_color", object, trait, index)
 
     def get_image(self, object, trait, index):
-        """ Returns the name of the image to use for a specified
-            *object.trait[index]* list item. A result of None means no image
-            should be used. Otherwise, the result should either be the name of
-            the image, or an ImageResource item specifying the image to use.
+        """Returns the name of the image to use for a specified
+        *object.trait[index]* list item. A result of None means no image
+        should be used. Otherwise, the result should either be the name of
+        the image, or an ImageResource item specifying the image to use.
         """
         return self._result_for("get_image", object, trait, index)
 
     def get_item(self, object, trait, index):
-        """ Returns the value of the *object.trait[index]* list item.
-        """
+        """Returns the value of the *object.trait[index]* list item."""
         return self._result_for("get_item", object, trait, index)
 
     def get_text(self, object, trait, index):
-        """ Returns the text to display for a specified *object.trait[index]*
-            list item.
+        """Returns the text to display for a specified *object.trait[index]*
+        list item.
         """
         return self._result_for("get_text", object, trait, index)
 
+    def get_tooltip(self, object, trait, index):
+        """Returns a string containing the tooltip to display for a specified
+        *object.trait[index]* list item.
+
+        Users should return *self.tooltip* to use the Adapter's default, or the
+        empty string to disable the tooltip for this row (in which case the Item's
+        tooltip, if present, will be shown on QT).
+        """
+        return self._result_for("get_tooltip", object, trait, index)
+
     # -- Adapter methods that are not sensitive to item type ------------------
 
     def len(self, object, trait):
-        """ Returns the number of items in the specified *object.trait* list.
-        """
+        """Returns the number of items in the specified *object.trait* list."""
         # Sometimes, during shutdown, the object has been set to None.
         if object is None:
             return 0
@@ -230,46 +234,42 @@ class ListStrAdapter(HasPrivateTraits):
             return len(getattr(object, trait))
 
     def get_default_value(self, object, trait):
-        """ Returns a new default value for the specified *object.trait* list.
-        """
+        """Returns a new default value for the specified *object.trait* list."""
         return self.default_value
 
     def get_default_text(self, object, trait):
-        """ Returns the default text for the specified *object.trait* list.
-        """
+        """Returns the default text for the specified *object.trait* list."""
         return self.default_text
 
     def get_default_image(self, object, trait):
-        """ Returns the default image for the specified *object.trait* list.
-        """
+        """Returns the default image for the specified *object.trait* list."""
         return self.image
 
     def get_default_bg_color(self, object, trait):
-        """ Returns the default background color for the specified
-            *object.trait* list.
+        """Returns the default background color for the specified
+        *object.trait* list.
         """
         return self._get_bg_color()
 
     def get_default_text_color(self, object, trait):
-        """ Returns the default text color for the specified *object.trait*
-            list.
+        """Returns the default text color for the specified *object.trait*
+        list.
         """
         return self._get_text_color()
 
     def set_text(self, object, trait, index, text):
-        """ Sets the text for a specified *object.trait[index]* list item to
-            *text*.
+        """Sets the text for a specified *object.trait[index]* list item to
+        *text*.
         """
         getattr(object, trait)[index] = text
 
     def delete(self, object, trait, index):
-        """ Deletes the specified *object.trait[index]* list item.
-        """
+        """Deletes the specified *object.trait[index]* list item."""
         del getattr(object, trait)[index]
 
     def insert(self, object, trait, index, value):
-        """ Inserts a new value at the specified *object.trait[index]* list
-            index.
+        """Inserts a new value at the specified *object.trait[index]* list
+        index.
         """
         getattr(object, trait)[index:index] = [value]
 
@@ -308,11 +308,14 @@ class ListStrAdapter(HasPrivateTraits):
     def _get_text(self):
         return str(self.item)
 
+    def _get_tooltip(self):
+        return self.tooltip
+
     # -- Private Methods ------------------------------------------------------
 
     def _result_for(self, name, object, trait, index, value=None):
-        """ Returns/Sets the value of the specified *name* attribute for the
-            specified *object.trait[index]* list item.
+        """Returns/Sets the value of the specified *name* attribute for the
+        specified *object.trait[index]* list item.
         """
         self.index = index
         self.value = value
@@ -358,9 +361,8 @@ class ListStrAdapter(HasPrivateTraits):
         self.cache[key] = handler
         return handler()
 
-    @on_trait_change("adapters.+update")
-    def _flush_cache(self):
-        """ Flushes the cache when any trait on any adapter changes.
-        """
+    @observe("adapters.items.+update")
+    def _flush_cache(self, event):
+        """Flushes the cache when any trait on any adapter changes."""
         self.cache = {}
         self.cache_flushed = True
