@@ -1,25 +1,17 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   02/14/2005
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Trait definition for a null-based (i.e., no UI) color.
 """
 
 
-
 from traits.api import Trait, TraitError
 
 # -------------------------------------------------------------------------
@@ -28,8 +20,7 @@ from traits.api import Trait, TraitError
 
 
 def convert_to_color(object, name, value):
-    """ Converts a number into a wxColour object.
-    """
+    """Converts a number into a wxColour object."""
     if isinstance(value, int):
         return value & 0xFFFFFF
 
