@@ -1,3 +1,13 @@
+# (C) Copyright 2008-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
@@ -15,20 +25,15 @@
 
 
 from pyface.qt import QtCore, QtGui
+from pyface.api import Image
 
-from traits.api import Str, List, Str, on_trait_change
-
-# FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
-# compatibility. The class has been moved to the
-# traitsui.editors.button_editor file.
-from traitsui.editors.button_editor import ToolkitEditorFactory
+from traits.api import List, Str, observe, on_trait_change
 
 from .editor import Editor
 
 
 class SimpleEditor(Editor):
-    """ Simple style editor for a button.
-    """
+    """Simple style editor for a button."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -44,20 +49,17 @@ class SimpleEditor(Editor):
     selected_item = Str()
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         label = self.factory.label or self.item.get_label(self.ui)
 
         if self.factory.values_trait:
             self.control = QtGui.QToolButton()
-            self.control.toolButtonStyle = QtCore.Qt.ToolButtonTextOnly
+            self.control.toolButtonStyle = QtCore.Qt.ToolButtonStyle.ToolButtonTextOnly
             self.control.setText(self.string_value(label))
-            self.object.on_trait_change(
-                self._update_menu, self.factory.values_trait
-            )
-            self.object.on_trait_change(
-                self._update_menu, self.factory.values_trait + "_items"
+            self.object.observe(
+                self._update_menu, self.factory.values_trait + ".items"
             )
             self._menu = QtGui.QMenu()
             self._update_menu()
@@ -69,20 +71,35 @@ class SimpleEditor(Editor):
             self.control.setAutoDefault(False)
 
         self.sync_value(self.factory.label_value, "label", "from")
-        self.control.clicked.connect(self.update_object)
+
+        # The connection type is set to workaround Qt5 + MacOSX issue with
+        # event dispatching. Without the type set to QueuedConnection, other
+        # widgets may not repaint properly in response to a button click.
+        # See enthought/traitsui#1308
+        self.control.clicked.connect(
+            self.update_object,
+            type=QtCore.Qt.ConnectionType.QueuedConnection,
+        )
         self.set_tooltip()
 
     def dispose(self):
-        """ Disposes of the contents of an editor.
-        """
+        """Disposes of the contents of an editor."""
+
+        if self.factory.values_trait:
+            self.object.observe(
+                self._update_menu,
+                self.factory.values_trait + ".items",
+                remove=True,
+            )
+
         if self.control is not None:
             self.control.clicked.disconnect(self.update_object)
-        super(SimpleEditor, self).dispose()
+        super().dispose()
 
     def _label_changed(self, label):
         self.control.setText(self.string_value(label))
 
-    def _update_menu(self):
+    def _update_menu(self, event=None):
         self._menu.blockSignals(True)
         self._menu.clear()
         for item in getattr(self.object, self.factory.values_trait):
@@ -98,8 +115,8 @@ class SimpleEditor(Editor):
         self.label = item_name
 
     def update_object(self):
-        """ Handles the user clicking the button by setting the factory value
-            on the object.
+        """Handles the user clicking the button by setting the factory value
+        on the object.
         """
         if self.control is None:
             return
@@ -115,15 +132,17 @@ class SimpleEditor(Editor):
             )
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         pass
 
 
 class CustomEditor(SimpleEditor):
-    """ Custom style editor for a button, which can contain an image.
-    """
+    """Custom style editor for a button, which can contain an image."""
+
+    #: The button image
+    image = Image()
 
     #: The mapping of button styles to Qt classes.
     _STYLE_MAP = {
@@ -133,8 +152,8 @@ class CustomEditor(SimpleEditor):
     }
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         # FIXME: We ignore orientation, width_padding and height_padding.
 
@@ -151,5 +170,20 @@ class CustomEditor(SimpleEditor):
             self.control.setIcon(factory.image.create_icon())
 
         self.sync_value(self.factory.label_value, "label", "from")
+        self.sync_value(self.factory.image_value, "image", "from")
         self.control.clicked.connect(self.update_object)
         self.set_tooltip()
+
+    @observe("image")
+    def _image_updated(self, event):
+        image = event.new
+        self.control.setIcon(image.create_icon())
+
+    def dispose(self):
+        """Disposes of the contents of an editor."""
+        if self.control is not None:
+            self.control.clicked.disconnect(self.update_object)
+
+        # FIXME: Maybe better to let this class subclass Editor directly
+        # enthought/traitsui#884
+        Editor.dispose(self)
