@@ -1,3 +1,13 @@
+# (C) Copyright 2008-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
@@ -14,8 +24,7 @@
 """
 
 
-
-from pyface.qt import QtCore, QtGui
+from pyface.qt import QtCore, QtGui, is_pyside
 
 from traitsui.editors.color_editor import (
     ToolkitEditorFactory as BaseToolkitEditorFactory,
@@ -30,7 +39,6 @@ from .editor_factory import (
 from .editor import Editor
 
 
-
 # Standard color samples:
 color_samples = []
 
@@ -45,25 +53,21 @@ color_samples = []
 
 
 class ToolkitEditorFactory(BaseToolkitEditorFactory):
-    """ PyQt editor factory for color editors.
-    """
+    """PyQt editor factory for color editors."""
 
     def to_qt4_color(self, editor):
-        """ Gets the PyQt color equivalent of the object trait.
-        """
+        """Gets the PyQt color equivalent of the object trait."""
         if self.mapped:
             return getattr(editor.object, editor.name + "_")
 
         return getattr(editor.object, editor.name)
 
     def from_qt4_color(self, color):
-        """ Gets the application equivalent of a PyQt value.
-        """
+        """Gets the application equivalent of a PyQt value."""
         return color
 
     def str_color(self, color):
-        """ Returns the text representation of a specified color value.
-        """
+        """Returns the text representation of a specified color value."""
         if isinstance(color, QtGui.QColor):
             alpha = color.alpha()
             if alpha == 255:
@@ -84,20 +88,19 @@ class ToolkitEditorFactory(BaseToolkitEditorFactory):
 
 
 class SimpleColorEditor(BaseSimpleEditor):
-    """ Simple style of color editor, which displays a text field whose
+    """Simple style of color editor, which displays a text field whose
     background color is the color value. Selecting the text field displays
     a dialog box for selecting a new color value.
     """
 
     def popup_editor(self):
-        """ Invokes the pop-up editor for an object trait.
-        """
+        """Invokes the pop-up editor for an object trait."""
         color = self.factory.to_qt4_color(self)
-        options = QtGui.QColorDialog.ShowAlphaChannel
+        options = QtGui.QColorDialog.ColorDialogOption.ShowAlphaChannel
         if not self.factory.use_native_dialog:
-            options |= QtGui.QColorDialog.DontUseNativeDialog
+            options |= QtGui.QColorDialog.ColorDialogOption.DontUseNativeDialog
         color = QtGui.QColorDialog.getColor(
-            color, self.control, u"Select Color", options
+            color, self.control, "Select Color", options
         )
 
         if color.isValid():
@@ -105,101 +108,93 @@ class SimpleColorEditor(BaseSimpleEditor):
             self.update_editor()
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
-        super(SimpleColorEditor, self).update_editor()
+        super().update_editor()
         set_color(self)
 
     def string_value(self, color):
-        """ Returns the text representation of a specified color value.
-        """
+        """Returns the text representation of a specified color value."""
         return self.factory.str_color(color)
 
 
 class CustomColorEditor(Editor):
-    """ Custom style of color editor, which displays a color editor panel.
-    """
+    """Custom style of color editor, which displays a color editor panel."""
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         self.control, self._simple_field = color_editor_for(self, parent)
 
     def dispose(self):
-        """ Disposes of the contents of an editor.
-        """
+        """Disposes of the contents of an editor."""
         if getattr(self, "_simple_field", None) is not None:
             self._simple_field.dispose()
             self._simple_field = None
-        super(CustomColorEditor, self).dispose()
+        super().dispose()
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         self._simple_field.update_editor()
 
     def update_object_from_swatch(self, color_text):
-        """ Updates the object trait when a color swatch is clicked.
-        """
+        """Updates the object trait when a color swatch is clicked."""
         color = QtGui.QColor(*[int(part) for part in color_text.split(",")])
         self.value = self.factory.from_qt4_color(color)
         self.update_editor()
 
     def string_value(self, color):
-        """ Returns the text representation of a specified color value.
-        """
+        """Returns the text representation of a specified color value."""
         return self.factory.str_color(color)
 
 
 class TextColorEditor(BaseTextEditor):
-    """ Text style of color editor, which displays a text field whose
+    """Text style of color editor, which displays a text field whose
     background color is the color value.
     """
 
     def update_object(self):
-        """ Handles the user changing the contents of the edit control.
-        """
+        """Handles the user changing the contents of the edit control."""
         self.value = str(self.control.text())
         set_color(self)
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
-        super(TextColorEditor, self).update_editor()
+        super().update_editor()
         set_color(self)
 
     def string_value(self, color):
-        """ Returns the text representation of a specified color value.
-        """
+        """Returns the text representation of a specified color value."""
         return self.factory.str_color(color)
 
 
 class ReadonlyColorEditor(BaseReadonlyEditor):
-    """ Read-only style of color editor, which displays a read-only text field
+    """Read-only style of color editor, which displays a read-only text field
     whose background color is the color value.
     """
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         self.control = QtGui.QLineEdit()
         self.control.setReadOnly(True)
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
-        super(ReadonlyColorEditor, self).update_editor()
+        super().update_editor()
         set_color(self)
 
     def string_value(self, color):
-        """ Returns the text representation of a specified color value.
-        """
+        """Returns the text representation of a specified color value."""
         return self.factory.str_color(color)
 
 
@@ -209,17 +204,16 @@ class ReadonlyColorEditor(BaseReadonlyEditor):
 
 
 def set_color(editor):
-    """  Sets the color of the specified color control.
-    """
+    """Sets the color of the specified color control."""
     color = editor.factory.to_qt4_color(editor)
     pal = QtGui.QPalette(editor.control.palette())
 
-    pal.setColor(QtGui.QPalette.Base, color)
+    pal.setColor(QtGui.QPalette.ColorRole.Base, color)
 
     if color.red() > 192 or color.blue() > 192 or color.green() > 192:
-        pal.setColor(QtGui.QPalette.Text, QtCore.Qt.black)
+        pal.setColor(QtGui.QPalette.ColorRole.Text, QtCore.Qt.GlobalColor.black)
     else:
-        pal.setColor(QtGui.QPalette.Text, QtCore.Qt.white)
+        pal.setColor(QtGui.QPalette.ColorRole.Text, QtCore.Qt.GlobalColor.white)
 
     editor.control.setPalette(pal)
 
@@ -230,7 +224,7 @@ def set_color(editor):
 
 
 class FixedButton(QtGui.QPushButton):
-    """ Override to work around a bug in Qt 4.7 on Macs.
+    """Override to work around a bug in Qt 4.7 on Macs.
 
     https://bugreports.qt-project.org/browse/QTBUG-15936
     """
@@ -240,8 +234,7 @@ class FixedButton(QtGui.QPushButton):
 
 
 def color_editor_for(editor, parent):
-    """ Creates a custom color editor panel for a specified editor.
-    """
+    """Creates a custom color editor panel for a specified editor."""
     # Create the colour samples if it hasn't already been done.
     if len(color_samples) == 0:
         color_choices = (0, 128, 192, 255)
@@ -286,7 +279,7 @@ def color_editor_for(editor, parent):
             color = color_samples[r * cols + c]
             color_text = "%d,%d,%d,%d" % color.getRgb()
             control.setStyleSheet(sheet_template % color_text)
-            control.setAttribute(QtCore.Qt.WA_LayoutUsesWidgetRect, True)
+            control.setAttribute(QtCore.Qt.WidgetAttribute.WA_LayoutUsesWidgetRect, True)
 
             control.clicked.connect(mapper.map)
             mapper.setMapping(control, color_text)
@@ -296,7 +289,10 @@ def color_editor_for(editor, parent):
 
             i += 1
 
-    mapper.mapped[str].connect(editor.update_object_from_swatch)
+    if is_pyside and QtCore.__version_info__ >= (5, 15):
+        mapper.mappedString.connect(editor.update_object_from_swatch)
+    else:
+        mapper.mapped[str].connect(editor.update_object_from_swatch)
 
     panel.addLayout(grid)
 
