@@ -1,4 +1,4 @@
-# (C) Copyright 2008-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2008-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -23,35 +23,42 @@
 """ Trait definition for a PyQt-based color.
 """
 
+from ast import literal_eval
 
 from pyface.qt import QtGui
-
+from pyface.color import Color as PyfaceColor
+from pyface.util.color_helpers import channels_to_ints
+from pyface.util.color_parser import color_table
 from traits.api import Trait, TraitError
 
 
-
 def convert_to_color(object, name, value):
-    """ Converts a number into a QColor object.
-    """
+    """Converts a number into a QColor object."""
     # Try the toolkit agnostic format.
     try:
-        tup = eval(value)
-    except:
+        tup = literal_eval(value)
+    except Exception:
         tup = value
 
+    if isinstance(value, str):
+        # Allow for spaces in the string value.
+        value = value.replace(" ", "")
+
+        # is it in the color table?
+        if value in color_table:
+            tup = channels_to_ints(color_table[value])
+
     if isinstance(tup, tuple):
-        if 3 <= len(tup) <= 4:
+        if 3 <= len(tup) <= 4 and all(isinstance(x, int) for x in tup):
             try:
                 color = QtGui.QColor(*tup)
-            except TypeError:
+            except Exception:
                 raise TraitError
         else:
             raise TraitError
+    elif isinstance(value, PyfaceColor):
+        color = value.to_toolkit()
     else:
-        if isinstance(value, str):
-            # Allow for spaces in the string value.
-            value = value.replace(" ", "")
-
         # Let the standard ctors handle the value.
         try:
             color = QtGui.QColor(value)
@@ -76,12 +83,10 @@ convert_to_color.info = (
 #  Standard colors:
 # -------------------------------------------------------------------------
 
-# Note that this is slightly different from the wx implementation in that the
-# names do not include spaces and the full set of SVG color keywords is
-# supported.
 standard_colors = {}
-for name in QtGui.QColor.colorNames():
-    standard_colors[str(name)] = QtGui.QColor(name)
+for name, rgba in color_table.items():
+    rgba_bytes = channels_to_ints(rgba)
+    standard_colors[str(name)] = QtGui.QColor(*rgba_bytes)
 
 # -------------------------------------------------------------------------
 #  Callable that returns an instance of the PyQtToolkitEditorFactory for color
@@ -101,8 +106,7 @@ def get_color_editor(*args, **traits):
 
 
 def PyQtColor(default="white", allow_none=False, **metadata):
-    """ Defines PyQt-specific color traits.
-    """
+    """Defines PyQt-specific color traits."""
     if default is None:
         allow_none = True
 
@@ -113,7 +117,7 @@ def PyQtColor(default="white", allow_none=False, **metadata):
             standard_colors,
             convert_to_color,
             editor=get_color_editor,
-            **metadata
+            **metadata,
         )
 
     return Trait(
@@ -121,5 +125,5 @@ def PyQtColor(default="white", allow_none=False, **metadata):
         standard_colors,
         convert_to_color,
         editor=get_color_editor,
-        **metadata
+        **metadata,
     )
