@@ -1,25 +1,17 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2009, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Evan Patterson
-#  Date:   08/03/2009
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ A Traits UI editor for datetime.date objects.
 """
 
 
-
 import datetime
 
 from pyface.qt import QtCore, QtGui
@@ -30,15 +22,12 @@ from .editor_factory import ReadonlyEditor as BaseReadonlyEditor
 from traitsui.editors.date_editor import CellFormat
 
 
-
-
 class SimpleEditor(Editor):
-    """ Simple Traits UI date editor that wraps QDateEdit.
-    """
+    """Simple Traits UI date editor that wraps QDateEdit."""
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         self.control = QtGui.QDateEdit()
         if hasattr(self.factory, "qt_date_format"):
@@ -77,9 +66,15 @@ class SimpleEditor(Editor):
 
         self.control.dateChanged.connect(self.update_object)
 
+    def dispose(self):
+        """Disposes of the contents of an editor."""
+        if self.control is not None:
+            self.control.dateChanged.disconnect(self.update_object)
+        super().dispose()
+
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         value = self.value
         if value:
@@ -87,14 +82,12 @@ class SimpleEditor(Editor):
             self.control.setDate(q_date)
 
     def update_object(self, q_date):
-        """ Handles the user entering input data in the edit control.
-        """
+        """Handles the user entering input data in the edit control."""
         self.value = datetime.date(q_date.year(), q_date.month(), q_date.day())
 
 
 class CustomEditor(Editor):
-    """ Custom Traits UI date editor that wraps QCalendarWidget.
-    """
+    """Custom Traits UI date editor that wraps QCalendarWidget."""
 
     #: Style used for when a date is unselected.
     #: Mapping from datetime.date to CellFormat
@@ -104,8 +97,8 @@ class CustomEditor(Editor):
     _selected = Set(Date)
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         self.control = QtGui.QCalendarWidget()
 
@@ -114,9 +107,15 @@ class CustomEditor(Editor):
 
         self.control.clicked.connect(self.update_object)
 
+    def dispose(self):
+        """Disposes of the contents of an editor."""
+        if self.control is not None:
+            self.control.clicked.disconnect(self.update_object)
+        super().dispose()
+
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         value = self.value
         if value:
@@ -130,8 +129,7 @@ class CustomEditor(Editor):
                 self._selected = set(value)
 
     def update_object(self, q_date):
-        """ Handles the user entering input data in the edit control.
-        """
+        """Handles the user entering input data in the edit control."""
         value = datetime.date(q_date.year(), q_date.month(), q_date.day())
         if self.factory.multi_select:
             if value in self.value:
@@ -153,7 +151,7 @@ class CustomEditor(Editor):
         self.apply_style(self.factory.selected_style, date)
 
     def set_unselected_style(self, style, date):
-        """ Set the style used for a date when it is not selected."""
+        """Set the style used for a date when it is not selected."""
         self._unselected_styles[date] = style
         if self.factory.multi_select:
             if date not in self.value:
@@ -162,14 +160,14 @@ class CustomEditor(Editor):
             self.apply_style(style, date)
 
     def apply_style(self, style, date):
-        """ Apply a given style to a given date."""
+        """Apply a given style to a given date."""
         qdt = QtCore.QDate(date)
         textformat = self.control.dateTextFormat(qdt)
         _apply_cellformat(style, textformat)
         self.control.setDateTextFormat(qdt, textformat)
 
     def apply_unselected_style(self, date):
-        """ Apply the style for when a date is unselected."""
+        """Apply the style for when a date is unselected."""
         # Resets the text format on the given dates
         textformat = QtGui.QTextCharFormat()
         if date in self._unselected_styles:
@@ -178,8 +176,7 @@ class CustomEditor(Editor):
         self.control.setDateTextFormat(qdt, textformat)
 
     def apply_unselected_style_to_all(self):
-        """ Make all the selected dates appear unselected.
-        """
+        """Make all the selected dates appear unselected."""
         for date in self._selected:
             self.apply_unselected_style(date)
 
@@ -190,12 +187,10 @@ class CustomEditor(Editor):
 
 
 class ReadonlyEditor(BaseReadonlyEditor):
-    """ Readonly Traits UI date editor that uses a QLabel for the view.
-    """
+    """Readonly Traits UI date editor that uses a QLabel for the view."""
 
     def _get_str_value(self):
-        """ Replace the default string value with our own date verision.
-        """
+        """Replace the default string value with our own date verision."""
         if not self.value:
             return self.factory.message
         else:
@@ -208,7 +203,7 @@ class ReadonlyEditor(BaseReadonlyEditor):
 
 
 def _apply_cellformat(cf, textformat):
-    """ Applies the formatting in the cellformat cf to the QTextCharFormat
+    """Applies the formatting in the cellformat cf to the QTextCharFormat
     object provided.
     """
     if cf.italics is not None:
@@ -219,9 +214,9 @@ def _apply_cellformat(cf, textformat):
 
     if cf.bold is not None:
         if cf.bold:
-            weight = QtGui.QFont.Bold
+            weight = QtGui.QFont.Weight.Bold
         else:
-            weight = QtGui.QFont.Normal
+            weight = QtGui.QFont.Weight.Normal
         textformat.setFontWeight(weight)
 
     if cf.bgcolor is not None:
@@ -232,20 +227,20 @@ def _apply_cellformat(cf, textformat):
 
 
 def _textformat_to_cellformat(textformat):
-    """ Convert QTextCharFormat to a CellFormat """
+    """Convert QTextCharFormat to a CellFormat"""
     bg_brush = textformat.background()
     fg_brush = textformat.foreground()
     return CellFormat(
         italics=textformat.fontItalic(),
         underline=textformat.fontUnderline(),
-        bold=textformat.fontWeight() == QtGui.QFont.Bold,
+        bold=textformat.fontWeight() == QtGui.QFont.Weight.Bold,
         bgcolor=_brush_to_color(bg_brush),
         fgcolor=_brush_to_color(fg_brush),
     )
 
 
 def _color_to_brush(color):
-    """ Returns a QBrush with the color specified in **color** """
+    """Returns a QBrush with the color specified in **color**"""
     brush = QtGui.QBrush()
     if isinstance(color, str) and hasattr(QtCore.Qt, color):
         col = getattr(QtCore.Qt, color)
