@@ -1,3 +1,12 @@
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 import datetime
 
@@ -9,17 +18,16 @@ from traits.api import Dict
 from .date_editor import CustomEditor as DateCustomEditor
 
 
-
 class CustomEditor(DateCustomEditor):
     def init(self, parent):
         if not self.factory.multi_select:
             raise ValueError("multi_select must be true.")
 
-        super(CustomEditor, self).init(parent)
+        super().init(parent)
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         start_date, end_date = self.value
         if start_date is not None and end_date is not None:
@@ -33,8 +41,7 @@ class CustomEditor(DateCustomEditor):
             )
 
     def update_object(self, q_date):
-        """ Handles the user entering input data in the edit control.
-        """
+        """Handles the user entering input data in the edit control."""
         value = datetime.date(q_date.year(), q_date.month(), q_date.day())
         start_date, end_date = self.value
 
