@@ -1,4 +1,4 @@
-# (C) Copyright 2008-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2008-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -20,7 +20,7 @@
 """ Defines various directory editor for the PyQt user interface toolkit.
 """
 
-from pyface.qt import QtGui
+from pyface.api import DirectoryDialog
 
 from .file_editor import (
     SimpleEditor as SimpleFileEditor,
@@ -28,26 +28,24 @@ from .file_editor import (
 )
 
 
-
 class SimpleEditor(SimpleFileEditor):
-    """ Simple style of editor for directories, which displays a text field
-        and a **Browse** button that opens a directory-selection dialog box.
+    """Simple style of editor for directories, which displays a text field
+    and a **Browse** button that opens a directory-selection dialog box.
     """
 
     def _create_file_dialog(self):
-        """ Creates the correct type of file dialog.
-        """
-        dlg = QtGui.QFileDialog(self.control)
-        dlg.selectFile(self._file_name.text())
-        dlg.setFileMode(QtGui.QFileDialog.Directory)
-        dlg.setOptions(QtGui.QFileDialog.ShowDirsOnly)
+        """Creates the correct type of file dialog."""
 
+        dlg = DirectoryDialog(
+            parent=self.get_control_widget(),
+            default_path=self._file_name.text(),
+        )
         return dlg
 
 
 class CustomEditor(CustomFileEditor):
-    """ Custom style of editor for directories, which displays a tree view of
-        the file system.
+    """Custom style of editor for directories, which displays a tree view of
+    the file system.
     """
 
     def init(self, parent):
@@ -56,8 +54,7 @@ class CustomEditor(CustomFileEditor):
         self._model.setNameFilters([""])
 
     def update_object(self, idx):
-        """ Handles the user changing the contents of the edit control.
-        """
+        """Handles the user changing the contents of the edit control."""
         if self.control is not None:
             if self._model.isDir(idx):
                 self.value = str(self._model.filePath(idx))
@@ -65,7 +62,6 @@ class CustomEditor(CustomFileEditor):
     # Trait change handlers --------------------------------------------------
 
     def _filter_changed(self):
-        """ Handles the 'filter' trait being changed.
-        """
+        """Handles the 'filter' trait being changed."""
         # name filters don't apply to directories
         pass
