@@ -1,3 +1,13 @@
+# (C) Copyright 2008-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
@@ -19,40 +29,19 @@ from pyface.qt import QtCore, QtGui
 
 from traits.api import TraitError
 
-from traitsui.editor_factory import EditorFactory as BaseEditorFactory
-
 from .editor import Editor
 
 
-# -------------------------------------------------------------------------
-#  'EditorFactory' class
-#   Deprecated alias for traitsui.editor_factory.EditorFactory
-# -------------------------------------------------------------------------
-
-
-class EditorFactory(BaseEditorFactory):
-    """ Deprecated alias for traitsui.editor_factory.EditorFactory.
-    """
-
-    def __init__(self, *args, **kwds):
-        super(EditorFactory, self).__init__(*args, **kwds)
-        warnings.warn(
-            "DEPRECATED: Use traitsui.editor_factory."
-            ".EditorFactory instead.",
-            DeprecationWarning,
-        )
-
-
 class SimpleEditor(Editor):
-    """ Base class for simple style editors, which displays a text field
+    """Base class for simple style editors, which displays a text field
     containing the text representation of the object trait value. Clicking in
     the text field displays an editor-specific dialog box for changing the
     value.
     """
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         self.control = _SimpleField(self)
         self.set_tooltip()
@@ -64,34 +53,31 @@ class SimpleEditor(Editor):
     # -------------------------------------------------------------------------
 
     def popup_editor(self):
-        """ Invokes the pop-up editor for an object trait.
-        """
+        """Invokes the pop-up editor for an object trait."""
         pass
 
 
 class TextEditor(Editor):
-    """ Base class for text style editors, which displays an editable text
+    """Base class for text style editors, which displays an editable text
     field, containing a text representation of the object trait value.
     """
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         self.control = QtGui.QLineEdit(self.str_value)
         self.control.editingFinished.connect(self.update_object)
         self.set_tooltip()
 
     def dispose(self):
-        """ Disposes of the contents of an editor.
-        """
+        """Disposes of the contents of an editor."""
         if self.control is not None:
             self.control.editingFinished.disconnect(self.update_object)
-        super(TextEditor, self).dispose()
+        super().dispose()
 
     def update_object(self):
-        """ Handles the user changing the contents of the edit control.
-        """
+        """Handles the user changing the contents of the edit control."""
         if self.control is None:
             return
         try:
@@ -101,7 +87,7 @@ class TextEditor(Editor):
 
 
 class ReadonlyEditor(Editor):
-    """ Base class for read-only style editors, which displays a read-only text
+    """Base class for read-only style editors, which displays a read-only text
     field, containing a text representation of the object trait value.
     """
 
@@ -111,26 +97,23 @@ class ReadonlyEditor(Editor):
     # -------------------------------------------------------------------------
 
     text_alignment_map = {
-        "left": QtCore.Qt.AlignLeft,
-        "right": QtCore.Qt.AlignRight,
-        "just": QtCore.Qt.AlignJustify,
-        "top": QtCore.Qt.AlignLeft,
-        "bottom": QtCore.Qt.AlignBottom,
-        "vcenter": QtCore.Qt.AlignVCenter,
-        "hcenter": QtCore.Qt.AlignHCenter,
-        "center": QtCore.Qt.AlignVCenter | QtCore.Qt.AlignHCenter,
+        "left": QtCore.Qt.AlignmentFlag.AlignLeft,
+        "right": QtCore.Qt.AlignmentFlag.AlignRight,
+        "just": QtCore.Qt.AlignmentFlag.AlignJustify,
+        "top": QtCore.Qt.AlignmentFlag.AlignLeft,
+        "bottom": QtCore.Qt.AlignmentFlag.AlignBottom,
+        "vcenter": QtCore.Qt.AlignmentFlag.AlignVCenter,
+        "hcenter": QtCore.Qt.AlignmentFlag.AlignHCenter,
+        "center": QtCore.Qt.AlignmentFlag.AlignVCenter | QtCore.Qt.AlignmentFlag.AlignHCenter,
     }
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         self.control = QtGui.QLabel(self.str_value)
 
         if self.item.resizable is True or self.item.height != -1.0:
-            self.control.setSizePolicy(
-                QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding
-            )
             self.control.setWordWrap(True)
 
         alignment = None
@@ -148,8 +131,8 @@ class ReadonlyEditor(Editor):
         self.set_tooltip()
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         self.control.setText(self.str_value)
 
@@ -164,5 +147,5 @@ class _SimpleField(QtGui.QLineEdit):
     def mouseReleaseEvent(self, e):
         QtGui.QLineEdit.mouseReleaseEvent(self, e)
 
-        if e.button() == QtCore.Qt.LeftButton:
+        if e.button() == QtCore.Qt.MouseButton.LeftButton:
             self._editor.popup_editor()
