@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -10,14 +10,13 @@
 
 from pyface.qt import QtGui, QtCore
 
-from traits.api import Float, Any, Str, Either
+from traits.api import Float, Any, Str, Union
 
 from traitsui.editors.api import RangeEditor
 from traitsui.qt4.editor import Editor
 from traitsui.qt4.extra.range_slider import RangeSlider
 
 
-
 class _BoundsEditor(Editor):
 
     evaluate = Any()
@@ -29,8 +28,8 @@ class _BoundsEditor(Editor):
     format = Str()
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         factory = self.factory
         if not factory.low_name:
@@ -63,7 +62,7 @@ class _BoundsEditor(Editor):
         sh.setWidth(sh.width() // 2)
         self._label_lo.setMaximumSize(sh)
 
-        self.control.slider = slider = RangeSlider(QtCore.Qt.Horizontal)
+        self.control.slider = slider = RangeSlider(QtCore.Qt.Orientation.Horizontal)
         slider.setTracking(factory.auto_set)
         slider.setMinimum(0)
         slider.setMaximum(10000)
@@ -196,8 +195,8 @@ class _BoundsEditor(Editor):
 
 class BoundsEditor(RangeEditor):
 
-    min = Either(None, Float)
-    max = Either(None, Float)
+    min = Union(None, Float)
+    max = Union(None, Float)
 
     def _get_simple_editor_class(self):
         return _BoundsEditor
