@@ -1,15 +1,12 @@
-# ------------------------------------------------------------------------------
-# Copyright (c) 2011, Enthought, Inc.
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Evan Patterson
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines a Traits UI View that allows for the customization of Qt-specific
     widget properties.
@@ -31,7 +28,9 @@ logger = logging.getLogger(__name__)
 
 
 class QtView(View):
-    """ A View that allows the specification of Qt style sheets.
+    """A View that allows the specification of Qt style sheets.
+
+    This works with any non-modal View.
     """
 
     #: An optional string containing a Qt style sheet.
@@ -60,10 +59,13 @@ class QtView(View):
         scrollable=None,
         args=None,
     ):
-        ui = super(QtView, self).ui(
+        ui = super().ui(
             context, parent, kind, view_elements, handler, id, scrollable, args
         )
 
+        if not ui.control:
+            return ui
+
         if self.style_sheet:
             ui.control.setStyleSheet(self.style_sheet)
 
