@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -12,14 +12,14 @@ from pyface.qt import QtGui, QtCore
 
 
 class RangeSlider(QtGui.QSlider):
-    """ A slider for ranges.
+    """A slider for ranges.
 
-        This class provides a dual-slider for ranges, where there is a defined
-        maximum and minimum, as is a normal slider, but instead of having a
-        single slider value, there are 2 slider values.
+    This class provides a dual-slider for ranges, where there is a defined
+    maximum and minimum, as is a normal slider, but instead of having a
+    single slider value, there are 2 slider values.
 
-        This class emits the same signals as the QSlider base class, with the
-        exception of valueChanged
+    This class emits the same signals as the QSlider base class, with the
+    exception of valueChanged
     """
 
     def __init__(self, *args):
@@ -28,8 +28,8 @@ class RangeSlider(QtGui.QSlider):
         self._low = self.minimum()
         self._high = self.maximum()
 
-        self.pressed_control = QtGui.QStyle.SC_None
-        self.hover_control = QtGui.QStyle.SC_None
+        self.pressed_control = QtGui.QStyle.SubControl.SC_None
+        self.hover_control = QtGui.QStyle.SubControl.SC_None
         self.click_offset = 0
 
         # 0 for the low, 1 for the high, -1 for both
@@ -74,14 +74,14 @@ class RangeSlider(QtGui.QSlider):
 
             if self.pressed_control:
                 opt.activeSubControls = self.pressed_control
-                opt.state |= QtGui.QStyle.State_Sunken
+                opt.state |= QtGui.QStyle.StateFlag.State_Sunken
             else:
                 opt.activeSubControls = self.hover_control
 
             opt.sliderPosition = value
             opt.sliderValue = value
             style.drawComplexControl(
-                QtGui.QStyle.CC_Slider, opt, painter, self
+                QtGui.QStyle.ComplexControl.CC_Slider, opt, painter, self
             )
 
     def mousePressEvent(self, event):
@@ -164,7 +164,7 @@ class RangeSlider(QtGui.QSlider):
         self.sliderMoved.emit(new_pos)
 
     def __pick(self, pt):
-        if self.orientation() == QtCore.Qt.Horizontal:
+        if self.orientation() == QtCore.Qt.Orientation.Horizontal:
             return pt.x()
         else:
             return pt.y()
@@ -181,7 +181,7 @@ class RangeSlider(QtGui.QSlider):
             style.CC_Slider, opt, style.SC_SliderHandle, self
         )
 
-        if self.orientation() == QtCore.Qt.Horizontal:
+        if self.orientation() == QtCore.Qt.Orientation.Horizontal:
             slider_length = sr.width()
             slider_min = gr.x()
             slider_max = gr.right() - slider_length + 1
