@@ -1,4 +1,4 @@
-# (C) Copyright 2008-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2008-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -26,17 +26,14 @@
 
 import os.path
 
-from pyface.qt import QtCore, QtGui, is_qt5, qt_api
+from pyface.api import SystemMetrics
+from pyface.qt import QtCore, QtGui, is_qt5, is_pyqt
 from pyface.ui_traits import convert_image
 from traits.api import Enum, CTrait, BaseTraitHandler, TraitError
 
 from traitsui.ui_traits import SequenceTypes
 
 
-
-is_pyqt = qt_api in {"pyqt", "pyqt5"}
-
-
 #: Layout orientation for a control and its associated editor
 Orientation = Enum("horizontal", "vertical")
 
@@ -45,7 +42,7 @@ DockStyle = Enum("horizontal", "vertical", "tab", "fixed")
 
 
 def pixmap_cache(name, path=None):
-    """ Convert an image file name to a cached QPixmap
+    """Convert an image file name to a cached QPixmap
 
     Returns the QPixmap corresponding to a filename. If the filename does not
     contain a path component, 'path' is used (or if 'path' is not specified,
@@ -81,13 +78,13 @@ def pixmap_cache(name, path=None):
 
 
 def position_window(window, width=None, height=None, parent=None):
-    """ Positions a window on the screen with a specified width and height so
-        that the window completely fits on the screen if possible.
+    """Positions a window on the screen with a specified width and height so
+    that the window completely fits on the screen if possible.
     """
     # Get the available geometry of the screen containing the window.
-    sgeom = QtGui.QApplication.desktop().availableGeometry(window)
-    screen_dx = sgeom.width()
-    screen_dy = sgeom.height()
+    system_metrics = SystemMetrics()
+    screen_dx = system_metrics.screen_width
+    screen_dy = system_metrics.screen_height
 
     # Use the frame geometry even though it is very unlikely that the X11 frame
     # exists at this point.
@@ -100,7 +97,7 @@ def position_window(window, width=None, height=None, parent=None):
 
     if parent is None:
         # Center the popup on the screen.
-        window.move((screen_dx - width) / 2, (screen_dy - height) / 2)
+        window.move((screen_dx - width) // 2, (screen_dy - height) // 2)
         return
 
     # Calculate the desired size of the popup control:
@@ -133,28 +130,26 @@ def position_window(window, width=None, height=None, parent=None):
 
 
 def restore_window(ui):
-    """ Restores the user preference items for a specified UI.
-    """
+    """Restores the user preference items for a specified UI."""
     prefs = ui.restore_prefs()
     if prefs is not None:
         ui.control.setGeometry(*prefs)
 
 
 def save_window(ui):
-    """ Saves the user preference items for a specified UI.
-    """
+    """Saves the user preference items for a specified UI."""
     geom = ui.control.geometry()
     ui.save_prefs((geom.x(), geom.y(), geom.width(), geom.height()))
 
 
 class IconButton(QtGui.QPushButton):
-    """ The IconButton class is a push button that contains a small image or a
-        standard icon provided by the current style.
+    """The IconButton class is a push button that contains a small image or a
+    standard icon provided by the current style.
     """
 
     def __init__(self, icon, slot):
-        """ Initialise the button.  icon is either the name of an image file or
-            one of the QtGui.QStyle.SP_* values.
+        """Initialise the button.  icon is either the name of an image file or
+        one of the QtGui.QStyle.SP_* values.
         """
         QtGui.QPushButton.__init__(self)
 
@@ -162,7 +157,7 @@ class IconButton(QtGui.QPushButton):
         sty = QtGui.QApplication.instance().style()
 
         # Get the minimum icon size to use.
-        ico_sz = sty.pixelMetric(QtGui.QStyle.PM_ButtonIconSize)
+        ico_sz = sty.pixelMetric(QtGui.QStyle.PixelMetric.PM_ButtonIconSize)
 
         if isinstance(icon, str):
             pm = pixmap_cache(icon)
@@ -184,12 +179,12 @@ class IconButton(QtGui.QPushButton):
         # Configure the button.
         self.setIcon(ico)
         self.setFlat(True)
-        self.setFocusPolicy(QtCore.Qt.NoFocus)
+        self.setFocusPolicy(QtCore.Qt.FocusPolicy.NoFocus)
 
         self.clicked.connect(slot)
 
     def sizeHint(self):
-        """ Reimplement sizeHint to return a recommended button size based on
+        """Reimplement sizeHint to return a recommended button size based on
         the size of the icon.
 
         Returns
@@ -203,17 +198,18 @@ class IconButton(QtGui.QPushButton):
         option = QtGui.QStyleOptionButton()
         self.initStyleOption(option)
         size = self.style().sizeFromContents(
-            QtGui.QStyle.CT_ToolButton, option, option.iconSize
+            QtGui.QStyle.ContentsType.CT_ToolButton, option, option.iconSize
         )
         return size
 
+
 # ------------------------------------------------------------------------
 # Text Rendering helpers
 # ------------------------------------------------------------------------
 
 
 def wrap_text_with_elision(text, font, width, height):
-    """ Wrap paragraphs to fit inside a given size, eliding if too long.
+    """Wrap paragraphs to fit inside a given size, eliding if too long.
 
     Parameters
     ----------
@@ -246,7 +242,7 @@ def wrap_text_with_elision(text, font, width, height):
             line = text_layout.createLine()
             if not line.isValid():
                 break
-            line.setLineWidth(width)
+            line.setLineWidth(int(width))
             line_start = line.textStart()
             line_end = line_start + line.textLength()
             line_text = paragraph[line_start:line_end].rstrip()
@@ -259,7 +255,7 @@ def wrap_text_with_elision(text, font, width, height):
         # elide last line as we ran out of room
         last_line = paragraph[line_start:]
         lines[-1] = font_metrics.elidedText(
-            last_line, QtCore.Qt.ElideRight, width
+            last_line, QtCore.Qt.TextElideMode.ElideRight, width
         )
 
     return lines
