@@ -1,4 +1,4 @@
-# (C) Copyright 2008-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2008-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -28,6 +28,7 @@ key binding editor).
 
 from pyface.qt import QtCore, QtGui
 
+from pyface.api import YES, confirm
 from traits.api import Bool, Event
 
 from .editor import Editor
@@ -36,8 +37,7 @@ from .key_event_to_name import key_event_to_name
 
 
 class KeyBindingEditor(Editor):
-    """ An editor for modifying bindings of keys to controls.
-    """
+    """An editor for modifying bindings of keys to controls."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -53,77 +53,58 @@ class KeyBindingEditor(Editor):
     clear = Event()
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         self.control = KeyBindingCtrl(self)
 
-    def update_object(self, event):
-        """ Handles the user entering input data in the edit control.
-        """
-        try:
-            self.value = value = key_event_to_name(event)
-            self._binding.text = value
-        except:
-            pass
-
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         self.control.setText(self.value)
 
-    def update_focus(self, has_focus):
-        """ Updates the current focus setting of the control.
-        """
-        if has_focus:
-            self._binding.border_size = 1
-            self.object.owner.focus_owner = self._binding
-
     def _key_changed(self, event):
-        """ Handles a keyboard event.
-        """
+        """Handles a keyboard event."""
         binding = self.object
         key_name = key_event_to_name(event)
-        cur_binding = binding.owner.key_binding_for(binding, key_name)
+        cur_binding = self.ui.parent.handler.key_binding_for(binding, key_name)
         if cur_binding is not None:
-            if (
-                QtGui.QMessageBox.question(
-                    self.control,
-                    "Duplicate Key Definition",
-                    "'%s' has already been assigned to '%s'.\n"
+            result = confirm(
+                parent=self.control,
+                message=(
+                    f"{key_name!r} has already been assigned to "
+                    f"'{cur_binding.description}'.\n"
                     "Do you wish to continue?"
-                    % (key_name, cur_binding.description),
-                    QtGui.QMessageBox.Yes | QtGui.QMessageBox.No,
-                    QtGui.QMessageBox.No,
-                )
-                != QtGui.QMessageBox.Yes
-            ):
+                ),
+                title="Duplicate Key Definition",
+            )
+            if result != YES:
                 return
 
         self.value = key_name
+        # Need to manually update editor because the update to the value
+        # won't get transferred to toolkit object due to loopback protection.
+        self.update_editor()
 
     def _clear_changed(self):
-        """ Handles a clear field event.
-        """
+        """Handles a clear field event."""
         self.value = ""
+        # Need to manually update editor because the update to the value
+        # won't get transferred to toolkit object due to loopback protection.
+        self.update_editor()
 
 
-class KeyBindingCtrl(QtGui.QLabel):
-    """ PyQt control for editing key bindings.
-    """
+class KeyBindingCtrl(QtGui.QLineEdit):
+    """PyQt control for editing key bindings."""
 
     def __init__(self, editor, parent=None):
         super().__init__(parent)
 
-        self.setFocusPolicy(QtCore.Qt.StrongFocus)
-        self.setIndent(4)
+        self.setFocusPolicy(QtCore.Qt.FocusPolicy.StrongFocus)
         self.setMinimumWidth(160)
-
-        pal = QtGui.QPalette(self.palette())
-        pal.setColor(QtGui.QPalette.Window, QtCore.Qt.white)
-        self.setPalette(pal)
-        self.setAutoFillBackground(True)
+        self.setMaximumWidth(160)
+        self.setReadOnly(True)
 
         # Save the reference to the controlling editor object:
         self.editor = editor
@@ -132,46 +113,38 @@ class KeyBindingCtrl(QtGui.QLabel):
         editor.has_focus = False
 
     def keyPressEvent(self, event):
-        """ Handle keyboard keys being pressed.
-        """
+        """Handle keyboard keys being pressed."""
         # Ignore presses of the control and shift keys.
-        if event.key() not in (QtCore.Qt.Key_Control, QtCore.Qt.Key_Shift):
+        if event.key() not in (QtCore.Qt.Key.Key_Control, QtCore.Qt.Key.Key_Shift):
             self.editor.key = event
 
     def paintEvent(self, event):
-        """ Updates the screen.
-        """
-        QtGui.QLabel.paintEvent(self, event)
-
-        w = self.width()
-        h = self.height()
-        p = QtGui.QPainter(self)
+        """Updates the screen."""
+        super().paintEvent(event)
 
         if self.editor.has_focus:
-            p.setRenderHint(QtGui.QPainter.Antialiasing, True)
+            w = self.width()
+            h = self.height()
+            p = QtGui.QPainter(self)
+
+            p.setRenderHint(QtGui.QPainter.RenderHint.Antialiasing, True)
             pen = QtGui.QPen(QtGui.QColor("tomato"))
             pen.setWidth(2)
             p.setPen(pen)
             p.drawRect(1, 1, w - 2, h - 2)
-        else:
-            p.setPen(self.palette().color(QtGui.QPalette.Mid))
-            p.drawRect(0, 0, w - 1, h - 1)
 
-        p.end()
+            p.end()
 
     def focusInEvent(self, event):
-        """ Handles getting the focus.
-        """
+        """Handles getting the focus."""
         self.editor.has_focus = True
         self.update()
 
     def focusOutEvent(self, event):
-        """ Handles losing the focus.
-        """
+        """Handles losing the focus."""
         self.editor.has_focus = False
         self.update()
 
     def mouseDoubleClickEvent(self, event):
-        """ Handles the user double clicking the control to clear its contents.
-        """
+        """Handles the user double clicking the control to clear its contents."""
         self.editor.clear = True
