@@ -1,31 +1,25 @@
-# -------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2009, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Evan Patterson
-#  Date:   08/05/2009
-#
-# -------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Traits UI editor for editing lists of strings.
 """
 
-
-from pyface.qt import QtCore, QtGui, is_qt5
-import collections
+import collections.abc
 
 from pyface.image_resource import ImageResource
+from pyface.qt import QtCore, QtGui, is_qt4
+
 from traits.api import (
     Any,
     Bool,
+    Dict,
     Event,
     Int,
     Instance,
@@ -43,8 +37,7 @@ from traitsui.menu import Menu
 
 
 class _ListStrEditor(Editor):
-    """ Traits UI editor for editing lists of strings.
-    """
+    """Traits UI editor for editing lists of strings."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -88,10 +81,10 @@ class _ListStrEditor(Editor):
     adapter = Instance(ListStrAdapter)
 
     #: Dictionary mapping image names to QIcons
-    images = Any({})
+    images = Dict()
 
     #: Dictionary mapping ImageResource objects to QIcons
-    image_resources = Any({})
+    image_resources = Dict()
 
     #: The current number of item currently in the list:
     item_count = Property()
@@ -104,8 +97,8 @@ class _ListStrEditor(Editor):
     # -------------------------------------------------------------------------
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         factory = self.factory
 
@@ -122,14 +115,17 @@ class _ListStrEditor(Editor):
         layout.setSpacing(0)
 
         if factory.title or factory.title_name:
-            header_view = QtGui.QHeaderView(QtCore.Qt.Horizontal, self.control)
+            header_view = QtGui.QHeaderView(QtCore.Qt.Orientation.Horizontal, self.control)
+            self._header_view = header_view
             header_view.setModel(self.model)
             header_view.setMaximumHeight(header_view.sizeHint().height())
-            if is_qt5:
-                header_view.setSectionResizeMode(QtGui.QHeaderView.Stretch)
+            if is_qt4:
+                header_view.setResizeMode(QtGui.QHeaderView.ResizeMode.Stretch)
             else:
-                header_view.setResizeMode(QtGui.QHeaderView.Stretch)
+                header_view.setSectionResizeMode(QtGui.QHeaderView.ResizeMode.Stretch)
             layout.addWidget(header_view)
+        else:
+            self._header_view = None
 
         self.list_view = _ListView(self)
         layout.addWidget(self.list_view)
@@ -174,8 +170,8 @@ class _ListStrEditor(Editor):
 
         # Make sure we listen for 'items' changes as well as complete list
         # replacements:
-        self.context_object.on_trait_change(
-            self.update_editor, self.extended_name + "_items", dispatch="ui"
+        self.context_object.observe(
+            self.update_editor, self.extended_name + ".items", dispatch="ui"
         )
 
         # Create the mapping from user supplied images to QIcons:
@@ -183,29 +179,37 @@ class _ListStrEditor(Editor):
             self._add_image(image_resource)
 
         # Refresh the editor whenever the adapter changes:
-        self.on_trait_change(
-            self.refresh_editor, "adapter.+update", dispatch="ui"
-        )
+        self.observe(self.refresh_editor, "adapter.+update", dispatch="ui")
 
         # Set the list control's tooltip:
         self.set_tooltip()
 
     def dispose(self):
-        """ Disposes of the contents of an editor.
-        """
-        self.context_object.on_trait_change(
-            self.update_editor, self.extended_name + "_items", remove=True
+        """Disposes of the contents of an editor."""
+        self.model.beginResetModel()
+        self.model.endResetModel()
+        self.context_object.observe(
+            self.update_editor,
+            self.extended_name + ".items",
+            remove=True,
+            dispatch="ui",
         )
 
-        self.on_trait_change(
-            self.refresh_editor, "adapter.+update", remove=True
+        self.observe(
+            self.refresh_editor, "adapter.+update", remove=True, dispatch="ui"
         )
+        if self._header_view is not None:
+            self._header_view.setModel(None)
+            self._header_view.deleteLater()
+            self._header_view = None
 
-        super(Editor, self).dispose()
+        self.list_view._dispose()
 
-    def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        super().dispose()
+
+    def update_editor(self, event=None):
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         if not self._no_update:
             self.model.beginResetModel()
@@ -220,14 +224,12 @@ class _ListStrEditor(Editor):
     #  ListStrEditor interface:
     # -------------------------------------------------------------------------
 
-    def refresh_editor(self):
-        """ Requests that the underlying list widget to redraw itself.
-        """
+    def refresh_editor(self, event=None):
+        """Requests that the underlying list widget to redraw itself."""
         self.list_view.viewport().update()
 
     def callx(self, func, *args, **kw):
-        """ Call a function without allowing the editor to update.
-        """
+        """Call a function without allowing the editor to update."""
         old = self._no_update
         self._no_update = True
         try:
@@ -236,8 +238,7 @@ class _ListStrEditor(Editor):
             self._no_update = old
 
     def setx(self, **keywords):
-        """ Set one or more attributes without allowing the editor to update.
-        """
+        """Set one or more attributes without allowing the editor to update."""
         old = self._no_notify
         self._no_notify = True
         try:
@@ -247,8 +248,7 @@ class _ListStrEditor(Editor):
             self._no_notify = old
 
     def get_image(self, image):
-        """ Converts a user specified image to a QIcon.
-        """
+        """Converts a user specified image to a QIcon."""
         if isinstance(image, ImageResource):
             result = self.image_resources.get(image)
             if result is not None:
@@ -259,8 +259,8 @@ class _ListStrEditor(Editor):
         return self.images.get(image)
 
     def is_auto_add(self, index):
-        """ Returns whether or not the index is the special 'auto add' item at
-            the end of the list.
+        """Returns whether or not the index is the special 'auto add' item at
+        the end of the list.
         """
         return self.factory.auto_add and (
             index >= self.adapter.len(self.object, self.name)
@@ -271,8 +271,7 @@ class _ListStrEditor(Editor):
     # -------------------------------------------------------------------------
 
     def _add_image(self, image_resource):
-        """ Adds a new image to the image map.
-        """
+        """Adds a new image to the image map."""
         image = image_resource.create_icon()
 
         self.image_resources[image_resource] = image
@@ -288,8 +287,7 @@ class _ListStrEditor(Editor):
     # -- Trait Event Handlers -------------------------------------------------
 
     def _selected_changed(self, selected):
-        """ Handles the editor's 'selected' trait being changed.
-        """
+        """Handles the editor's 'selected' trait being changed."""
         if not self._no_update:
             try:
                 selected_index = self.value.index(selected)
@@ -299,20 +297,18 @@ class _ListStrEditor(Editor):
                 self._selected_index_changed(selected_index)
 
     def _selected_index_changed(self, selected_index):
-        """ Handles the editor's 'selected_index' trait being changed.
-        """
+        """Handles the editor's 'selected_index' trait being changed."""
         if not self._no_update:
             smodel = self.list_view.selectionModel()
             if selected_index == -1:
                 smodel.clearSelection()
             else:
                 mi = self.model.index(selected_index)
-                smodel.select(mi, QtGui.QItemSelectionModel.ClearAndSelect)
+                smodel.select(mi, QtGui.QItemSelectionModel.SelectionFlag.ClearAndSelect)
                 self.list_view.scrollTo(mi)
 
     def _multi_selected_changed(self, selected):
-        """ Handles the editor's 'multi_selected' trait being changed.
-        """
+        """Handles the editor's 'multi_selected' trait being changed."""
         if not self._no_update:
             indices = []
             for item in selected:
@@ -323,8 +319,7 @@ class _ListStrEditor(Editor):
             self._multi_selected_indices_changed(indices)
 
     def _multi_selected_items_changed(self, event):
-        """ Handles the editor's 'multi_selected' trait being modified.
-        """
+        """Handles the editor's 'multi_selected' trait being modified."""
         if not self._no_update:
             try:
                 added = [self.value.index(item) for item in event.added]
@@ -332,50 +327,46 @@ class _ListStrEditor(Editor):
             except ValueError:
                 pass
             else:
-                event = TraitListEvent(0, added, removed)
+                event = TraitListEvent(index=0, added=added, removed=removed)
                 self._multi_selected_indices_items_changed(event)
 
     def _multi_selected_indices_changed(self, selected_indices):
-        """ Handles the editor's 'multi_selected_indices' trait being changed.
-        """
+        """Handles the editor's 'multi_selected_indices' trait being changed."""
         if not self._no_update:
             smodel = self.list_view.selectionModel()
             smodel.clearSelection()
             for selected_index in selected_indices:
                 smodel.select(
                     self.model.index(selected_index),
-                    QtGui.QItemSelectionModel.Select,
+                    QtGui.QItemSelectionModel.SelectionFlag.Select,
                 )
             if selected_indices:
                 self.list_view.scrollTo(self.model.index(selected_indices[-1]))
 
     def _multi_selected_indices_items_changed(self, event):
-        """ Handles the editor's 'multi_selected_indices' trait being modified.
-        """
+        """Handles the editor's 'multi_selected_indices' trait being modified."""
         if not self._no_update:
             smodel = self.list_view.selectionModel()
             for selected_index in event.removed:
                 smodel.select(
                     self.model.index(selected_index),
-                    QtGui.QItemSelectionModel.Deselect,
+                    QtGui.QItemSelectionModel.SelectionFlag.Deselect,
                 )
             for selected_index in event.added:
                 smodel.select(
                     self.model.index(selected_index),
-                    QtGui.QItemSelectionModel.Select,
+                    QtGui.QItemSelectionModel.SelectionFlag.Select,
                 )
 
     # -- List Control Event Handlers ------------------------------------------
 
     def _on_activate(self, mi):
-        """ Handle a cell being activated.
-        """
+        """Handle a cell being activated."""
         self.activated_index = index = mi.row()
         self.activated = self.adapter.get_item(self.object, self.name, index)
 
-    def _on_context_menu(self, point):
-        """ Handle a context menu request.
-        """
+    def _on_mouse_right_click(self, point):
+        """Handle a mouse right click event"""
         mi = self.list_view.indexAt(point)
         if mi.isValid():
             self.right_clicked_index = index = mi.row()
@@ -384,8 +375,7 @@ class _ListStrEditor(Editor):
             )
 
     def _on_row_selection(self, added, removed):
-        """ Handle the row selection being changed.
-        """
+        """Handle the row selection being changed."""
         self._no_update = True
         try:
             indices = self.list_view.selectionModel().selectedRows()
@@ -401,8 +391,7 @@ class _ListStrEditor(Editor):
             self._no_update = False
 
     def _on_rows_selection(self, added, removed):
-        """ Handle the rows selection being changed.
-        """
+        """Handle the rows selection being changed."""
         self._no_update = True
         try:
             indices = self.list_view.selectionModel().selectedRows()
@@ -422,7 +411,7 @@ class _ListStrEditor(Editor):
         if isinstance(menu, str):
             menu = getattr(self.object, menu, None)
 
-        if isinstance(menu, collections.Callable):
+        if isinstance(menu, collections.abc.Callable):
             menu = menu(index)
 
         if menu is not None:
@@ -448,23 +437,21 @@ class _ListStrEditor(Editor):
 
 
 class _ItemDelegate(QtGui.QStyledItemDelegate):
-    """ A QStyledItemDelegate which optionally draws horizontal gridlines.
-        (QListView does not support gridlines).
+    """A QStyledItemDelegate which optionally draws horizontal gridlines.
+    (QListView does not support gridlines).
     """
 
     def __init__(self, editor, parent=None):
-        """ Save the editor
-        """
+        """Save the editor"""
         QtGui.QStyledItemDelegate.__init__(self, parent)
         self._editor = editor
 
     def paint(self, painter, option, index):
-        """ Overrident to draw gridlines.
-        """
+        """Overrident to draw gridlines."""
         QtGui.QStyledItemDelegate.paint(self, painter, option, index)
         if self._editor.factory.horizontal_lines:
             painter.save()
-            painter.setPen(option.palette.color(QtGui.QPalette.Dark))
+            painter.setPen(option.palette.color(QtGui.QPalette.ColorRole.Dark))
             painter.drawLine(
                 option.rect.bottomLeft(), option.rect.bottomRight()
             )
@@ -472,12 +459,10 @@ class _ItemDelegate(QtGui.QStyledItemDelegate):
 
 
 class _ListView(QtGui.QListView):
-    """ A QListView configured to behave as expected by TraitsUI.
-    """
+    """A QListView configured to behave as expected by TraitsUI."""
 
     def __init__(self, editor):
-        """ Initialise the object.
-        """
+        """Initialise the object."""
         QtGui.QListView.__init__(self)
 
         self._editor = editor
@@ -487,38 +472,48 @@ class _ListView(QtGui.QListView):
 
         # Configure the selection behavior
         if factory.multi_select:
-            mode = QtGui.QAbstractItemView.ExtendedSelection
+            mode = QtGui.QAbstractItemView.SelectionMode.ExtendedSelection
         else:
-            mode = QtGui.QAbstractItemView.SingleSelection
+            mode = QtGui.QAbstractItemView.SelectionMode.SingleSelection
         self.setSelectionMode(mode)
 
         # Configure drag and drop behavior
         self.setDragEnabled(True)
         self.setDragDropOverwriteMode(True)
-        self.setDragDropMode(QtGui.QAbstractItemView.InternalMove)
+        self.setDragDropMode(QtGui.QAbstractItemView.DragDropMode.InternalMove)
         self.setDropIndicatorShown(True)
 
         if editor.factory.menu is False:
-            self.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
+            self.setContextMenuPolicy(QtCore.Qt.ContextMenuPolicy.NoContextMenu)
         elif editor.factory.menu is not False:
-            self.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+            self.setContextMenuPolicy(QtCore.Qt.ContextMenuPolicy.CustomContextMenu)
 
         self.customContextMenuRequested.connect(editor._on_context_menu)
 
         # Configure context menu behavior
-        self.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+        self.setContextMenuPolicy(QtCore.Qt.ContextMenuPolicy.CustomContextMenu)
+
+    def _dispose(self):
+        """Clean up states in this view."""
+        self.setModel(None)
+
+    def mouseReleaseEvent(self, event):
+        """Reimplemented to support listening to right clicked item."""
+        if event.button() == QtCore.Qt.MouseButton.RightButton:
+            event.accept()
+            self._editor._on_mouse_right_click(event.pos())
+        super().mouseReleaseEvent(event)
 
     def keyPressEvent(self, event):
-        """ Reimplemented to support edit, insert, and delete by keyboard.
-        """
+        """Reimplemented to support edit, insert, and delete by keyboard."""
         editor = self._editor
         factory = editor.factory
 
         # Note that setting 'EditKeyPressed' as an edit trigger does not work on
         # most platforms, which is why we do this here.
         if (
-            event.key() in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return)
-            and self.state() != QtGui.QAbstractItemView.EditingState
+            event.key() in (QtCore.Qt.Key.Key_Enter, QtCore.Qt.Key.Key_Return)
+            and self.state() != QtGui.QAbstractItemView.State.EditingState
             and factory.editable
             and "edit" in factory.operations
         ):
@@ -533,7 +528,7 @@ class _ListView(QtGui.QListView):
                 self.edit(editor.model.index(row))
 
         elif (
-            event.key() in (QtCore.Qt.Key_Backspace, QtCore.Qt.Key_Delete)
+            event.key() in (QtCore.Qt.Key.Key_Backspace, QtCore.Qt.Key.Key_Delete)
             and factory.editable
             and "delete" in factory.operations
         ):
@@ -558,7 +553,7 @@ class _ListView(QtGui.QListView):
                 )
 
         elif (
-            event.key() == QtCore.Qt.Key_Insert
+            event.key() == QtCore.Qt.Key.Key_Insert
             and factory.editable
             and "insert" in factory.operations
         ):
