@@ -1,3 +1,13 @@
+# (C) Copyright 2009-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # ------------------------------------------------------------------------------
 # Copyright (c) 2008, Riverbank Computing Limited
 # All rights reserved.
@@ -15,8 +25,7 @@
 """
 
 
-
-from pyface.qt import QtCore, QtGui, is_qt5
+from pyface.qt import QtCore, QtGui, is_qt4
 from pyface.image_resource import ImageResource
 from pyface.timer.api import do_later
 from pyface.ui_traits import Image
@@ -24,6 +33,7 @@ from traits.api import (
     Any,
     Bool,
     Button,
+    Dict,
     Event,
     List,
     HasTraits,
@@ -32,7 +42,7 @@ from traits.api import (
     Property,
     Str,
     cached_property,
-    on_trait_change,
+    observe,
 )
 
 from traitsui.api import (
@@ -60,23 +70,21 @@ from .editor import Editor
 from .table_model import TableModel, SortFilterTableModel
 
 
+if is_qt4:
 
-if is_qt5:
+    def set_qheader_section_resize_mode(header):
+        return header.setResizeMode
+
+else:
 
     def set_qheader_section_resize_mode(header):
         return header.setSectionResizeMode
 
 
-else:
-
-    def set_qheader_section_resize_mode(header):
-        return header.setResizeMode
-
-
 class TableEditor(Editor, BaseTableEditor):
-    """ Editor that presents data in a table. Optionally, tables can have
-        a set of filters that reduce the set of data displayed, according to
-        their criteria.
+    """Editor that presents data in a table. Optionally, tables can have
+    a set of filters that reduce the set of data displayed, according to
+    their criteria.
     """
 
     # -------------------------------------------------------------------------
@@ -108,9 +116,9 @@ class TableEditor(Editor, BaseTableEditor):
     selected = Any()
 
     #: The current selected row
-    selected_row = Property(Any, depends_on="selected")
+    selected_row = Property(Any, observe="selected")
 
-    selected_indices = Property(Any, depends_on="selected")
+    selected_indices = Property(Any, observe="selected")
 
     #: Current filter object (should be a TableFilter or callable or None):
     filter = Any()
@@ -150,10 +158,10 @@ class TableEditor(Editor, BaseTableEditor):
     auto_size = Bool(False)
 
     #: Dictionary mapping image names to QIcons
-    images = Any({})
+    images = Dict()
 
     #: Dictionary mapping ImageResource objects to QIcons
-    image_resources = Any({})
+    image_resources = Dict()
 
     #: An image being converted:
     image = Image
@@ -214,7 +222,7 @@ class TableEditor(Editor, BaseTableEditor):
         # the triangle indicating it is the sort index, even though no sorting
         # has actually been done. Sort here for UI/model consistency.
         if self.factory.sortable and not self.factory.reorderable:
-            self.model.sort(0, QtCore.Qt.AscendingOrder)
+            self.model.sort(0, QtCore.Qt.SortOrder.AscendingOrder)
 
         # Connect to the mode specific selection handler and select the first
         # row/column/cell. Do this before creating the edit_view to make sure
@@ -254,11 +262,11 @@ class TableEditor(Editor, BaseTableEditor):
             self.control = main_view
         else:
             if factory.orientation == "horizontal":
-                self.control = QtGui.QSplitter(QtCore.Qt.Horizontal)
+                self.control = QtGui.QSplitter(QtCore.Qt.Orientation.Horizontal)
             else:
-                self.control = QtGui.QSplitter(QtCore.Qt.Vertical)
+                self.control = QtGui.QSplitter(QtCore.Qt.Orientation.Vertical)
             self.control.setSizePolicy(
-                QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding
+                QtGui.QSizePolicy.Policy.Expanding, QtGui.QSizePolicy.Policy.Expanding
             )
             self.control.addWidget(main_view)
             self.control.setStretchFactor(0, 2)
@@ -326,7 +334,9 @@ class TableEditor(Editor, BaseTableEditor):
         self._update_columns()
 
     def dispose(self):
-        """ Disposes of the contents of an editor."""
+        """Disposes of the contents of an editor."""
+        self.model.beginResetModel()
+        self.model.endResetModel()
 
         # Make sure that the auxiliary UIs are properly disposed
         if self.toolbar_ui is not None:
@@ -350,7 +360,7 @@ class TableEditor(Editor, BaseTableEditor):
             self._update_columns, "columns_items", remove=True
         )
 
-        super(TableEditor, self).dispose()
+        super().dispose()
 
     def update_editor(self):
         """Updates the editor when the object trait changes externally to the
@@ -380,16 +390,15 @@ class TableEditor(Editor, BaseTableEditor):
             self.table_view.setUpdatesEnabled(True)
 
     def restore_prefs(self, prefs):
-        """ Restores any saved user preference information associated with the
-            editor.
+        """Restores any saved user preference information associated with the
+        editor.
         """
         header = self.table_view.horizontalHeader()
         if header is not None and "column_state" in prefs:
             header.restoreState(prefs["column_state"])
 
     def save_prefs(self):
-        """ Returns any user preference information associated with the editor.
-        """
+        """Returns any user preference information associated with the editor."""
         prefs = {}
         header = self.table_view.horizontalHeader()
         if header is not None:
@@ -456,7 +465,7 @@ class TableEditor(Editor, BaseTableEditor):
 
         mode = self.factory.selection_mode
         indexes = []
-        flags = QtGui.QItemSelectionModel.ClearAndSelect
+        flags = QtGui.QItemSelectionModel.SelectionFlag.ClearAndSelect
 
         # In the case of row or column selection, we need a dummy value for the
         # other dimension that has not been filtered.
@@ -465,7 +474,7 @@ class TableEditor(Editor, BaseTableEditor):
 
         # Selection mode is 'row' or 'rows'
         if mode.startswith("row"):
-            flags |= QtGui.QItemSelectionModel.Rows
+            flags |= QtGui.QItemSelectionModel.SelectionFlag.Rows
             items = self.items()
             for obj in objects:
                 try:
@@ -476,7 +485,7 @@ class TableEditor(Editor, BaseTableEditor):
 
         # Selection mode is 'column' or 'columns'
         elif mode.startswith("column"):
-            flags |= QtGui.QItemSelectionModel.Columns
+            flags |= QtGui.QItemSelectionModel.SelectionFlag.Columns
             for name in objects:
                 column = self._column_index_from_name(name)
                 if column != -1:
@@ -504,7 +513,7 @@ class TableEditor(Editor, BaseTableEditor):
             index = self.model.mapFromSource(index)
             if index.isValid():
                 smodel.setCurrentIndex(
-                    index, QtGui.QItemSelectionModel.NoUpdate
+                    index, QtGui.QItemSelectionModel.SelectionFlag.NoUpdate
                 )
                 selection.select(index, index)
 
@@ -563,8 +572,7 @@ class TableEditor(Editor, BaseTableEditor):
             self.filter_summary = "%i of %i items" % (len(fi), num_items)
 
     def _add_image(self, image_resource):
-        """ Adds a new image to the image map.
-        """
+        """Adds a new image to the image map."""
         image = image_resource.create_icon()
 
         self.image_resources[image_resource] = image
@@ -573,8 +581,7 @@ class TableEditor(Editor, BaseTableEditor):
         return image
 
     def _get_image(self, image):
-        """ Converts a user specified image to a QIcon.
-        """
+        """Converts a user specified image to a QIcon."""
         if isinstance(image, str):
             self.image = image
             image = self.image
@@ -679,8 +686,7 @@ class TableEditor(Editor, BaseTableEditor):
             self.set_selection(self.selected, notify=False)
 
     def _update_filter_changed(self):
-        """ The filter has changed internally.
-        """
+        """The filter has changed internally."""
         self._filter_changed(self.filter, self.filter)
 
     # -- Event Handlers -------------------------------------------------------
@@ -835,11 +841,10 @@ ReadonlyEditor = TableEditor
 
 
 class TableDelegate(QtGui.QStyledItemDelegate):
-    """ A QStyledItemDelegate which fetches Traits UI editors.
-    """
+    """A QStyledItemDelegate which fetches Traits UI editors."""
 
     def createEditor(self, parent, option, index):
-        """ Reimplemented to return the editor for a given index."""
+        """Reimplemented to return the editor for a given index."""
 
         model = index.model()
         index = model.mapToSource(index)
@@ -870,7 +875,7 @@ class TableDelegate(QtGui.QStyledItemDelegate):
         control.setParent(parent)
 
         # Required for QMouseEvents to propagate to the widget
-        control.setFocusPolicy(QtCore.Qt.StrongFocus)
+        control.setFocusPolicy(QtCore.Qt.FocusPolicy.StrongFocus)
 
         # The table view's background will shine through unless the editor
         # paints its own background
@@ -882,28 +887,27 @@ class TableDelegate(QtGui.QStyledItemDelegate):
         return control
 
     def updateEditorGeometry(self, editor, option, index):
-        """ Update the editor's geometry.
-        """
+        """Update the editor's geometry."""
         editor.setGeometry(option.rect)
 
     def paint(self, painter, option, index):
         self.initStyleOption(option, index)
 
-        if (option.state & QtGui.QStyle.State_Selected) and (
-            option.state & QtGui.QStyle.State_Active
+        if (option.state & QtGui.QStyle.StateFlag.State_Selected) and (
+            option.state & QtGui.QStyle.StateFlag.State_Active
         ):
             factory = self.parent()._editor.factory
             if factory.selection_bg_color is not None:
                 option.palette.setColor(
-                    QtGui.QPalette.Highlight, factory.selection_bg_color_
+                    QtGui.QPalette.ColorRole.Highlight, factory.selection_bg_color_
                 )
             if factory.selection_color is not None:
                 option.palette.setColor(
-                    QtGui.QPalette.HighlightedText, factory.selection_color_
+                    QtGui.QPalette.ColorRole.HighlightedText, factory.selection_color_
                 )
 
         QtGui.QApplication.style().drawControl(
-            QtGui.QStyle.CE_ItemViewItem, option, painter, None
+            QtGui.QStyle.ControlElement.CE_ItemViewItem, option, painter, None
         )
 
 
@@ -912,28 +916,28 @@ class TableView(QtGui.QTableView):
 
     _SELECTION_MAP = {
         "row": (
-            QtGui.QAbstractItemView.SelectRows,
-            QtGui.QAbstractItemView.SingleSelection,
+            QtGui.QAbstractItemView.SelectionBehavior.SelectRows,
+            QtGui.QAbstractItemView.SelectionMode.SingleSelection,
         ),
         "rows": (
-            QtGui.QAbstractItemView.SelectRows,
-            QtGui.QAbstractItemView.ExtendedSelection,
+            QtGui.QAbstractItemView.SelectionBehavior.SelectRows,
+            QtGui.QAbstractItemView.SelectionMode.ExtendedSelection,
         ),
         "column": (
-            QtGui.QAbstractItemView.SelectColumns,
-            QtGui.QAbstractItemView.SingleSelection,
+            QtGui.QAbstractItemView.SelectionBehavior.SelectColumns,
+            QtGui.QAbstractItemView.SelectionMode.SingleSelection,
         ),
         "columns": (
-            QtGui.QAbstractItemView.SelectColumns,
-            QtGui.QAbstractItemView.ExtendedSelection,
+            QtGui.QAbstractItemView.SelectionBehavior.SelectColumns,
+            QtGui.QAbstractItemView.SelectionMode.ExtendedSelection,
         ),
         "cell": (
-            QtGui.QAbstractItemView.SelectItems,
-            QtGui.QAbstractItemView.SingleSelection,
+            QtGui.QAbstractItemView.SelectionBehavior.SelectItems,
+            QtGui.QAbstractItemView.SelectionMode.SingleSelection,
         ),
         "cells": (
-            QtGui.QAbstractItemView.SelectItems,
-            QtGui.QAbstractItemView.ExtendedSelection,
+            QtGui.QAbstractItemView.SelectionBehavior.SelectItems,
+            QtGui.QAbstractItemView.SelectionMode.ExtendedSelection,
         ),
     }
 
@@ -957,11 +961,11 @@ class TableView(QtGui.QTableView):
 
         # Configure the editing behavior.
         triggers = (
-            QtGui.QAbstractItemView.DoubleClicked
-            | QtGui.QAbstractItemView.SelectedClicked
+            QtGui.QAbstractItemView.EditTrigger.DoubleClicked
+            | QtGui.QAbstractItemView.EditTrigger.SelectedClicked
         )
         if factory.edit_on_first_click and not factory.reorderable:
-            triggers |= QtGui.QAbstractItemView.CurrentChanged
+            triggers |= QtGui.QAbstractItemView.EditTrigger.CurrentChanged
         self.setEditTriggers(triggers)
 
         # Configure the reordering and sorting behavior.
@@ -970,7 +974,7 @@ class TableView(QtGui.QTableView):
         self.setDropIndicatorShown(True)
 
         if factory.reorderable:
-            self.setDragDropMode(QtGui.QAbstractItemView.InternalMove)
+            self.setDragDropMode(QtGui.QAbstractItemView.DragDropMode.InternalMove)
         if factory.sortable:
             self.setSortingEnabled(True)
 
@@ -980,7 +984,7 @@ class TableView(QtGui.QTableView):
         self.resizeColumnsToContents()
 
     def setModel(self, model):
-        super(TableView, self).setModel(model)
+        super().setModel(model)
         self._update_header_sizing()
 
     def contextMenuEvent(self, event):
@@ -1026,7 +1030,7 @@ class TableView(QtGui.QTableView):
         """Reimplemented to create context menu for the vertical header."""
 
         vheader = self.verticalHeader()
-        if obj is vheader and event.type() == QtCore.QEvent.ContextMenu:
+        if obj is vheader and event.type() == QtCore.QEvent.Type.ContextMenu:
             event.accept()
             editor = self._editor
             row = vheader.logicalIndexAt(event.pos().y())
@@ -1083,7 +1087,7 @@ class TableView(QtGui.QTableView):
             return size_hint
 
         width = self.style().pixelMetric(
-            QtGui.QStyle.PM_ScrollBarExtent, QtGui.QStyleOptionHeader(), self
+            QtGui.QStyle.PixelMetric.PM_ScrollBarExtent, QtGui.QStyleOptionHeader(), self
         )
         for column in range(len(self._editor.columns)):
             width += self.sizeHintForColumn(column)
@@ -1113,25 +1117,30 @@ class TableView(QtGui.QTableView):
 
             # Determine the width of the column label
             text = column.get_label()
-            width = QtGui.QFontMetrics(font).width(text)
+            # QFontMetrics.width() is deprecated and Qt docs suggest using
+            # horizontalAdvance() instead, but is only available since Qt 5.11
+            if QtCore.__version_info__ >= (5, 11):
+                width = QtGui.QFontMetrics(font).horizontalAdvance(text)
+            else:
+                width = QtGui.QFontMetrics(font).width(text)
 
             # Add margin to the calculated width as appropriate
             style = self.style()
             option = QtGui.QStyleOptionHeader()
             width += (
                 style.pixelMetric(
-                    QtGui.QStyle.PM_HeaderGripMargin, option, self
+                    QtGui.QStyle.PixelMetric.PM_HeaderGripMargin, option, self
                 )
                 * 2
             )
             if editor.factory.sortable and not editor.factory.reorderable:
                 # Add size of sort indicator
                 width += style.pixelMetric(
-                    QtGui.QStyle.PM_HeaderMarkSize, option, self
+                    QtGui.QStyle.PixelMetric.PM_HeaderMarkSize, option, self
                 )
                 # Add distance between sort indicator and text
                 width += style.pixelMetric(
-                    QtGui.QStyle.PM_HeaderMargin, option, self
+                    QtGui.QStyle.PixelMetric.PM_HeaderMargin, option, self
                 )
             return max(base_width, width)
 
@@ -1140,7 +1149,7 @@ class TableView(QtGui.QTableView):
             return requested_width
 
     def resizeColumnsToContents(self):
-        """ Support proportional column width specifications. """
+        """Support proportional column width specifications."""
 
         # TODO: The proportional size specification approach found in the
         # TableColumns is not entirely compatible with the ability to
@@ -1191,10 +1200,10 @@ class TableView(QtGui.QTableView):
             editor.dispose()
             delattr(control, "_editor")
 
-        return super(TableView, self).closeEditor(control, hint)
+        return super().closeEditor(control, hint)
 
     def _update_header_sizing(self):
-        """ Header section sizing can be done only after a valid model is set.
+        """Header section sizing can be done only after a valid model is set.
         Otherwise results in segfault with Qt5.
         """
         editor = self._editor
@@ -1207,23 +1216,23 @@ class TableView(QtGui.QTableView):
             factory.editable and (insertable or factory.deletable)
         ) or factory.reorderable:
             vheader.installEventFilter(self)
-            set_resize_mode(QtGui.QHeaderView.ResizeToContents)
+            set_resize_mode(QtGui.QHeaderView.ResizeMode.ResizeToContents)
         elif not factory.show_row_labels:
             vheader.hide()
         if factory.row_height > 0:
             vheader.setDefaultSectionSize(factory.row_height)
         self.setAlternatingRowColors(factory.alternate_bg_color)
-        self.setHorizontalScrollMode(QtGui.QAbstractItemView.ScrollPerPixel)
+        self.setHorizontalScrollMode(QtGui.QAbstractItemView.ScrollMode.ScrollPerPixel)
         # Configure the column headings.
         # We detect if there are any stretchy sections at all; if not, then
         # we make the last non-fixed-size column stretchy.
         hheader = self.horizontalHeader()
         set_resize_mode = set_qheader_section_resize_mode(hheader)
         resize_mode_map = dict(
-            interactive=QtGui.QHeaderView.Interactive,
-            fixed=QtGui.QHeaderView.Fixed,
-            stretch=QtGui.QHeaderView.Stretch,
-            resize_to_contents=QtGui.QHeaderView.ResizeToContents,
+            interactive=QtGui.QHeaderView.ResizeMode.Interactive,
+            fixed=QtGui.QHeaderView.ResizeMode.Fixed,
+            stretch=QtGui.QHeaderView.ResizeMode.Stretch,
+            resize_to_contents=QtGui.QHeaderView.ResizeMode.ResizeToContents,
         )
         stretchable_columns = []
         for i, column in enumerate(editor.columns):
@@ -1236,7 +1245,7 @@ class TableView(QtGui.QTableView):
             hheader.setStretchLastSection(True)
         else:
             # hheader.setSectionResizeMode(
-            #     stretchable_columns[-1], QtGui.QHeaderView.Stretch)
+            #     stretchable_columns[-1], QtGui.QHeaderView.ResizeMode.Stretch)
             hheader.setStretchLastSection(False)
         if factory.show_column_labels:
             hheader.setHighlightSections(False)
@@ -1250,8 +1259,7 @@ class TableView(QtGui.QTableView):
 
 
 class TableFilterEditor(HasTraits):
-    """ An editor that manages table filters.
-    """
+    """An editor that manages table filters."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -1264,7 +1272,7 @@ class TableFilterEditor(HasTraits):
     filters = List(TableFilter)
 
     #: The list of available templates from which filters can be created
-    templates = Property(List(TableFilter), depends_on="filters")
+    templates = Property(List(TableFilter), observe="filters")
 
     #: The currently selected filter template
     selected_template = Instance(TableFilter)
@@ -1273,7 +1281,7 @@ class TableFilterEditor(HasTraits):
     selected_filter = Instance(TableFilter, allow_none=True)
 
     #: The view to use for the current filter
-    selected_filter_view = Property(depends_on="selected_filter")
+    selected_filter_view = Property(observe="selected_filter")
 
     #: Buttons for add/removing filters
     add_button = Button("New")
@@ -1357,18 +1365,18 @@ class TableFilterEditor(HasTraits):
         ]
         self.selected_template = self.templates[0]
 
-    def _add_button_fired(self):
-        """ Create a new filter based on the selected template and select it.
-        """
+    @observe('add_button')
+    def _create_and_select_new_filter(self, event):
+        """Create a new filter based on the selected template and select it."""
         new_filter = self.selected_template.clone_traits()
         new_filter.template = False
         new_filter.name = new_filter._name = "New filter"
         self.filters.append(new_filter)
         self.selected_filter = new_filter
 
-    def _remove_button_fired(self):
-        """ Delete the currently selected filter.
-        """
+    @observe("remove_button")
+    def _delete_selected_filter(self, event):
+        """Delete the currently selected filter."""
         if self.selected_template == self.selected_filter:
             self.selected_template = self.templates[0]
 
@@ -1379,10 +1387,10 @@ class TableFilterEditor(HasTraits):
         else:
             self.selected_filter = None
 
-    @on_trait_change("selected_filter:name")
-    def _update_filter_list(self):
-        """ A hack to make the EnumEditor watching the list of filters refresh
-            their text when the name of the selected filter changes.
+    @observe("selected_filter:name")
+    def _update_filter_list(self, event):
+        """A hack to make the EnumEditor watching the list of filters refresh
+        their text when the name of the selected filter changes.
         """
         filters = self.filters
         self.filters = []
