@@ -1,4 +1,4 @@
-# (C) Copyright 2009-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2009-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -23,7 +23,6 @@
 """
 
 
-
 import logging
 
 from pyface.qt import QtCore, QtGui
@@ -33,23 +32,22 @@ from traitsui.ui_traits import SequenceTypes
 from .clipboard import PyMimeData
 
 
-
 # set up logging for the module
 logger = logging.getLogger(__name__)
 
 
 # Mapping for trait alignment values to qt4 horizontal alignment constants
 h_alignment_map = {
-    "left": QtCore.Qt.AlignLeft,
-    "center": QtCore.Qt.AlignHCenter,
-    "right": QtCore.Qt.AlignRight,
+    "left": QtCore.Qt.AlignmentFlag.AlignLeft,
+    "center": QtCore.Qt.AlignmentFlag.AlignHCenter,
+    "right": QtCore.Qt.AlignmentFlag.AlignRight,
 }
 
 # Mapping for trait alignment values to qt4 vertical alignment constants
 v_alignment_map = {
-    "top": QtCore.Qt.AlignTop,
-    "center": QtCore.Qt.AlignVCenter,
-    "bottom": QtCore.Qt.AlignBottom,
+    "top": QtCore.Qt.AlignmentFlag.AlignTop,
+    "center": QtCore.Qt.AlignmentFlag.AlignVCenter,
+    "bottom": QtCore.Qt.AlignmentFlag.AlignBottom,
 }
 
 # MIME type for internal table drag/drop operations
@@ -57,8 +55,7 @@ mime_type = "traits-ui-table-editor"
 
 
 def as_qcolor(color):
-    """ Convert a color specification (maybe a tuple) into a QColor.
-    """
+    """Convert a color specification (maybe a tuple) into a QColor."""
     if isinstance(color, SequenceTypes):
         return QtGui.QColor(*color)
     else:
@@ -100,36 +97,36 @@ class TableModel(QtCore.QAbstractTableModel):
             # probably during shutdown, but I haven't investigated
             return None
 
-        if role == QtCore.Qt.DisplayRole or role == QtCore.Qt.EditRole:
+        if role == QtCore.Qt.ItemDataRole.DisplayRole or role == QtCore.Qt.ItemDataRole.EditRole:
             text = column.get_value(obj)
             if text is not None:
                 return text
 
-        elif role == QtCore.Qt.DecorationRole:
+        elif role == QtCore.Qt.ItemDataRole.DecorationRole:
             image = self._editor._get_image(column.get_image(obj))
             if image is not None:
                 return image
 
-        elif role == QtCore.Qt.ToolTipRole:
+        elif role == QtCore.Qt.ItemDataRole.ToolTipRole:
             tooltip = column.get_tooltip(obj)
             if tooltip:
                 return tooltip
 
-        elif role == QtCore.Qt.FontRole:
+        elif role == QtCore.Qt.ItemDataRole.FontRole:
             font = column.get_text_font(obj)
             if font is None:
                 font = self._editor.factory.cell_font
             if font is not None:
                 return QtGui.QFont(font)
 
-        elif role == QtCore.Qt.TextAlignmentRole:
+        elif role == QtCore.Qt.ItemDataRole.TextAlignmentRole:
             string = column.get_horizontal_alignment(obj)
-            h_alignment = h_alignment_map.get(string, QtCore.Qt.AlignLeft)
+            h_alignment = h_alignment_map.get(string, QtCore.Qt.AlignmentFlag.AlignLeft)
             string = column.get_vertical_alignment(obj)
-            v_alignment = v_alignment_map.get(string, QtCore.Qt.AlignVCenter)
+            v_alignment = v_alignment_map.get(string, QtCore.Qt.AlignmentFlag.AlignVCenter)
             return int(h_alignment | v_alignment)
 
-        elif role == QtCore.Qt.BackgroundRole:
+        elif role == QtCore.Qt.ItemDataRole.BackgroundRole:
             color = column.get_cell_color(obj)
             if color is None:
                 if column.is_editable(obj):
@@ -143,7 +140,7 @@ class TableModel(QtCore.QAbstractTableModel):
             q_color = as_qcolor(color)
             return QtGui.QBrush(q_color)
 
-        elif role == QtCore.Qt.ForegroundRole:
+        elif role == QtCore.Qt.ItemDataRole.ForegroundRole:
             color = column.get_text_color(obj)
             if color is None:
                 color = self._editor.factory.cell_color_
@@ -151,15 +148,15 @@ class TableModel(QtCore.QAbstractTableModel):
                 q_color = as_qcolor(color)
                 return QtGui.QBrush(q_color)
 
-        elif role == QtCore.Qt.UserRole:
+        elif role == QtCore.Qt.ItemDataRole.UserRole:
             return obj
 
-        elif role == QtCore.Qt.CheckStateRole:
+        elif role == QtCore.Qt.ItemDataRole.CheckStateRole:
             if column.get_type(obj) == "bool" and column.show_checkbox:
                 if column.get_raw_value(obj):
-                    return QtCore.Qt.Checked
+                    return QtCore.Qt.CheckState.Checked
                 else:
-                    return QtCore.Qt.Unchecked
+                    return QtCore.Qt.CheckState.Unchecked
 
         return None
 
@@ -170,14 +167,14 @@ class TableModel(QtCore.QAbstractTableModel):
 
         if not mi.isValid():
             if editor.factory.reorderable:
-                return QtCore.Qt.ItemIsDropEnabled
+                return QtCore.Qt.ItemFlag.ItemIsDropEnabled
             else:
-                return QtCore.Qt.NoItemFlags
+                return QtCore.Qt.ItemFlag.NoItemFlags
 
         flags = (
-            QtCore.Qt.ItemIsSelectable
-            | QtCore.Qt.ItemIsEnabled
-            | QtCore.Qt.ItemIsDragEnabled
+            QtCore.Qt.ItemFlag.ItemIsSelectable
+            | QtCore.Qt.ItemFlag.ItemIsEnabled
+            | QtCore.Qt.ItemFlag.ItemIsDragEnabled
         )
 
         obj = editor.items()[mi.row()]
@@ -185,13 +182,13 @@ class TableModel(QtCore.QAbstractTableModel):
 
         if editor.factory:
             if editor.factory.editable and column.is_editable(obj):
-                flags |= QtCore.Qt.ItemIsEditable | QtCore.Qt.ItemIsDropEnabled
+                flags |= QtCore.Qt.ItemFlag.ItemIsEditable | QtCore.Qt.ItemFlag.ItemIsDropEnabled
 
             if editor.factory.reorderable:
-                flags |= QtCore.Qt.ItemIsDropEnabled
+                flags |= QtCore.Qt.ItemFlag.ItemIsDropEnabled
 
             if column.get_type(obj) == "bool" and column.show_checkbox:
-                flags |= QtCore.Qt.ItemIsUserCheckable
+                flags |= QtCore.Qt.ItemFlag.ItemIsUserCheckable
 
         return flags
 
@@ -200,15 +197,15 @@ class TableModel(QtCore.QAbstractTableModel):
 
         editor = self._editor
 
-        if orientation == QtCore.Qt.Horizontal:
+        if orientation == QtCore.Qt.Orientation.Horizontal:
             column = editor.columns[section]
 
-            if role == QtCore.Qt.DisplayRole:
+            if role == QtCore.Qt.ItemDataRole.DisplayRole:
                 return column.get_label()
 
-        elif orientation == QtCore.Qt.Vertical:
+        elif orientation == QtCore.Qt.Orientation.Vertical:
 
-            if role == QtCore.Qt.DisplayRole:
+            if role == QtCore.Qt.ItemDataRole.DisplayRole:
                 return str(section + 1)
 
         if editor.factory is None:
@@ -216,17 +213,17 @@ class TableModel(QtCore.QAbstractTableModel):
             # probably during shutdown, but I haven't investigated
             return None
 
-        if role == QtCore.Qt.FontRole:
+        if role == QtCore.Qt.ItemDataRole.FontRole:
             font = editor.factory.label_font
             if font is not None:
                 return QtGui.QFont(font)
 
-        elif role == QtCore.Qt.BackgroundRole:
+        elif role == QtCore.Qt.ItemDataRole.BackgroundRole:
             color = editor.factory.label_bg_color_
             if color is not None:
                 return color
 
-        elif role == QtCore.Qt.ForegroundRole:
+        elif role == QtCore.Qt.ItemDataRole.ForegroundRole:
             color = editor.factory.label_color_
             if color is not None:
                 return color
@@ -308,12 +305,12 @@ class TableModel(QtCore.QAbstractTableModel):
     def dropMimeData(self, mime_data, action, row, column, parent):
         """Reimplemented to allow items to be moved."""
 
-        if action == QtCore.Qt.IgnoreAction:
+        if action == QtCore.Qt.DropAction.IgnoreAction:
             return False
 
         # this is a drag from a table model?
         data = mime_data.data(mime_type)
-        if not data.isNull() and action == QtCore.Qt.MoveAction:
+        if not data.isNull() and action == QtCore.Qt.DropAction.MoveAction:
             id_and_rows = [
                 int(s) for s in data.data().decode("utf8").split(" ")
             ]
@@ -349,35 +346,35 @@ class TableModel(QtCore.QAbstractTableModel):
     def supportedDropActions(self):
         """Reimplemented to allow items to be moved."""
 
-        return QtCore.Qt.MoveAction
+        return QtCore.Qt.DropAction.MoveAction
 
     # -------------------------------------------------------------------------
     #  Utility methods
     # -------------------------------------------------------------------------
 
     def _get_columns_drag_value(self, columns):
-        """ Returns the value to use when the specified columns are dragged or
-            copied and pasted. The parameter *cols* is a list of column indexes.
+        """Returns the value to use when the specified columns are dragged or
+        copied and pasted. The parameter *cols* is a list of column indexes.
         """
         return [self._get_column_data(column) for column in columns]
 
     def _get_column_data(self, column):
-        """ Return the model data for the column as a list """
+        """Return the model data for the column as a list"""
         editor = self._editor
         column_obj = editor.columns[column]
         return [column_obj.get_value(item) for item in editor.items()]
 
     def _get_rows_drag_value(self, rows):
-        """ Returns the value to use when the specified rows are dragged or
-            copied and pasted. The parameter *rows* is a list of row indexes.
-            Return a list of objects.
+        """Returns the value to use when the specified rows are dragged or
+        copied and pasted. The parameter *rows* is a list of row indexes.
+        Return a list of objects.
         """
         items = self._editor.items()
         return [items[row] for row in rows]
 
     def _get_cell_drag_value(self, row, column):
-        """ Returns the value to use when the specified cell is dragged or
-            copied and pasted.
+        """Returns the value to use when the specified cell is dragged or
+        copied and pasted.
         """
         editor = self._editor
         item = editor.items()[row]
@@ -440,7 +437,7 @@ class SortFilterTableModel(QtGui.QSortFilterProxyModel):
     # -------------------------------------------------------------------------
 
     def filterAcceptsRow(self, source_row, source_parent):
-        """"Reimplemented to use a TableFilter for filtering rows."""
+        """ "Reimplemented to use a TableFilter for filtering rows."""
 
         if self._editor._filtered_cache is None:
             return True
