@@ -1,29 +1,21 @@
-# -------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2009, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Evan Patterson
-#  Date:   06/22/2009
-#
-# -------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ A traits UI editor for editing tabular data (arrays, list of tuples, lists
     of objects, etc).
 """
 
 
-
 from contextlib import contextmanager
 
-from pyface.qt import QtCore, QtGui, is_qt5
+from pyface.qt import QtCore, QtGui, is_qt4
 from pyface.image_resource import ImageResource
 from pyface.ui_traits import Image
 
@@ -31,6 +23,7 @@ from traits.api import (
     Any,
     Bool,
     Callable,
+    Dict,
     Event,
     HasStrictTraits,
     Instance,
@@ -46,23 +39,29 @@ from traitsui.helper import compute_column_widths
 from .editor import Editor
 from .tabular_model import TabularModel
 
+SCROLL_TO_POSITION_HINT_MAP = {
+    "center": QtGui.QTableView.PositionAtCenter,
+    "top": QtGui.QTableView.PositionAtTop,
+    "bottom": QtGui.QTableView.PositionAtBottom,
+    "visible": QtGui.QTableView.EnsureVisible,
+}
 
 
 class HeaderEventFilter(QtCore.QObject):
     def __init__(self, editor):
-        super(HeaderEventFilter, self).__init__()
+        super().__init__()
         self.editor = editor
 
     def eventFilter(self, obj, event):
-        if event.type() == QtCore.QEvent.ContextMenu:
+        if event.type() == QtCore.QEvent.Type.ContextMenu:
             self.editor._on_column_context_menu(event.pos())
             return True
         return False
 
 
 class TabularEditor(Editor):
-    """ A traits UI editor for editing tabular data (arrays, list of tuples,
-        lists of objects, etc).
+    """A traits UI editor for editing tabular data (arrays, list of tuples,
+    lists of objects, etc).
     """
 
     # -- Trait Definitions ----------------------------------------------------
@@ -132,10 +131,10 @@ class TabularEditor(Editor):
     model = Instance(TabularModel)
 
     #: Dictionary mapping image names to QIcons
-    images = Any({})
+    images = Dict()
 
     #: Dictionary mapping ImageResource objects to QIcons
-    image_resources = Any({})
+    image_resources = Dict()
 
     #: An image being converted:
     image = Image
@@ -149,8 +148,8 @@ class TabularEditor(Editor):
     # -------------------------------------------------------------------------
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         factory = self.factory
         adapter = self.adapter = factory.adapter
@@ -211,7 +210,7 @@ class TabularEditor(Editor):
             self._on_column_click
         )
 
-        control.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+        control.setContextMenuPolicy(QtCore.Qt.ContextMenuPolicy.CustomContextMenu)
         control.customContextMenuRequested.connect(self._on_context_menu)
 
         self.header_event_filter = HeaderEventFilter(self)
@@ -247,12 +246,14 @@ class TabularEditor(Editor):
         # Rebuild the editor columns and headers whenever the adapter's
         # 'columns' changes:
         self.on_trait_change(
-            self.update_editor, "adapter.columns", dispatch="ui"
+            self._adapter_columns_updated, "adapter.columns", dispatch="ui"
         )
 
     def dispose(self):
-        """ Disposes of the contents of an editor.
-        """
+        """Disposes of the contents of an editor."""
+        self.model.beginResetModel()
+        self.model.endResetModel()
+
         self.context_object.on_trait_change(
             self.update_editor, self.extended_name + "_items", remove=True
         )
@@ -266,16 +267,16 @@ class TabularEditor(Editor):
             self.refresh_editor, "adapter.+update", remove=True
         )
         self.on_trait_change(
-            self.update_editor, "adapter.columns", remove=True
+            self._adapter_columns_updated, "adapter.columns", remove=True
         )
 
         self.adapter.cleanup()
 
-        super(TabularEditor, self).dispose()
+        super().dispose()
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         if not self._no_update:
             self.model.beginResetModel()
@@ -290,13 +291,11 @@ class TabularEditor(Editor):
     # -------------------------------------------------------------------------
 
     def refresh_editor(self):
-        """ Requests the table view to redraw itself.
-        """
+        """Requests the table view to redraw itself."""
         self.control.viewport().update()
 
     def callx(self, func, *args, **kw):
-        """ Call a function without allowing the editor to update.
-        """
+        """Call a function without allowing the editor to update."""
         old = self._no_update
         self._no_update = True
         try:
@@ -305,8 +304,7 @@ class TabularEditor(Editor):
             self._no_update = old
 
     def setx(self, **keywords):
-        """ Set one or more attributes without allowing the editor to update.
-        """
+        """Set one or more attributes without allowing the editor to update."""
         old = self._no_notify
         self._no_notify = True
         try:
@@ -320,18 +318,17 @@ class TabularEditor(Editor):
     # -------------------------------------------------------------------------
 
     def restore_prefs(self, prefs):
-        """ Restores any saved user preference information associated with the
-            editor.
+        """Restores any saved user preference information associated with the
+        editor.
         """
         cws = prefs.get("cached_widths")
         num_columns = len(self.adapter.columns)
         if cws is not None and num_columns == len(cws):
             for column in range(num_columns):
-                self.control.setColumnWidth(column, cws[column])
+                self.control.setColumnWidth(column, int(cws[column]))
 
     def save_prefs(self):
-        """ Returns any user preference information associated with the editor.
-        """
+        """Returns any user preference information associated with the editor."""
         widths = [
             self.control.columnWidth(column)
             for column in range(len(self.adapter.columns))
@@ -343,8 +340,7 @@ class TabularEditor(Editor):
     # -------------------------------------------------------------------------
 
     def _add_image(self, image_resource):
-        """ Adds a new image to the image map.
-        """
+        """Adds a new image to the image map."""
         image = image_resource.create_icon()
 
         self.image_resources[image_resource] = image
@@ -353,8 +349,7 @@ class TabularEditor(Editor):
         return image
 
     def _get_image(self, image):
-        """ Converts a user specified image to a QIcon.
-        """
+        """Converts a user specified image to a QIcon."""
         if isinstance(image, str):
             self.image = image
             image = self.image
@@ -368,8 +363,8 @@ class TabularEditor(Editor):
         return self.images.get(image)
 
     def _mouse_click(self, index, trait):
-        """ Generate a TabularEditorEvent event for a specified model index and
-            editor trait name.
+        """Generate a TabularEditorEvent event for a specified model index and
+        editor trait name.
         """
         event = TabularEditorEvent(
             editor=self, row=index.row(), column=index.column()
@@ -379,19 +374,33 @@ class TabularEditor(Editor):
     # -- Trait Event Handlers -------------------------------------------------
 
     def _clicked_changed(self):
-        """ When mouse is clicked on a specific cell, update the selected
-            indices first
+        """When mouse is clicked on a specific cell, update the selected
+        indices first
         """
         if not self.factory.multi_select:
             self.selected_row = self.clicked.row
             self.selected_column = self.clicked.column
 
     def _column_clicked_changed(self):
-        """ When column is clicked, update selected column first
-        """
+        """When column is clicked, update selected column first"""
         if not self.factory.multi_select:
             self.selected_column = self.column_clicked.column
 
+    def _adapter_columns_updated(self):
+        """Update the view when the adapter columns trait changes.
+        Note that this change handler is added after the UI is instantiated,
+        and removed when the UI is disposed.
+        """
+        # Invalidate internal state of the view related to the columns
+        n_columns = len(self.adapter.columns)
+        if (
+            self.control is not None
+            and self.control._user_widths is not None
+            and len(self.control._user_widths) != n_columns
+        ):
+            self.control._user_widths = None
+        self.update_editor()
+
     def _update_changed(self):
         self.update_editor()
 
@@ -422,8 +431,8 @@ class TabularEditor(Editor):
                     self.model.index(
                         selected_row, max(self.selected_column, 0)
                     ),
-                    QtGui.QItemSelectionModel.ClearAndSelect
-                    | QtGui.QItemSelectionModel.Rows,
+                    QtGui.QItemSelectionModel.SelectionFlag.ClearAndSelect
+                    | QtGui.QItemSelectionModel.SelectionFlag.Rows,
                 )
                 # Once selected, scroll to the row
                 self.scroll_to_row = selected_row
@@ -446,7 +455,7 @@ class TabularEditor(Editor):
         except:
             pass
         else:
-            list_event = TraitListEvent(0, added, removed)
+            list_event = TraitListEvent(index=0, added=added, removed=removed)
             self._multi_selected_rows_items_changed(list_event)
 
     def _multi_selected_rows_changed(self, selected_rows):
@@ -460,8 +469,8 @@ class TabularEditor(Editor):
             smodel.clearSelection()
             smodel.select(
                 selection,
-                QtGui.QItemSelectionModel.Select
-                | QtGui.QItemSelectionModel.Rows,
+                QtGui.QItemSelectionModel.SelectionFlag.Select
+                | QtGui.QItemSelectionModel.SelectionFlag.Rows,
             )
 
     def _multi_selected_rows_items_changed(self, event):
@@ -470,14 +479,14 @@ class TabularEditor(Editor):
             for row in event.removed:
                 smodel.select(
                     self.model.index(row, 0),
-                    QtGui.QItemSelectionModel.Deselect
-                    | QtGui.QItemSelectionModel.Rows,
+                    QtGui.QItemSelectionModel.SelectionFlag.Deselect
+                    | QtGui.QItemSelectionModel.SelectionFlag.Rows,
                 )
             for row in event.added:
                 smodel.select(
                     self.model.index(row, 0),
-                    QtGui.QItemSelectionModel.Select
-                    | QtGui.QItemSelectionModel.Rows,
+                    QtGui.QItemSelectionModel.SelectionFlag.Select
+                    | QtGui.QItemSelectionModel.SelectionFlag.Rows,
                 )
 
     def _selected_column_changed(self, selected_column):
@@ -488,34 +497,25 @@ class TabularEditor(Editor):
                     self.model.index(
                         max(self.selected_row, 0), selected_column
                     ),
-                    QtGui.QItemSelectionModel.ClearAndSelect
-                    | QtGui.QItemSelectionModel.Rows,
+                    QtGui.QItemSelectionModel.SelectionFlag.ClearAndSelect
+                    | QtGui.QItemSelectionModel.SelectionFlag.Rows,
                 )
                 # Once selected, scroll to the column
                 self.scroll_to_column = selected_column
 
-    scroll_to_row_hint_map = {
-        "center": QtGui.QTableView.PositionAtCenter,
-        "top": QtGui.QTableView.PositionAtTop,
-        "bottom": QtGui.QTableView.PositionAtBottom,
-        "visible": QtGui.QTableView.EnsureVisible,
-    }
-
     def _scroll_to_row_changed(self, row):
-        """ Scroll to the given row.
-        """
-        scroll_hint = self.scroll_to_row_hint_map.get(
-            self.factory.scroll_to_row_hint, self.control.PositionAtCenter
+        """Scroll to the given row."""
+        scroll_hint = SCROLL_TO_POSITION_HINT_MAP.get(
+            self.factory.scroll_to_position_hint, self.control.EnsureVisible
         )
         self.control.scrollTo(
             self.model.index(row, max(self.selected_column, 0)), scroll_hint
         )
 
     def _scroll_to_column_changed(self, column):
-        """ Scroll to the given column.
-        """
-        scroll_hint = self.scroll_to_row_hint_map.get(
-            self.factory.scroll_to_row_hint, self.control.PositionAtCenter
+        """Scroll to the given column."""
+        scroll_hint = SCROLL_TO_POSITION_HINT_MAP.get(
+            self.factory.scroll_to_position_hint, self.control.EnsureVisible
         )
         self.control.scrollTo(
             self.model.index(max(self.selected_row, 0), column), scroll_hint
@@ -524,19 +524,16 @@ class TabularEditor(Editor):
     # -- Table Control Event Handlers -----------------------------------------
 
     def _on_activate(self, index):
-        """ Handle a cell being activated.
-        """
+        """Handle a cell being activated."""
         self.activated_row = row = index.row()
         self.activated = self.adapter.get_item(self.object, self.name, row)
 
     def _on_click(self, index):
-        """ Handle a cell being clicked.
-        """
+        """Handle a cell being clicked."""
         self._mouse_click(index, "clicked")
 
     def _on_dclick(self, index):
-        """ Handle a cell being double clicked.
-        """
+        """Handle a cell being double clicked."""
         self._mouse_click(index, "dclicked")
 
     def _on_column_click(self, column):
@@ -552,8 +549,7 @@ class TabularEditor(Editor):
         setattr(self, "column_right_clicked", event)
 
     def _on_row_selection(self, added, removed):
-        """ Handle the row selection being changed.
-        """
+        """Handle the row selection being changed."""
         self._no_update = True
         try:
             indexes = self.control.selectionModel().selectedRows()
@@ -569,8 +565,7 @@ class TabularEditor(Editor):
             self._no_update = False
 
     def _on_rows_selection(self, added, removed):
-        """ Handle the rows selection being changed.
-        """
+        """Handle the rows selection being changed."""
         self._no_update = True
         try:
             indexes = self.control.selectionModel().selectedRows()
@@ -657,29 +652,27 @@ class TabularEditorEvent(HasStrictTraits):
 
 
 class _ItemDelegate(QtGui.QStyledItemDelegate):
-    """ A QStyledItemDelegate which draws its owns gridlines so that we can
-        choose to draw only the horizontal or only the vertical gridlines if
-        appropriate.
+    """A QStyledItemDelegate which draws its owns gridlines so that we can
+    choose to draw only the horizontal or only the vertical gridlines if
+    appropriate.
     """
 
     def __init__(self, table_view):
-        """ Store which grid lines to draw.
-        """
+        """Store which grid lines to draw."""
         QtGui.QStyledItemDelegate.__init__(self, table_view)
         self._horizontal_lines = table_view._editor.factory.horizontal_lines
         self._vertical_lines = table_view._editor.factory.vertical_lines
 
     def paint(self, painter, option, index):
-        """ Overrident to draw gridlines.
-        """
+        """Overrident to draw gridlines."""
         QtGui.QStyledItemDelegate.paint(self, painter, option, index)
         painter.save()
 
         # FIXME: 'styleHint' is returning bogus (negative) values. Why?
         # style = QtGui.QApplication.instance().style()
-        # color = style.styleHint(QtGui.QStyle.SH_Table_GridLineColor, option)
+        # color = style.styleHint(QtGui.QStyle.StyleHint.SH_Table_GridLineColor, option)
         # painter.setPen(QtGui.QColor(color))
-        painter.setPen(option.palette.color(QtGui.QPalette.Dark))
+        painter.setPen(option.palette.color(QtGui.QPalette.ColorRole.Dark))
 
         if self._horizontal_lines:
             painter.drawLine(
@@ -692,12 +685,10 @@ class _ItemDelegate(QtGui.QStyledItemDelegate):
 
 
 class _TableView(QtGui.QTableView):
-    """ A QTableView configured to behave as expected by TraitsUI.
-    """
+    """A QTableView configured to behave as expected by TraitsUI."""
 
     def __init__(self, editor):
-        """ Initialise the object.
-        """
+        """Initialise the object."""
         QtGui.QTableView.__init__(self)
 
         self._user_widths = None
@@ -714,12 +705,14 @@ class _TableView(QtGui.QTableView):
             vheader.hide()
 
         if factory.show_row_titles and factory.auto_resize_rows:
-            if is_qt5:
-                vheader.setSectionResizeMode(
-                    QtGui.QHeaderView.ResizeToContents
+            if is_qt4:
+                vheader.setResizeMode(
+                    QtGui.QHeaderView.ResizeMode.ResizeToContents
                 )
             else:
-                vheader.setResizeMode(QtGui.QHeaderView.ResizeToContents)
+                vheader.setSectionResizeMode(
+                    QtGui.QHeaderView.ResizeMode.ResizeToContents
+                )
         else:
             # Set a default height for rows. Although setting the resize mode to
             # ResizeToContents would provide the best sizes, this is far too
@@ -753,11 +746,11 @@ class _TableView(QtGui.QTableView):
         self.setItemDelegate(_ItemDelegate(self))
 
         # Configure the selection behaviour.
-        self.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
+        self.setSelectionBehavior(QtGui.QAbstractItemView.SelectionBehavior.SelectRows)
         if factory.multi_select:
-            mode = QtGui.QAbstractItemView.ExtendedSelection
+            mode = QtGui.QAbstractItemView.SelectionMode.ExtendedSelection
         else:
-            mode = QtGui.QAbstractItemView.SingleSelection
+            mode = QtGui.QAbstractItemView.SelectionMode.SingleSelection
         self.setSelectionMode(mode)
 
         # Configure drag and drop behavior
@@ -765,22 +758,21 @@ class _TableView(QtGui.QTableView):
         if factory.editable:
             self.viewport().setAcceptDrops(True)
         if factory.drag_move:
-            self.setDragDropMode(QtGui.QAbstractItemView.InternalMove)
+            self.setDragDropMode(QtGui.QAbstractItemView.DragDropMode.InternalMove)
         else:
-            self.setDragDropMode(QtGui.QAbstractItemView.DragDrop)
+            self.setDragDropMode(QtGui.QAbstractItemView.DragDropMode.DragDrop)
         self.setDropIndicatorShown(True)
 
     def keyPressEvent(self, event):
-        """ Reimplemented to support edit, insert, and delete by keyboard.
-        """
+        """Reimplemented to support edit, insert, and delete by keyboard."""
         editor = self._editor
         factory = editor.factory
 
         # Note that setting 'EditKeyPressed' as an edit trigger does not work on
         # most platforms, which is why we do this here.
         if (
-            event.key() in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return)
-            and self.state() != QtGui.QAbstractItemView.EditingState
+            event.key() in (QtCore.Qt.Key.Key_Enter, QtCore.Qt.Key.Key_Return)
+            and self.state() != QtGui.QAbstractItemView.State.EditingState
             and factory.editable
             and "edit" in factory.operations
         ):
@@ -795,7 +787,7 @@ class _TableView(QtGui.QTableView):
                 self.edit(editor.model.index(row, 0))
 
         elif (
-            event.key() in (QtCore.Qt.Key_Backspace, QtCore.Qt.Key_Delete)
+            event.key() in (QtCore.Qt.Key.Key_Backspace, QtCore.Qt.Key.Key_Delete)
             and factory.editable
             and "delete" in factory.operations
         ):
@@ -808,7 +800,7 @@ class _TableView(QtGui.QTableView):
                 editor.model.removeRow(editor.selected_row)
 
         elif (
-            event.key() == QtCore.Qt.Key_Insert
+            event.key() == QtCore.Qt.Key.Key_Insert
             and factory.editable
             and "insert" in factory.operations
         ):
@@ -828,8 +820,7 @@ class _TableView(QtGui.QTableView):
             QtGui.QTableView.keyPressEvent(self, event)
 
     def sizeHint(self):
-        """ Reimplemented to define a reasonable size hint.
-        """
+        """Reimplemented to define a reasonable size hint."""
         sh = QtGui.QTableView.sizeHint(self)
 
         width = 0
@@ -840,30 +831,29 @@ class _TableView(QtGui.QTableView):
         return sh
 
     def resizeEvent(self, event):
-        """ Reimplemented to size the table columns when the size of the table
-            changes. Because the layout algorithm requires that the available
-            space be known, we have to wait until the UI that contains this
-            table gives it its initial size.
+        """Reimplemented to size the table columns when the size of the table
+        changes. Because the layout algorithm requires that the available
+        space be known, we have to wait until the UI that contains this
+        table gives it its initial size.
         """
-        super(_TableView, self).resizeEvent(event)
+        super().resizeEvent(event)
 
         parent = self.parent()
-        if (
-            parent
-            and (self.isVisible() or isinstance(parent, QtGui.QMainWindow))
+        if parent and (
+            self.isVisible() or isinstance(parent, QtGui.QMainWindow)
         ):
             self.resizeColumnsToContents()
 
     def sizeHintForColumn(self, column):
-        """ Reimplemented to support absolute width specification via
-            TabularAdapters and to avoid scanning all data to determine the size
-            hint. (TabularEditor, unlike TableEditor, is expected to handle very
-            large data sets.)
+        """Reimplemented to support absolute width specification via
+        TabularAdapters and to avoid scanning all data to determine the size
+        hint. (TabularEditor, unlike TableEditor, is expected to handle very
+        large data sets.)
         """
         editor = self._editor
         if editor.factory.auto_resize:
             # Use the default implementation.
-            return super(_TableView, self).sizeHintForColumn(column)
+            return super().sizeHintForColumn(column)
 
         width = editor.adapter.get_width(editor.object, editor.name, column)
         if width > 1:
@@ -872,7 +862,7 @@ class _TableView(QtGui.QTableView):
             return self.horizontalHeader().sectionSizeHint(column)
 
     def resizeColumnsToContents(self):
-        """ Reimplemented to support proportional column width specifications.
+        """Reimplemented to support proportional column width specifications.
 
         The core part of the computation is carried out in
         :func:`traitsui.helpers.compute_column_widths`
@@ -881,7 +871,7 @@ class _TableView(QtGui.QTableView):
         adapter = editor.adapter
         if editor.factory.auto_resize:
             # Use the default implementation.
-            return super(_TableView, self).resizeColumnsToContents()
+            return super().resizeColumnsToContents()
 
         available_space = self.viewport().width()
         requested = []
@@ -901,7 +891,7 @@ class _TableView(QtGui.QTableView):
                 hheader.resizeSection(column, width)
 
     def columnResized(self, index, old, new):
-        """ Handle user-driven resizing of columns.
+        """Handle user-driven resizing of columns.
 
         This affects the column widths when not using auto-sizing.
         """
@@ -909,12 +899,15 @@ class _TableView(QtGui.QTableView):
             if self._user_widths is None:
                 self._user_widths = [None] * len(self._editor.adapter.columns)
             self._user_widths[index] = new
-            if not self._editor.factory.auto_resize:
+            if (
+                self._editor.factory is not None
+                and not self._editor.factory.auto_resize
+            ):
                 self.resizeColumnsToContents()
 
     @contextmanager
     def _resizing(self):
-        """ Context manager that guards against recursive column resizing. """
+        """Context manager that guards against recursive column resizing."""
         self._is_resizing = True
         try:
             yield
