@@ -1,3 +1,13 @@
+# (C) Copyright 2008-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
@@ -13,15 +23,11 @@
 """ Defines the various text editors for the PyQt user interface toolkit.
 """
 
-
 from pyface.qt import QtCore, QtGui
 
-from traits.api import TraitError
+from traits.api import Any, Callable, List, TraitError, Tuple
 
-# FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
-# compatibility. The class has been moved to the
-# traitsui.editors.text_editor file.
-from traitsui.editors.text_editor import evaluate_trait, ToolkitEditorFactory
+from traitsui.editors.text_editor import evaluate_trait
 
 from .editor import Editor
 
@@ -30,10 +36,8 @@ from .editor_factory import ReadonlyEditor as BaseReadonlyEditor
 from .constants import OKColor
 
 
-
 class SimpleEditor(Editor):
-    """ Simple style text editor, which displays a text field.
-    """
+    """Simple style text editor, which displays a text field."""
 
     #: Flag for window styles:
     base_style = QtGui.QLineEdit
@@ -48,9 +52,15 @@ class SimpleEditor(Editor):
     #: Function used to evaluate textual user input:
     evaluate = evaluate_trait
 
+    # -- private trait definitions ------------------------------------------
+
+    #: A list of tuple(Qt signal, slot) connected which need to be disconnected
+    #: in dispose.
+    _connections_to_remove = List(Tuple(Any, Callable))
+
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         factory = self.factory
         wtype = self.base_style
@@ -70,18 +80,25 @@ class SimpleEditor(Editor):
             control.setReadOnly(True)
 
         if factory.password:
-            control.setEchoMode(QtGui.QLineEdit.Password)
-
-        if factory.auto_set and not factory.is_grid_cell:
-            if wtype == QtGui.QTextEdit:
-                control.textChanged.connect(self.update_object)
-            else:
-                control.textEdited.connect(self.update_object)
+            control.setEchoMode(QtGui.QLineEdit.EchoMode.Password)
 
+        if wtype == QtGui.QTextEdit:
+            control.textChanged.connect(self.update_object)
+            self._connections_to_remove.append(
+                (control.textChanged, self.update_object)
+            )
         else:
-            # Assume enter_set is set, otherwise the value will never get
-            # updated.
-            control.editingFinished.connect(self.update_object)
+            # QLineEdit
+            if factory.auto_set and not factory.is_grid_cell:
+                control.textEdited.connect(self.update_object)
+                self._connections_to_remove.append(
+                    (control.textEdited, self.update_object)
+                )
+            else:
+                control.editingFinished.connect(self.update_object)
+                self._connections_to_remove.append(
+                    (control.editingFinished, self.update_object)
+                )
 
         placeholder = self.factory.placeholder
 
@@ -89,18 +106,29 @@ class SimpleEditor(Editor):
             # setPlaceholderText is introduced to QTextEdit since Qt 5.2
             control.setPlaceholderText(placeholder)
 
+        if wtype is not QtGui.QTextEdit and QtCore.__version_info__ >= (5, 2):
+            # setClearButtonEnabled is introduced to QLineEdit since Qt 5.2
+            control.setClearButtonEnabled(self.factory.cancel_button)
+
         self.control = control
         # default horizontal policy is Expand, set this to Minimum
         if not (self.item.resizable) and not self.item.springy:
             policy = self.control.sizePolicy()
-            policy.setHorizontalPolicy(QtGui.QSizePolicy.Minimum)
+            policy.setHorizontalPolicy(QtGui.QSizePolicy.Policy.Minimum)
             self.control.setSizePolicy(policy)
         self.set_error_state(False)
         self.set_tooltip()
 
+    def dispose(self):
+        """Disposes of the contents of an editor."""
+        while self._connections_to_remove:
+            signal, handler = self._connections_to_remove.pop()
+            signal.disconnect(handler)
+
+        super().dispose()
+
     def update_object(self):
-        """ Handles the user entering input data in the edit control.
-        """
+        """Handles the user entering input data in the edit control."""
         if (not self._no_update) and (self.control is not None):
             try:
                 self.value = self._get_user_value()
@@ -115,8 +143,8 @@ class SimpleEditor(Editor):
                 pass
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         user_value = self._get_user_value()
         try:
@@ -136,8 +164,7 @@ class SimpleEditor(Editor):
             self.set_error_state(False)
 
     def _get_user_value(self):
-        """ Gets the actual value corresponding to what the user typed.
-        """
+        """Gets the actual value corresponding to what the user typed."""
         try:
             value = self.control.text()
         except AttributeError:
@@ -159,8 +186,7 @@ class SimpleEditor(Editor):
         return ret
 
     def error(self, excp):
-        """ Handles an error that occurs while setting the object's trait value.
-        """
+        """Handles an error that occurs while setting the object's trait value."""
         if self._error is None:
             self._error = True
             self.ui.errors += 1
@@ -168,14 +194,12 @@ class SimpleEditor(Editor):
         self.set_error_state(True)
 
     def in_error_state(self):
-        """ Returns whether or not the editor is in an error state.
-        """
+        """Returns whether or not the editor is in an error state."""
         return self.invalid or self._error
 
 
 class CustomEditor(SimpleEditor):
-    """ Custom style of text editor, which displays a multi-line text field.
-    """
+    """Custom style of text editor, which displays a multi-line text field."""
 
     #: FIXME: The wx version exposes a wx constant.
     #: Flag for window style. This value overrides the default.
@@ -183,22 +207,21 @@ class CustomEditor(SimpleEditor):
 
 
 class ReadonlyEditor(BaseReadonlyEditor):
-    """ Read-only style of text editor, which displays a read-only text field.
-    """
+    """Read-only style of text editor, which displays a read-only text field."""
 
     def init(self, parent):
-        super(ReadonlyEditor, self).init(parent)
+        super().init(parent)
 
         if self.factory.readonly_allow_selection:
             flags = (
                 self.control.textInteractionFlags()
-                | QtCore.Qt.TextSelectableByMouse
+                | QtCore.Qt.TextInteractionFlag.TextSelectableByMouse
             )
             self.control.setTextInteractionFlags(flags)
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         new_value = self.str_value
 
