@@ -1,3 +1,13 @@
+# (C) Copyright 2008-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
@@ -14,7 +24,6 @@ the PyQt user interface toolkit.
 """
 
 
-
 # Make sure that importing from this backend is OK:
 from traitsui.toolkit import assert_toolkit_import
 
@@ -26,10 +35,11 @@ from pyface.toolkit import toolkit_object as pyface_toolkit
 _app = pyface_toolkit("init:_app")
 
 from traits.trait_notifiers import set_ui_handler
+from pyface.api import SystemMetrics
 from pyface.qt import QtCore, QtGui, qt_api
 
 from traitsui.toolkit import Toolkit
-from .constants import screen_dx, screen_dy
+
 
 # -------------------------------------------------------------------------
 #  Handles UI notification handler requests that occur on a thread other than
@@ -40,8 +50,8 @@ _QT_TRAITS_EVENT = QtCore.QEvent.Type(QtCore.QEvent.registerEventType())
 
 
 class _CallAfter(QtCore.QObject):
-    """ This class dispatches a handler so that it executes in the main GUI
-        thread (similar to the wx function).
+    """This class dispatches a handler so that it executes in the main GUI
+    thread (similar to the wx function).
     """
 
     # The list of pending calls.
@@ -51,8 +61,7 @@ class _CallAfter(QtCore.QObject):
     _calls_mutex = QtCore.QMutex()
 
     def __init__(self, handler, *args, **kwds):
-        """ Initialise the call.
-        """
+        """Initialise the call."""
         QtCore.QObject.__init__(self)
 
         # Save the details of the call.
@@ -75,8 +84,7 @@ class _CallAfter(QtCore.QObject):
         QtGui.QApplication.instance().postEvent(self, event)
 
     def event(self, event):
-        """ QObject event handler.
-        """
+        """QObject event handler."""
         if event.type() == _QT_TRAITS_EVENT:
             # Invoke the handler
             self._handler(*self._args, **self._kwds)
@@ -91,16 +99,15 @@ class _CallAfter(QtCore.QObject):
             return QtCore.QObject.event(self, event)
 
     def _finished(self):
-        """ Remove the call from the list, so it can be garbage collected.
-        """
+        """Remove the call from the list, so it can be garbage collected."""
         self._calls_mutex.lock()
         del self._calls[self._calls.index(self)]
         self._calls_mutex.unlock()
 
 
 def ui_handler(handler, *args, **kwds):
-    """ Handles UI notification handler requests that occur on a thread other
-        than the UI thread.
+    """Handles UI notification handler requests that occur on a thread other
+    than the UI thread.
     """
     _CallAfter(handler, *args, **kwds)
 
@@ -115,71 +122,70 @@ class _KeyEventHook(QtCore.QObject):
     """
 
     def __init__(self, handler):
-        super(_KeyEventHook, self).__init__()
+        super().__init__()
         self._handler = handler
 
     def eventFilter(self, object, event):
-        if event.type() == QtCore.QEvent.KeyPress:
+        if event.type() == QtCore.QEvent.Type.KeyPress:
             return self._handler(event)
         else:
             return QtCore.QObject.eventFilter(self, object, event)
 
 
 class GUIToolkit(Toolkit):
-    """ Implementation class for PyQt toolkit.
-    """
+    """Implementation class for PyQt toolkit."""
 
     def ui_panel(self, ui, parent):
-        """ Creates a PyQt panel-based user interface using information
-            from the specified UI object.
+        """Creates a PyQt panel-based user interface using information
+        from the specified UI object.
         """
         from . import ui_panel
 
         ui_panel.ui_panel(ui, parent)
 
     def ui_subpanel(self, ui, parent):
-        """ Creates a PyQt subpanel-based user interface using information
-            from the specified UI object.
+        """Creates a PyQt subpanel-based user interface using information
+        from the specified UI object.
         """
         from . import ui_panel
 
         ui_panel.ui_subpanel(ui, parent)
 
     def ui_livemodal(self, ui, parent):
-        """ Creates a PyQt modal "live update" dialog user interface using
-            information from the specified UI object.
+        """Creates a PyQt modal "live update" dialog user interface using
+        information from the specified UI object.
         """
         from . import ui_live
 
         ui_live.ui_livemodal(ui, parent)
 
     def ui_live(self, ui, parent):
-        """ Creates a PyQt non-modal "live update" window user interface
-            using information from the specified UI object.
+        """Creates a PyQt non-modal "live update" window user interface
+        using information from the specified UI object.
         """
         from . import ui_live
 
         ui_live.ui_live(ui, parent)
 
     def ui_modal(self, ui, parent):
-        """ Creates a PyQt modal dialog user interface using information
-            from the specified UI object.
+        """Creates a PyQt modal dialog user interface using information
+        from the specified UI object.
         """
         from . import ui_modal
 
         ui_modal.ui_modal(ui, parent)
 
     def ui_nonmodal(self, ui, parent):
-        """ Creates a PyQt non-modal dialog user interface using
-            information from the specified UI object.
+        """Creates a PyQt non-modal dialog user interface using
+        information from the specified UI object.
         """
         from . import ui_modal
 
         ui_modal.ui_nonmodal(ui, parent)
 
     def ui_wizard(self, ui, parent):
-        """ Creates a PyQt wizard dialog user interface using information
-            from the specified UI object.
+        """Creates a PyQt wizard dialog user interface using information
+        from the specified UI object.
         """
         import ui_wizard
 
@@ -195,7 +201,7 @@ class GUIToolkit(Toolkit):
         scrollable=None,
         args=None,
     ):
-        """ Creates a PyQt modal dialog user interface that
+        """Creates a PyQt modal dialog user interface that
             runs as a complete application, using information from the
             specified View object.
 
@@ -233,8 +239,7 @@ class GUIToolkit(Toolkit):
         )
 
     def position(self, ui):
-        """ Positions the associated dialog window on the display.
-        """
+        """Positions the associated dialog window on the display."""
         view = ui.view
         window = ui.control
 
@@ -243,11 +248,11 @@ class GUIToolkit(Toolkit):
         if parent is None:
             px = 0
             py = 0
-            pdx = screen_dx
-            pdy = screen_dy
+            pdx = SystemMetrics().screen_width
+            pdy = SystemMetrics().screen_height
         else:
             pos = parent.pos()
-            if int(parent.windowFlags()) & QtCore.Qt.Window == 0:
+            if int(parent.windowFlags()) & QtCore.Qt.WindowType.Window == 0:
                 pos = parent.mapToGlobal(pos)
             px = pos.x()
             py = pos.y()
@@ -266,14 +271,14 @@ class GUIToolkit(Toolkit):
         if width < 0.0:
             width = cur_width
         elif width <= 1.0:
-            width = int(width * screen_dx)
+            width = int(width * SystemMetrics().screen_width)
         else:
             width = int(width)
 
         if height < 0.0:
             height = cur_height
         elif height <= 1.0:
-            height = int(height * screen_dy)
+            height = int(height * SystemMetrics().screen_height)
         else:
             height = int(height)
 
@@ -305,58 +310,52 @@ class GUIToolkit(Toolkit):
 
         # Position and size the window as requested:
         layout = window.layout()
-        if layout.sizeConstraint() == QtGui.QLayout.SetFixedSize:
-            layout.setSizeConstraint(QtGui.QLayout.SetDefaultConstraint)
+        if layout.sizeConstraint() == QtGui.QLayout.SizeConstraint.SetFixedSize:
+            layout.setSizeConstraint(QtGui.QLayout.SizeConstraint.SetDefaultConstraint)
             window.move(max(0, x), max(0, y))
             window.setFixedSize(QtCore.QSize(width, height))
         else:
             window.setGeometry(max(0, x), max(0, y), width, height)
 
     def show_help(self, ui, control):
-        """ Shows a help window for a specified UI and control.
-        """
+        """Shows a help window for a specified UI and control."""
         from . import ui_panel
 
         ui_panel.show_help(ui, control)
 
     def save_window(self, ui):
-        """ Saves user preference information associated with a UI window.
-        """
+        """Saves user preference information associated with a UI window."""
         from . import helper
 
         helper.save_window(ui)
 
     def rebuild_ui(self, ui):
-        """ Rebuilds a UI after a change to the content of the UI.
-        """
+        """Rebuilds a UI after a change to the content of the UI."""
         if ui.control is not None:
             ui.recycle()
             ui.info.ui = ui
         ui.rebuild(ui, ui.parent)
 
     def set_title(self, ui):
-        """ Sets the title for the UI window.
-        """
+        """Sets the title for the UI window."""
         ui.control.setWindowTitle(ui.title)
 
     def set_icon(self, ui):
-        """ Sets the icon for the UI window.
-        """
+        """Sets the icon for the UI window."""
         from pyface.image_resource import ImageResource
 
         if isinstance(ui.icon, ImageResource):
             ui.control.setWindowIcon(ui.icon.create_icon())
 
     def key_event_to_name(self, event):
-        """ Converts a keystroke event into a corresponding key name.
-        """
+        """Converts a keystroke event into a corresponding key name."""
         from . import key_event_to_name
 
         return key_event_to_name.key_event_to_name(event)
 
     def hook_events(self, ui, control, events=None, handler=None):
-        """ Hooks all specified events for all controls in a UI so that they
-            can be routed to the correct event handler.
+        """Hooks all specified events for all controls in a UI so that they
+        can be routed to the correct event handler.
         """
         if events is None:
             # FIXME: Implement drag and drop events ala toolkit.py for wx
@@ -370,14 +369,13 @@ class GUIToolkit(Toolkit):
             control.installEventFilter(ui._key_event_hook)
 
     def skip_event(self, event):
-        """ Indicates that an event should continue to be processed by the
-            toolkit.
+        """Indicates that an event should continue to be processed by the
+        toolkit.
         """
         event.ignore()
 
     def destroy_control(self, control):
-        """ Destroys a specified GUI toolkit control.
-        """
+        """Destroys a specified GUI toolkit control."""
         # Block signals to prevent any editors from being updated (the control
         # will not be deleted immediately).
         control.blockSignals(True)
@@ -387,17 +385,9 @@ class GUIToolkit(Toolkit):
         control.hide()
         control.deleteLater()
 
-        # PyQt v4.3.1 and earlier deleteLater() didn't transfer ownership to
-        # C++, which is necessary for the QObject system to garbage collect it.
-        if qt_api == "pyqt":
-            if QtCore.PYQT_VERSION < 0x040302:
-                import sip
-
-                sip.transferto(control, None)
-
     def destroy_children(self, control):
-        """ Destroys all of the child controls of a specified GUI toolkit
-            control.
+        """Destroys all of the child controls of a specified GUI toolkit
+        control.
         """
         for w in control.children():
             # Only destroy widgets.
@@ -407,22 +397,22 @@ class GUIToolkit(Toolkit):
                 w.deleteLater()
 
     def image_size(self, image):
-        """ Returns a ( width, height ) tuple containing the size of a
-            specified toolkit image.
+        """Returns a ( width, height ) tuple containing the size of a
+        specified toolkit image.
         """
         return (image.width(), image.height())
 
     def constants(self):
-        """ Returns a dictionary of useful constants.
+        """Returns a dictionary of useful constants.
 
-            Currently, the dictionary should have the following key/value pairs:
+        Currently, the dictionary should have the following key/value pairs:
 
-            - 'WindowColor': the standard window background color in the toolkit
-              specific color format.
+        - 'WindowColor': the standard window background color in the toolkit
+          specific color format.
         """
         return {
             "WindowColor": QtGui.QApplication.palette().color(
-                QtGui.QPalette.Window
+                QtGui.QPalette.ColorRole.Window
             )
         }
 
@@ -440,238 +430,3 @@ class GUIToolkit(Toolkit):
         from . import font_trait as ft
 
         return ft.PyQtFont(*args, **traits)
-
-    # -------------------------------------------------------------------------
-    #  'Editor' class methods:
-    # -------------------------------------------------------------------------
-
-    # Generic UI-base editor:
-    def ui_editor(self):
-        from . import ui_editor
-
-        return ui_editor.UIEditor
-
-    # -------------------------------------------------------------------------
-    #  'EditorFactory' factory methods:
-    # -------------------------------------------------------------------------
-
-    # Array:
-    def array_editor(self, *args, **traits):
-        from . import array_editor as ae
-
-        return ae.ToolkitEditorFactory(*args, **traits)
-
-    # Boolean:
-    def boolean_editor(self, *args, **traits):
-        from . import boolean_editor as be
-
-        return be.ToolkitEditorFactory(*args, **traits)
-
-    # Button:
-    def button_editor(self, *args, **traits):
-        from . import button_editor as be
-
-        return be.ToolkitEditorFactory(*args, **traits)
-
-    # Check list:
-    def check_list_editor(self, *args, **traits):
-        from . import check_list_editor as cle
-
-        return cle.ToolkitEditorFactory(*args, **traits)
-
-    # Code:
-    def code_editor(self, *args, **traits):
-        from . import code_editor as ce
-
-        return ce.ToolkitEditorFactory(*args, **traits)
-
-    # Color:
-    def color_editor(self, *args, **traits):
-        from . import color_editor as ce
-
-        return ce.ToolkitEditorFactory(*args, **traits)
-
-    # Compound:
-    def compound_editor(self, *args, **traits):
-        from . import compound_editor as ce
-
-        return ce.ToolkitEditorFactory(*args, **traits)
-
-    def styled_date_editor(self, *args, **traits):
-        from . import styled_date_editor as sde
-
-        return sde.ToolkitEditorFactory(*args, **traits)
-
-    # Custom:
-    def custom_editor(self, *args, **traits):
-        from . import custom_editor as ce
-
-        return ce.ToolkitEditorFactory(*args, **traits)
-
-    # Directory:
-    def directory_editor(self, *args, **traits):
-        from . import directory_editor as de
-
-        return de.ToolkitEditorFactory(*args, **traits)
-
-    # Drop (drag and drop target):
-    def drop_editor(self, *args, **traits):
-        from . import drop_editor as de
-
-        return de.ToolkitEditorFactory(*args, **traits)
-
-    # Drag and drop:
-    def dnd_editor(self, *args, **traits):
-        import dnd_editor as dnd
-
-        return dnd.ToolkitEditorFactory(*args, **traits)
-
-    # Enum(eration):
-    def enum_editor(self, *args, **traits):
-        from . import enum_editor as ee
-
-        return ee.ToolkitEditorFactory(*args, **traits)
-
-    # File:
-    def file_editor(self, *args, **traits):
-        from . import file_editor as fe
-
-        return fe.ToolkitEditorFactory(*args, **traits)
-
-    # Font:
-    def font_editor(self, *args, **traits):
-        from . import font_editor as fe
-
-        return fe.ToolkitEditorFactory(*args, **traits)
-
-    # Key Binding:
-    def key_binding_editor(self, *args, **traits):
-        from . import key_binding_editor as kbe
-
-        return kbe.ToolkitEditorFactory(*args, **traits)
-
-    # History:
-    def history_editor(self, *args, **traits):
-        from . import history_editor as he
-
-        return he.HistoryEditor(*args, **traits)
-
-    # HTML:
-    def html_editor(self, *args, **traits):
-        from . import html_editor as he
-
-        return he.ToolkitEditorFactory(*args, **traits)
-
-    # Image:
-    def image_editor(self, *args, **traits):
-        from . import image_editor as ie
-
-        return ie.ImageEditor(*args, **traits)
-
-    # Image enum(eration):
-    def image_enum_editor(self, *args, **traits):
-        from . import image_enum_editor as iee
-
-        return iee.ToolkitEditorFactory(*args, **traits)
-
-    # Instance:
-    def instance_editor(self, *args, **traits):
-        from . import instance_editor as ie
-
-        return ie.ToolkitEditorFactory(*args, **traits)
-
-    # List:
-    def list_editor(self, *args, **traits):
-        from . import list_editor as le
-
-        return le.ToolkitEditorFactory(*args, **traits)
-
-    # ListStr:
-    def list_str_editor(self, *args, **traits):
-        from . import list_str_editor as lse
-
-        return lse.ListStrEditor(*args, **traits)
-
-    # Null:
-    def null_editor(self, *args, **traits):
-        from . import null_editor as ne
-
-        return ne.ToolkitEditorFactory(*args, **traits)
-
-    # Ordered set:
-    def ordered_set_editor(self, *args, **traits):
-        import ordered_set_editor as ose
-
-        return ose.ToolkitEditorFactory(*args, **traits)
-
-    # Plot:
-    def plot_editor(self, *args, **traits):
-        import plot_editor as pe
-
-        return pe.ToolkitEditorFactory(*args, **traits)
-
-    # Range:
-    def range_editor(self, *args, **traits):
-        from . import range_editor as re
-
-        return re.ToolkitEditorFactory(*args, **traits)
-
-    # RGB Color:
-    def rgb_color_editor(self, *args, **traits):
-        from . import rgb_color_editor as rgbce
-
-        return rgbce.ToolkitEditorFactory(*args, **traits)
-
-    # Set:
-    def set_editor(self, *args, **traits):
-        from . import set_editor as se
-
-        return se.ToolkitEditorFactory(*args, **traits)
-
-    # Shell:
-    def shell_editor(self, *args, **traits):
-        from . import shell_editor as se
-
-        return se.ToolkitEditorFactory(*args, **traits)
-
-    # Table:
-    def table_editor(self, *args, **traits):
-        from . import table_editor as te
-
-        return te.ToolkitEditorFactory(*args, **traits)
-
-    # Tabular:
-    def tabular_editor(self, *args, **traits):
-        from . import tabular_editor as te
-
-        return te.TabularEditor(*args, **traits)
-
-    # Text:
-    def text_editor(self, *args, **traits):
-        from . import text_editor as te
-
-        return te.ToolkitEditorFactory(*args, **traits)
-
-    # Title:
-    def title_editor(self, *args, **traits):
-        from . import title_editor
-
-        return title_editor.TitleEditor(*args, **traits)
-
-    # Tree:
-    def tree_editor(self, *args, **traits):
-        from . import tree_editor as te
-
-        return te.ToolkitEditorFactory(*args, **traits)
-
-    # Tuple:
-    def tuple_editor(self, *args, **traits):
-        from . import tuple_editor as te
-
-        return te.ToolkitEditorFactory(*args, **traits)
-
-    # Value:
-    def value_editor(self, *args, **traits):
-        from . import value_editor as ve
-
-        return ve.ToolkitEditorFactory(*args, **traits)
