@@ -1,3 +1,13 @@
+# (C) Copyright 2008-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
 # All rights reserved.
@@ -14,13 +24,7 @@
 """
 
 
-# FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
-# compatibility. The class has been moved to the
-# traitsui.editors.tuple_editor file.
-from traitsui.editors.tuple_editor import (
-    SimpleEditor as BaseSimpleEditor,
-    ToolkitEditorFactory,
-)
+from traitsui.editors.tuple_editor import SimpleEditor as BaseSimpleEditor
 
 from .editor import Editor
 
@@ -30,7 +34,7 @@ from .editor import Editor
 
 
 class SimpleEditor(BaseSimpleEditor, Editor):
-    """ Simple style of editor for tuples.
+    """Simple style of editor for tuples.
 
     The editor displays an editor for each of the fields in the tuple, based on
     the type of each field.
