@@ -1,4 +1,4 @@
-# (C) Copyright 2008-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2008-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -25,7 +25,9 @@
 
 
 from pyface.qt import QtCore, QtGui
-
+from pyface.action.schema.api import (
+    ActionManagerBuilder, MenuBarSchema, ToolBarSchema,
+)
 from traits.api import HasPrivateTraits, Instance
 
 from traitsui.base_panel import BasePanel as _BasePanel
@@ -36,8 +38,7 @@ from .helper import restore_window, save_window
 
 
 class ButtonEditor(Editor):
-    """ Editor for buttons.
-    """
+    """Editor for buttons."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -51,15 +52,13 @@ class ButtonEditor(Editor):
         HasPrivateTraits.__init__(self, **traits)
 
     def perform(self):
-        """ Handles the associated button being clicked.
-        """
+        """Handles the associated button being clicked."""
         handler = self.ui.handler
         self.ui.do_undoable(handler.perform, self.ui.info, self.action, None)
 
 
 class BasePanel(_BasePanel):
-    """Base class for Traits UI panels.
-    """
+    """Base class for Traits UI panels."""
 
     def add_button(
         self,
@@ -71,8 +70,7 @@ class BasePanel(_BasePanel):
         name=None,
         default=False,
     ):
-        """ Creates a button.
-        """
+        """Creates a button."""
         ui = self.ui
         if (action.defined_when != "") and (
             not ui.eval_when(action.defined_when)
@@ -106,20 +104,17 @@ class BasePanel(_BasePanel):
         return button
 
     def _on_undoable(self, event):
-        """Handles a change to the "undoable" state of the undo history
-        """
+        """Handles a change to the "undoable" state of the undo history"""
         state = event.new
         self.undo.setEnabled(state)
 
     def _on_redoable(self, event):
-        """Handles a change to the "redoable" state of the undo history.
-        """
+        """Handles a change to the "redoable" state of the undo history."""
         state = event.new
         self.redo.setEnabled(state)
 
     def _on_revertable(self, event):
-        """ Handles a change to the "revert" state.
-        """
+        """Handles a change to the "revert" state."""
         state = event.new
         self.revert.setEnabled(state)
 
@@ -148,16 +143,18 @@ class _StickyDialog(QtGui.QDialog):
         # _StickyDialog open where one has a Window flag and other has a Dialog
         # flag results in the latter (Dialog) to be always placed on top of
         # the former (Window).
-        flags = QtCore.Qt.Window
+        flags = QtCore.Qt.WindowType.Window
         if not ui.view.resizable:
-            flags |= QtCore.Qt.WindowSystemMenuHint
-            layout.setSizeConstraint(QtGui.QLayout.SetFixedSize)
+            flags |= QtCore.Qt.WindowType.WindowSystemMenuHint
+            layout.setSizeConstraint(QtGui.QLayout.SizeConstraint.SetFixedSize)
         try:
-            flags |= QtCore.Qt.WindowCloseButtonHint
+            flags |= QtCore.Qt.WindowType.WindowCloseButtonHint
             if ui.view.resizable:
-                flags |= (
-                    QtCore.Qt.WindowMinimizeButtonHint
-                    | QtCore.Qt.WindowMaximizeButtonHint
+                # Cast to int to deal with cast-to-int deprecation warning on
+                # PyQt5 5.12.3
+                flags |= int(
+                    QtCore.Qt.WindowType.WindowMinimizeButtonHint
+                    | QtCore.Qt.WindowType.WindowMaximizeButtonHint
                 )
         except AttributeError:
             # Either PyQt or Qt is too old.
@@ -186,25 +183,24 @@ class _StickyDialog(QtGui.QDialog):
         the Enter key if no default button has been explicitly set."""
 
         if (
-            e.key() in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return)
+            e.key() in (QtCore.Qt.Key.Key_Enter, QtCore.Qt.Key.Key_Return)
             and not self._ui.view.default_button
         ):
             return
 
-        if e.key() == QtCore.Qt.Key_Escape and not self._ok_to_close():
+        if e.key() == QtCore.Qt.Key.Key_Escape and not self._ok_to_close():
             return
 
         QtGui.QDialog.keyPressEvent(self, e)
 
     def sizeHint(self):
-        """Reimplemented to provide an appropriate size hint for the window.
-        """
+        """Reimplemented to provide an appropriate size hint for the window."""
         size = QtGui.QDialog.sizeHint(self)
         view = self._ui.view
         if view.width > 0:
-            size.setWidth(view.width)
+            size.setWidth(int(view.width))
         if view.height > 0:
-            size.setHeight(view.height)
+            size.setHeight(int(view.height))
         return size
 
     def done(self, r):
@@ -320,7 +316,7 @@ class BaseDialog(BasePanel):
         if style == BaseDialog.NONMODAL:
             ui.control.show()
         else:
-            ui.control.setWindowModality(QtCore.Qt.ApplicationModal)
+            ui.control.setWindowModality(QtCore.Qt.WindowModality.ApplicationModal)
             ui.control.exec_()
 
     def set_icon(self, icon=None):
@@ -339,9 +335,11 @@ class BaseDialog(BasePanel):
         self.ok.setEnabled(errors == 0)
 
     def _add_menubar(self):
-        """Adds a menu bar to the dialog.
-        """
+        """Adds a menu bar to the dialog."""
         menubar = self.ui.view.menubar
+        if isinstance(menubar, MenuBarSchema):
+            builder = self.ui.view.action_manager_builder
+            menubar = builder.create_action_manager(menubar)
         if menubar is not None:
             self._last_group = self._last_parent = None
             self.control.layout().setMenuBar(
@@ -350,9 +348,11 @@ class BaseDialog(BasePanel):
             self._last_group = self._last_parent = None
 
     def _add_toolbar(self):
-        """ Adds a toolbar to the dialog.
-        """
+        """Adds a toolbar to the dialog."""
         toolbar = self.ui.view.toolbar
+        if isinstance(toolbar, ToolBarSchema):
+            builder = self.ui.view.action_manager_builder
+            toolbar = builder.create_action_manager(toolbar)
         if toolbar is not None:
             self._last_group = self._last_parent = None
             qt_toolbar = toolbar.create_tool_bar(self.control, self)
@@ -361,8 +361,7 @@ class BaseDialog(BasePanel):
             self._last_group = self._last_parent = None
 
     def _add_statusbar(self):
-        """ Adds a statusbar to the dialog.
-        """
+        """Adds a statusbar to the dialog."""
         if self.ui.view.statusbar is not None:
             control = QtGui.QStatusBar()
             control.setSizeGripEnabled(self.ui.view.resizable)
@@ -379,7 +378,7 @@ class BaseDialog(BasePanel):
                 if width <= 1.0:
                     stretch = int(100 * width)
                 else:
-                    item_control.setMinimumWidth(width)
+                    item_control.setMinimumWidth(int(width))
                 control.addWidget(item_control, stretch)
 
                 # Set up event listener for updating the status text
@@ -397,8 +396,7 @@ class BaseDialog(BasePanel):
             self.ui._statusbar = listeners
 
     def _set_status_text(self, control):
-        """ Helper function for _add_statusbar.
-        """
+        """Helper function for _add_statusbar."""
 
         def set_status_text(event):
             text = event.new
