@@ -1,25 +1,17 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   07/01/2005
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the filter object used to filter items displayed in a table editor.
 """
 
 
-
 from traits.api import (
     Any,
     Bool,
@@ -35,7 +27,6 @@ from traits.api import (
 )
 
 from .editor_factory import EditorFactory
-from .editors.api import EnumEditor
 from .group import Group
 from .include import Include
 from .item import Item
@@ -64,8 +55,7 @@ GenericTableFilterRuleOperation = Trait(
 
 
 class TableFilter(HasPrivateTraits):
-    """ Filter for items displayed in a table.
-    """
+    """Filter for items displayed in a table."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -139,24 +129,23 @@ class TableFilter(HasPrivateTraits):
     filter_view = Group()
 
     def filter(self, object):
-        """ Returns whether a specified object meets the filter or search
+        """Returns whether a specified object meets the filter or search
         criteria.
         """
         return self.allowed(object)
 
     def description(self):
-        """ Returns a user-readable description of what kind of object
+        """Returns a user-readable description of what kind of object
         satisfies the filter.
         """
         return self.desc
 
     def edit(self, object):
-        """ Edits the contents of the filter.
-        """
+        """Edits the contents of the filter."""
         return self.edit_traits(view=self.edit_view(object), kind="livemodal")
 
     def edit_view(self, object):
-        """ Return a view to use for editing the filter.
+        """Return a view to use for editing the filter.
 
         The ''object'' parameter is a sample object for the table that the
         filter will be applied to. It is supplied in case the filter needs to
@@ -184,8 +173,7 @@ class TableFilter(HasPrivateTraits):
 
 
 class EvalTableFilter(TableFilter):
-    """ A table filter based on evaluating an expression.
-    """
+    """A table filter based on evaluating an expression."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -204,26 +192,27 @@ class EvalTableFilter(TableFilter):
     filter_view = Group("expression")
 
     def filter(self, object):
-        """ Returns whether a specified object meets the filter or search
+        """Returns whether a specified object meets the filter or search
         criteria.
         """
         if self._traits is None:
             self._traits = object.trait_names()
         try:
-            return eval(self.expression_, globals(), object.trait_get(*self._traits))
+            return eval(
+                self.expression_, globals(), object.trait_get(*self._traits)
+            )
         except:
             return False
 
     def description(self):
-        """ Returns a user readable description of what kind of object
-            satisfies the filter.
+        """Returns a user readable description of what kind of object
+        satisfies the filter.
         """
         return self.expression
 
 
 class GenericTableFilterRule(HasPrivateTraits):
-    """ A general rule used by a table filter.
-    """
+    """A general rule used by a table filter."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -261,20 +250,19 @@ class GenericTableFilterRule(HasPrivateTraits):
     ignored_traits = ["filter", "name_editor", "value_editor"]
 
     def __init__(self, **traits):
-        super(GenericTableFilterRule, self).__init__(**traits)
+        super().__init__(**traits)
         if self.name == "":
-            names = list(self.filter._trait_values.keys())
+            names = list(self.filter._name_to_value.keys())
             if len(names) > 0:
                 names.sort()
                 self.name = names[0]
                 self.enabled = False
 
     def _name_changed(self, name):
-        """ Handles a change to the value of the **name** trait.
-        """
+        """Handles a change to the value of the **name** trait."""
         filter = self.filter
         if (filter is not None) and (filter._object is not None):
-            self.value = filter._trait_values.get(name)
+            self.value = filter._name_to_value.get(name)
             self.value_editor = filter._object.base_trait(name).get_editor()
 
     # -------------------------------------------------------------------------
@@ -288,22 +276,20 @@ class GenericTableFilterRule(HasPrivateTraits):
                 self.enabled = True
 
     def clone_traits(self, traits=None, memo=None, copy=None, **metadata):
-        """ Clones a new object from this one, optionally copying only a
+        """Clones a new object from this one, optionally copying only a
         specified set of traits."""
         return (
-            super(GenericTableFilterRule, self)
+            super()
             .clone_traits(traits, memo, copy, **metadata)
             .trait_set(enabled=self.enabled, name=self.name)
         )
 
     def description(self):
-        """ Returns a description of the filter.
-        """
+        """Returns a description of the filter."""
         return "%s %s %s" % (self.name, self.operation, self.value)
 
     def is_true(self, object):
-        """ Returns whether the rule is true for a specified object.
-        """
+        """Returns whether the rule is true for a specified object."""
         try:
             value1 = getattr(object, self.name)
             type1 = type(value1)
@@ -347,48 +333,41 @@ class GenericTableFilterRule(HasPrivateTraits):
 
 
 class GenericTableFilterRuleEnabledColumn(ObjectColumn):
-    """ Table column that indicates whether a filter rule is enabled.
-    """
+    """Table column that indicates whether a filter rule is enabled."""
 
     def get_value(self, object):
-        """ Returns the traits editor of the column for a specified object.
-        """
+        """Returns the traits editor of the column for a specified object."""
         if hasattr(object, "enabled") and object.enabled:
-            return u"\N{HEAVY CHECK MARK}"
+            return "\N{HEAVY CHECK MARK}"
         else:
             return ""
 
 
 class GenericTableFilterRuleAndOrColumn(ObjectColumn):
-    """ Table column that displays whether a filter rule is conjoining ('and')
-        or disjoining ('or').
+    """Table column that displays whether a filter rule is conjoining ('and')
+    or disjoining ('or').
     """
 
     def get_value(self, object):
-        """ Returns the traits editor of the column for a specified object.
-        """
+        """Returns the traits editor of the column for a specified object."""
         if object.and_or == "or":
             return "or"
         return ""
 
 
 class GenericTableFilterRuleNameColumn(ObjectColumn):
-    """ Table column for the name of an object trait.
-    """
+    """Table column for the name of an object trait."""
 
     def get_editor(self, object):
-        """ Returns the traits editor of the column for a specified object.
-        """
+        """Returns the traits editor of the column for a specified object."""
         return object.name_editor
 
 
 class GenericTableFilterRuleValueColumn(ObjectColumn):
-    """ Table column for the value of an object trait.
-    """
+    """Table column for the value of an object trait."""
 
     def get_editor(self, object):
-        """ Returns the traits editor of the column for a specified object.
-        """
+        """Returns the traits editor of the column for a specified object."""
         return object.value_editor
 
 
@@ -406,8 +385,7 @@ generic_table_filter_rule_columns = [
 
 
 class RuleTableFilter(TableFilter):
-    """ A table filter based on rules.
-    """
+    """A table filter based on rules."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -429,7 +407,7 @@ class RuleTableFilter(TableFilter):
     _object = Any()
 
     #: Map of trait names and default values
-    _trait_values = Any()
+    _name_to_value = Any()
 
     # -------------------------------------------------------------------------
     #  Traits view definitions:
@@ -447,7 +425,7 @@ class RuleTableFilter(TableFilter):
     )
 
     def filter(self, object):
-        """ Returns whether a specified object meets the filter or search
+        """Returns whether a specified object meets the filter or search
         criteria.
         """
         is_first = is_true = True
@@ -462,8 +440,8 @@ class RuleTableFilter(TableFilter):
         return is_true
 
     def description(self):
-        """ Returns a user-readable description of the kind of object that
-            satisfies the filter.
+        """Returns a user-readable description of the kind of object that
+        satisfies the filter.
         """
         ors = []
         ands = []
@@ -484,10 +462,10 @@ class RuleTableFilter(TableFilter):
         if len(ors) > 1:
             return " or ".join(["(%s)" % t for t in ors])
 
-        return super(RuleTableFilter, self).description()
+        return super().description()
 
     def edit_view(self, object):
-        """ Return a view to use for editing the filter.
+        """Return a view to use for editing the filter.
 
         The ''object'' parameter is a sample object for the table that the
         filter will be applied to. It is supplied in case the filter needs to
@@ -499,7 +477,7 @@ class RuleTableFilter(TableFilter):
             return self.edit_traits(view="error_view")
 
         names = object.editable_traits()
-        self._trait_values = object.get(names)
+        self._name_to_value = object.get(names)
         return View(
             [
                 ["name{Filter name}", "_"],
@@ -522,9 +500,9 @@ class RuleTableFilter(TableFilter):
         )
 
     def _get_table_editor(self, names):
-        """ Returns a table editor to use for editing the filter.
-        """
-        from .api import TableEditor
+        """Returns a table editor to use for editing the filter."""
+        from traitsui.api import TableEditor
+        from traitsui.editors.api import EnumEditor
 
         return TableEditor(
             columns=generic_table_filter_rule_columns,
@@ -542,19 +520,18 @@ class RuleTableFilter(TableFilter):
         )
 
     def __getstate__(self):
-        """ Returns the state to be pickled.
+        """Returns the state to be pickled.
 
         This definition overrides **object**.
         """
         dict = self.__dict__.copy()
         if "_object" in dict:
             del dict["_object"]
-            del dict["_trait_values"]
+            del dict["_name_to_value"]
         return dict
 
     def _rules_changed(self, rules):
-        """ Handles a change to the **rules** trait.
-        """
+        """Handles a change to the **rules** trait."""
         for rule in rules:
             rule.filter = self
 
@@ -573,8 +550,7 @@ menu_table_filter_rule_columns = [
 
 
 class MenuTableFilter(RuleTableFilter):
-    """ A table filter based on a menu of rules.
-    """
+    """A table filter based on a menu of rules."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -587,7 +563,7 @@ class MenuTableFilter(RuleTableFilter):
     view_id = Str("traitsui.table_filter.MenuTableFilter")
 
     def filter(self, object):
-        """ Returns whether a specified object meets the filter or search
+        """Returns whether a specified object meets the filter or search
         criteria.
         """
         for rule in self.rules:
@@ -596,8 +572,8 @@ class MenuTableFilter(RuleTableFilter):
         return True
 
     def description(self):
-        """ Returns a user8readable description of what kind of object
-            satisfies the filter.
+        """Returns a user8readable description of what kind of object
+        satisfies the filter.
         """
         result = " and ".join(
             [rule.description() for rule in self.rules if rule.enabled]
@@ -607,9 +583,9 @@ class MenuTableFilter(RuleTableFilter):
         return "All items"
 
     def _get_table_editor(self, names):
-        """ Returns a table editor to use for editing the filter.
-        """
+        """Returns a table editor to use for editing the filter."""
         from .api import TableEditor
+        from .editors.api import EnumEditor
 
         names = self._object.editable_traits()
         name_editor = EnumEditor(values=names)
