@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -17,7 +17,7 @@ from traitsui.testing.tester._ui_tester_registry.wx._registry_helper import (
 
 
 def register(registry):
-    """ Register interactions for the given registry.
+    """Register interactions for the given registry.
 
     If there are any conflicts, an error will occur.
 
@@ -36,7 +36,7 @@ def register(registry):
     registry.register_interaction(
         target_class=ReadonlyEditor,
         interaction_class=DisplayedText,
-        handler=lambda wrapper, _:
-            _interaction_helpers.readonly_textbox_displayed_text(
-                wrapper._target.control),
+        handler=lambda wrapper, _: _interaction_helpers.readonly_textbox_displayed_text(
+            wrapper._target.control
+        ),
     )
