@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -37,8 +37,7 @@ from traitsui.tests._tools import (
 
 
 class NumberWithSpinnerEditor(HasTraits):
-    """Dialog containing a RangeEditor in 'spinner' mode for an Int.
-    """
+    """Dialog containing a RangeEditor in 'spinner' mode for an Int."""
 
     number = Int()
 
@@ -50,7 +49,6 @@ class NumberWithSpinnerEditor(HasTraits):
 
 
 class TestRangeEditorSpinner(BaseTestMixin, unittest.TestCase):
-
     def setUp(self):
         BaseTestMixin.setUp(self)
 
