@@ -1,26 +1,18 @@
-# -------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2007-19, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   07/13/2007
-#
-# -------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines 'theme' related classes.
 """
 
-
-
 from traits.api import HasPrivateTraits, Property, cached_property
+from traits.etsconfig.api import ETSConfig
 
 from .ui_traits import Image, HasBorder, HasMargin, Alignment
 
@@ -51,30 +43,30 @@ class Theme(HasPrivateTraits):
     label_color = Property()
 
     #: The image slice used to draw the theme (Wx only)
-    image_slice = Property(depends_on="image")
+    image_slice = Property(observe="image")
 
     # -- Constructor ----------------------------------------------------------
 
     def __init__(self, image=None, **traits):
-        """ Initializes the object.
-        """
+        """Initializes the object."""
         if image is not None:
             self.image = image
 
-        super(Theme, self).__init__(**traits)
+        super().__init__(**traits)
 
     # -- Property Implementations ---------------------------------------------
 
     def _get_content_color(self):
-        import wx
+        if ETSConfig.toolkit == "wx":
+            import wx
 
-        if self._content_color is None:
-            color = wx.BLACK
-            islice = self.image_slice
-            if islice is not None:
-                color = islice.content_color
+            if self._content_color is None:
+                color = wx.BLACK
+                islice = self.image_slice
+                if islice is not None:
+                    color = islice.content_color
 
-            self._content_color = color
+                self._content_color = color
 
         return self._content_color
 
@@ -82,15 +74,16 @@ class Theme(HasPrivateTraits):
         self._content_color = color
 
     def _get_label_color(self):
-        import wx
+        if ETSConfig.toolkit == "wx":
+            import wx
 
-        if self._label_color is None:
-            color = wx.BLACK
-            islice = self.image_slice
-            if islice is not None:
-                color = islice.label_color
+            if self._label_color is None:
+                color = wx.BLACK
+                islice = self.image_slice
+                if islice is not None:
+                    color = islice.label_color
 
-            self._label_color = color
+                self._label_color = color
 
         return self._label_color
 
@@ -99,12 +92,13 @@ class Theme(HasPrivateTraits):
 
     @cached_property
     def _get_image_slice(self):
-        from traitsui.wx.image_slice import image_slice_for
-
         if self.image is None:
             return None
 
-        return image_slice_for(self.image)
+        if ETSConfig.toolkit == "wx":
+            from traitsui.wx.image_slice import image_slice_for
+
+            return image_slice_for(self.image)
 
 
 #: The default theme:
