@@ -1,13 +1,15 @@
-#  Copyright (c) 2015, Enthought, Inc.
-#  All rights reserved.
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 import logging
+import warnings
 
 from traits.api import (
     Bool,
@@ -18,7 +20,7 @@ from traits.api import (
     Property,
     Str,
     Tuple,
-    Either,
+    Union,
 )
 
 from traitsui.basic_editor_factory import BasicEditorFactory
@@ -31,13 +33,11 @@ from traitsui.ui_editor import UIEditor
 from traitsui.view import View
 
 
-
 logger = logging.getLogger(__name__)
 
 
 class DataFrameAdapter(TabularAdapter):
-    """ Generic tabular adapter for data frames
-    """
+    """Generic tabular adapter for data frames"""
 
     #: The text to use for a generic entry.
     text = Property()
@@ -58,10 +58,10 @@ class DataFrameAdapter(TabularAdapter):
     format = Property()
 
     #: The format for each element, or a mapping column ID to format.
-    _formats = Either(Str, Dict, default="%s")
+    _formats = Union(Str, Dict, default_value="%s")
 
     #: The font for each element, or a mapping column ID to font.
-    _fonts = Either(Font, Dict, default="Courier 10")
+    _fonts = Union(Font, Dict, default_value="Courier 10")
 
     def _get_index_alignment(self):
         import numpy as np
@@ -114,7 +114,7 @@ class DataFrameAdapter(TabularAdapter):
                 value,
                 self.column,
                 self.row,
-                exc_info=True
+                exc_info=True,
             )
 
     def _get_index_text(self):
@@ -128,15 +128,13 @@ class DataFrameAdapter(TabularAdapter):
             index.values[self.row] = value
         except Exception:
             logger.debug(
-                "User entered invalid value %r for index",
-                value,
-                exc_info=True
+                "User entered invalid value %r for index", value, exc_info=True
             )
 
     # ---- Adapter methods that are not sensitive to item type ----------------
 
     def get_item(self, object, trait, row):
-        """ Override the base implementation to work with DataFrames
+        """Override the base implementation to work with DataFrames
 
         This returns a dataframe with one row, rather than a series, since
         using a dataframe preserves dtypes.
@@ -145,7 +143,7 @@ class DataFrameAdapter(TabularAdapter):
         return getattr(object, trait).iloc[row : row + 1]
 
     def delete(self, object, trait, row):
-        """ Override the base implementation to work with DataFrames
+        """Override the base implementation to work with DataFrames
 
         Unavoidably does a copy of the data, setting the trait with the new
         value.
@@ -162,7 +160,7 @@ class DataFrameAdapter(TabularAdapter):
         setattr(object, trait, new_df)
 
     def insert(self, object, trait, row, value):
-        """ Override the base implementation to work with DataFrames
+        """Override the base implementation to work with DataFrames
 
         Unavoidably does a copy of the data, setting the trait with the new
         value.
@@ -180,7 +178,7 @@ class DataFrameAdapter(TabularAdapter):
 
 
 class _DataFrameEditor(UIEditor):
-    """ TraitsUI-based editor implementation for data frames """
+    """TraitsUI-based editor implementation for data frames"""
 
     #: Indicate that the editor is scrollable/resizable:
     scrollable = True
@@ -200,8 +198,7 @@ class _DataFrameEditor(UIEditor):
             return ""
 
     def _data_frame_view(self):
-        """ Return the view used by the editor.
-        """
+        """Return the view used by the editor."""
 
         return View(
             Item(
@@ -225,7 +222,9 @@ class _DataFrameEditor(UIEditor):
                     scroll_to_row=self._target_name(
                         self.factory.scroll_to_row
                     ),  # noqa
-                    scroll_to_row_hint=self.factory.scroll_to_row_hint,
+                    scroll_to_position_hint=(
+                        self.factory.scroll_to_position_hint
+                    ),
                     scroll_to_column=self._target_name(
                         self.factory.scroll_to_column
                     ),  # noqa
@@ -251,8 +250,7 @@ class _DataFrameEditor(UIEditor):
         )
 
     def init_ui(self, parent):
-        """ Creates the Traits UI for displaying the array.
-        """
+        """Creates the Traits UI for displaying the array."""
         factory = self.factory
         if factory.columns != []:
             columns = []
@@ -293,7 +291,7 @@ class _DataFrameEditor(UIEditor):
 
 
 class DataFrameEditor(BasicEditorFactory):
-    """ Editor factory for basic data frame editor """
+    """Editor factory for basic data frame editor"""
 
     #: The editor implementation class.
     klass = Property()
@@ -305,13 +303,13 @@ class DataFrameEditor(BasicEditorFactory):
     show_titles = Bool(True)
 
     #: Optional list of either column ID or pairs of (column title, column ID).
-    columns = List(Either(Str, Tuple(Str, Str)))
+    columns = List(Union(Str, Tuple(Str, Str)))
 
     #: The format for each element, or a mapping column ID to format.
-    formats = Either(Str, Dict, default="%s")
+    formats = Union(Str, Dict, default_value="%s")
 
     #: The font for each element, or a mapping column ID to font.
-    fonts = Either(Font, Dict, default="Courier 10")
+    fonts = Union(Font, Dict, default_value="Courier 10")
 
     #: The optional extended name of the trait to synchronize the selection
     #: values with:
@@ -347,8 +345,12 @@ class DataFrameEditor(BasicEditorFactory):
     #: trigger a scroll-to command. The data is an integer giving the row.
     scroll_to_row = Str()
 
-    #: Controls behavior of scroll to row
-    scroll_to_row_hint = Enum("center", "top", "bottom", "visible")
+    #: Deprecated: Controls behavior of scroll to row and scroll to column
+    scroll_to_row_hint = Property(Str, observe="scroll_to_position_hint")
+
+    #: (replacement of scroll_to_row_hint, but more clearly named)
+    #: Controls behavior of scroll to row and scroll to column
+    scroll_to_position_hint = Enum("visible", "center", "top", "bottom")
 
     #: The optional extended name of the Event trait that should be used to
     #: trigger a scroll-to command. The data is an integer giving the column.
@@ -391,6 +393,21 @@ class DataFrameEditor(BasicEditorFactory):
     adapter = Instance(DataFrameAdapter)
 
     def _get_klass(self):
-        """ The class used to construct editor objects.
-        """
+        """The class used to construct editor objects."""
         return toolkit_object("data_frame_editor:_DataFrameEditor")
+
+    def _get_scroll_to_row_hint(self):
+        warnings.warn(
+            "Use of scroll_to_row_hint trait is deprecated. "
+            "Use scroll_to_position_hint instead.",
+            DeprecationWarning,
+        )
+        return self.scroll_to_position_hint
+
+    def _set_scroll_to_row_hint(self, hint):
+        warnings.warn(
+            "Use of scroll_to_row_hint trait is deprecated. "
+            "Use scroll_to_position_hint instead.",
+            DeprecationWarning,
+        )
+        self.scroll_to_position_hint = hint
