@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/21/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the various editors for multi-selection enumerations, for the
 wxPython user interface toolkit.
@@ -26,11 +19,6 @@ import wx
 
 from traits.api import List, Str, TraitError
 
-# FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
-# compatibility. The class has been moved to the
-# traitsui.editors.check_list_editor file.
-from traitsui.editors.check_list_editor import ToolkitEditorFactory
-
 from .editor_factory import TextEditor as BaseTextEditor
 
 from .editor import EditorWithList
@@ -41,19 +29,13 @@ from functools import reduce
 
 logger = logging.getLogger(__name__)
 
-
-# default formatting function (would import from string, but not in Python 3)
-capitalize = lambda s: s.capitalize()
-
-
 # -------------------------------------------------------------------------
 #  'SimpleEditor' class:
 # -------------------------------------------------------------------------
 
 
 class SimpleEditor(EditorWithList):
-    """ Simple style of editor for checklists, which displays a combo box.
-    """
+    """Simple style of editor for checklists, which displays a combo box."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
@@ -66,30 +48,29 @@ class SimpleEditor(EditorWithList):
     values = List()
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         self.create_control(parent)
-        super(SimpleEditor, self).init(parent)
+        super().init(parent)
         self.set_tooltip()
 
     def dispose(self):
         self.control.Unbind(wx.EVT_CHOICE)
+        super().dispose()
 
     def create_control(self, parent):
-        """ Creates the initial editor control.
-        """
+        """Creates the initial editor control."""
         self.control = wx.Choice(
             parent, -1, wx.Point(0, 0), wx.Size(100, 20), []
         )
         self.control.Bind(wx.EVT_CHOICE, self.update_object)
 
     def list_updated(self, values):
-        """ Handles updates to the list of legal checklist values.
-        """
+        """Handles updates to the list of legal checklist values."""
         sv = self.string_value
         if (len(values) > 0) and isinstance(values[0], str):
-            values = [(x, sv(x, capitalize)) for x in values]
+            values = [(x, sv(x, str.capitalize)) for x in values]
         self.values = valid_values = [x[0] for x in values]
         self.names = [x[1] for x in values]
 
@@ -102,7 +83,7 @@ class SimpleEditor(EditorWithList):
                     del cur_value[i]
                     modified = True
                 except TypeError as e:
-                    logger.warn(
+                    logger.warning(
                         "Unable to remove non-current value [%s] from "
                         "values %s",
                         cur_value[i],
@@ -116,8 +97,7 @@ class SimpleEditor(EditorWithList):
         self.rebuild_editor()
 
     def rebuild_editor(self):
-        """ Rebuilds the editor after its definition is modified.
-        """
+        """Rebuilds the editor after its definition is modified."""
         control = self.control
         control.Clear()
         for name in self.names:
@@ -126,8 +106,7 @@ class SimpleEditor(EditorWithList):
         self.update_editor()
 
     def update_object(self, event):
-        """ Handles the user selecting a new value from the combo box.
-        """
+        """Handles the user selecting a new value from the combo box."""
         value = self.values[self.names.index(event.GetString())]
         if not isinstance(self.value, str):
             value = [value]
@@ -135,8 +114,8 @@ class SimpleEditor(EditorWithList):
         self.value = value
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         try:
             self.control.SetSelection(
@@ -152,19 +131,17 @@ class SimpleEditor(EditorWithList):
 
 
 class CustomEditor(SimpleEditor):
-    """ Custom style of editor for checklists, which displays a set of check
-        boxes.
+    """Custom style of editor for checklists, which displays a set of check
+    boxes.
     """
 
     def create_control(self, parent):
-        """ Creates the initial editor control.
-        """
+        """Creates the initial editor control."""
         # Create a panel to hold all of the check boxes
         self.control = panel = TraitsUIPanel(parent, -1)
 
     def rebuild_editor(self):
-        """ Rebuilds the editor after its definition is modified.
-        """
+        """Rebuilds the editor after its definition is modified."""
         panel = self.control
         panel.SetSizer(None)
         panel.DestroyChildren()
@@ -177,12 +154,19 @@ class CustomEditor(SimpleEditor):
         n = len(labels)
         cols = self.factory.cols
         rows = (n + cols - 1) // cols
+        # incr will keep track of how to increment index so that as we traverse
+        # the grid in row major order, the elements are added to appear in
+        # column major order
         incr = [n // cols] * cols
         rem = n % cols
 
         for i in range(cols):
             incr[i] += rem > i
         incr[-1] = -(reduce(lambda x, y: x + y, incr[:-1], 0) - 1)
+        # e.g for a gird:
+        # 0 2 4
+        # 1 3 5
+        # incr should be [2, 2, -3]
 
         if cols > 1:
             sizer = wx.GridSizer(0, cols, 2, 4)
@@ -191,6 +175,7 @@ class CustomEditor(SimpleEditor):
 
         # Add the set of all possible choices:
         index = 0
+        # populate the layout in row_major order
         for i in range(rows):
             for j in range(cols):
                 if n > 0:
@@ -198,7 +183,9 @@ class CustomEditor(SimpleEditor):
                     control = wx.CheckBox(panel, -1, label)
                     control.value = value = values[index]
                     control.SetValue(value in cur_value)
-                    panel.Bind(wx.EVT_CHECKBOX, self.update_object, id=control.GetId())
+                    panel.Bind(
+                        wx.EVT_CHECKBOX, self.update_object, id=control.GetId()
+                    )
                     index += incr[j]
                     n -= 1
                 else:
@@ -225,8 +212,7 @@ class CustomEditor(SimpleEditor):
         panel.Refresh()
 
     def update_object(self, event):
-        """ Handles the user clicking one of the custom check boxes.
-        """
+        """Handles the user clicking one of the custom check boxes."""
         control = event.GetEventObject()
         cur_value = parse_value(self.value)
         if control.GetValue():
@@ -238,8 +224,8 @@ class CustomEditor(SimpleEditor):
         self.value = cur_value
 
     def update_editor(self):
-        """ Updates the editor when the object trait changes externally to the
-            editor.
+        """Updates the editor when the object trait changes externally to the
+        editor.
         """
         new_values = parse_value(self.value)
         for control in self.control.GetChildren():
@@ -248,12 +234,10 @@ class CustomEditor(SimpleEditor):
 
 
 class TextEditor(BaseTextEditor):
-    """ Text style of editor for checklists, which displays a text field.
-    """
+    """Text style of editor for checklists, which displays a text field."""
 
     def update_object(self, event):
-        """ Handles the user changing the contents of the edit control.
-        """
+        """Handles the user changing the contents of the edit control."""
         try:
             value = self.control.GetValue()
             value = eval(value)
@@ -271,8 +255,7 @@ class TextEditor(BaseTextEditor):
 
 
 def parse_value(value):
-    """ Parses a value into a list.
-    """
+    """Parses a value into a list."""
     if value is None:
         return []
 
