@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/29/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines a wxPython ImageControl widget that is used by various trait
     editors to display trait values iconically.
@@ -24,8 +17,8 @@ import wx
 
 
 class ImageControl(wx.Window):
-    """ A wxPython control that displays an image, which can be selected or
-        unselected by mouse clicks.
+    """A wxPython control that displays an image, which can be selected or
+    unselected by mouse clicks.
     """
 
     #: Pens used to draw the 'selection' marker:
@@ -40,16 +33,15 @@ class ImageControl(wx.Window):
     def __init__(
         self, parent, bitmap, selected=None, handler=None, padding=10
     ):
-        """ Initializes the object.
-        """
-        wx.Window.__init__(
-            self,
-            parent,
-            -1,
-            size=wx.Size(
+        """Initializes the object."""
+        if bitmap is not None:
+            size = wx.Size(
                 bitmap.GetWidth() + padding, bitmap.GetHeight() + padding
-            ),
-        )
+            )
+        else:
+            size = wx.Size(32 + padding, 32 + padding)
+
+        wx.Window.__init__(self, parent, -1, size=size,)
         self._bitmap = bitmap
         self._selected = selected
         self._handler = handler
@@ -66,8 +58,7 @@ class ImageControl(wx.Window):
         self.Bind(wx.EVT_LEAVE_WINDOW, self._on_leave)
 
     def Selected(self, selected=None):
-        """ Gets or sets the selection state of the image.
-        """
+        """Gets or sets the selection state of the image."""
         if selected is not None:
             selected = selected != 0
             if selected != self._selected:
@@ -86,18 +77,18 @@ class ImageControl(wx.Window):
         return self._selected
 
     def Bitmap(self, bitmap=None):
-        """ Gets or sets the bitmap image.
-        """
+        """Gets or sets the bitmap image."""
         if bitmap is not None:
             if bitmap != self._bitmap:
                 self._bitmap = bitmap
                 self.Refresh()
+        else:
+            self._bitmap = None
 
         return self._bitmap
 
     def Handler(self, handler=None):
-        """ Gets or sets the click handler.
-        """
+        """Gets or sets the click handler."""
         if handler is not None:
             if handler != self._handler:
                 self._handler = handler
@@ -106,30 +97,26 @@ class ImageControl(wx.Window):
         return self._handler
 
     def _on_enter(self, event=None):
-        """ Handles the mouse entering the control.
-        """
+        """Handles the mouse entering the control."""
         if self._selected is not None:
             self._mouse_over = True
             self.Refresh()
 
     def _on_leave(self, event=None):
-        """ Handles the mouse leaving the control.
-        """
+        """Handles the mouse leaving the control."""
         if self._mouse_over:
             self._mouse_over = False
             self.Refresh()
 
     def _on_left_down(self, event=None):
-        """ Handles the user pressing the mouse button.
-        """
+        """Handles the user pressing the mouse button."""
         if self._selected is not None:
             self.CaptureMouse()
             self._button_down = True
             self.Refresh()
 
     def _on_left_up(self, event=None):
-        """ Handles the user clicking the control.
-        """
+        """Handles the user clicking the control."""
         need_refresh = self._button_down
         if need_refresh:
             self.ReleaseMouse()
@@ -152,11 +139,12 @@ class ImageControl(wx.Window):
             self.Refresh()
 
     def _on_paint(self, event=None):
-        """ Handles the control being re-painted.
-        """
+        """Handles the control being re-painted."""
         wdc = wx.PaintDC(self)
         wdx, wdy = self.GetClientSize()
         bitmap = self._bitmap
+        if bitmap is None:
+            return
         bdx = bitmap.GetWidth()
         bdy = bitmap.GetHeight()
         wdc.DrawBitmap(bitmap, (wdx - bdx) // 2, (wdy - bdy) // 2, True)
