@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -97,8 +97,7 @@ key_map = {
 
 
 def key_event_to_name(event):
-    """ Converts a keystroke event into a corresponding key name.
-    """
+    """Converts a keystroke event into a corresponding key name."""
     key_code = event.GetKeyCode()
     if event.ControlDown() and (1 <= key_code <= 26):
         key = chr(key_code + 96)
