@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   12/18/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the base class for the wxPython-based Traits UI modal and non-modal
     dialogs.
@@ -21,6 +14,9 @@
 
 import wx
 
+from pyface.action.schema.api import (
+    ActionManagerBuilder, MenuBarSchema, ToolBarSchema,
+)
 from traits.api import HasPrivateTraits, Instance
 
 from traitsui.base_panel import BasePanel as _BasePanel
@@ -30,8 +26,7 @@ from .helper import restore_window
 
 
 class ButtonEditor(Editor):
-    """ Editor for buttons.
-    """
+    """Editor for buttons."""
 
     # Action associated with the button
     action = Instance(Action)
@@ -41,15 +36,13 @@ class ButtonEditor(Editor):
         HasPrivateTraits.__init__(self, **traits)
 
     def perform(self, event):
-        """ Handles the associated button being clicked.
-        """
+        """Handles the associated button being clicked."""
         handler = self.ui.handler
         self.ui.do_undoable(handler.perform, self.ui.info, self.action, event)
 
 
 class BaseDialog(_BasePanel):
-    """ Base class for Traits UI dialog boxes.
-    """
+    """Base class for Traits UI dialog boxes."""
 
     # The different dialog styles.
     NONMODAL = 0
@@ -98,14 +91,13 @@ class BaseDialog(_BasePanel):
             ui.control.Show()
 
     def default_icon(self):
-        """ Return a default icon for a TraitsUI dialog. """
+        """Return a default icon for a TraitsUI dialog."""
         from pyface.image_resource import ImageResource
 
         return ImageResource("frame.ico")
 
     def set_icon(self, icon=None):
-        """ Sets the frame's icon.
-        """
+        """Sets the frame's icon."""
         from pyface.image_resource import ImageResource
 
         if not isinstance(icon, ImageResource):
@@ -113,8 +105,7 @@ class BaseDialog(_BasePanel):
         self.control.SetIcon(icon.create_icon())
 
     def add_statusbar(self):
-        """ Adds a status bar to the dialog.
-        """
+        """Adds a status bar to the dialog."""
         ui = self.ui
         statusbar = ui.view.statusbar
         context = ui.context
@@ -132,14 +123,14 @@ class BaseDialog(_BasePanel):
 
                 set_text = self._set_status_text(control, i)
                 name = item.name
-                set_text(ui.get_extended_value(name))
+                control.SetStatusText(ui.get_extended_value(name), i)
                 col = name.find(".")
                 object = "object"
                 if col >= 0:
                     object = name[:col]
                     name = name[col + 1 :]
                 object = context[object]
-                object.on_trait_change(set_text, name, dispatch="ui")
+                object.observe(set_text, name, dispatch="ui")
                 listeners.append((object, set_text, name))
 
             control.SetStatusWidths(widths)
@@ -147,15 +138,19 @@ class BaseDialog(_BasePanel):
             ui._statusbar = listeners
 
     def _set_status_text(self, control, i):
-        def set_status_text(text):
+        def set_status_text(event):
+            text = event.new
             control.SetStatusText(text, i)
 
         return set_status_text
 
     def add_menubar(self):
-        """ Adds a menu bar to the dialog.
-        """
+        """Adds a menu bar to the dialog."""
         menubar = self.ui.view.menubar
+        menubar = self.ui.view.menubar
+        if isinstance(menubar, MenuBarSchema):
+            builder = self.ui.view.action_manager_builder
+            menubar = builder.create_action_manager(menubar)
         if menubar is not None:
             self._last_group = self._last_parent = None
             self.control.SetMenuBar(
@@ -164,9 +159,11 @@ class BaseDialog(_BasePanel):
             self._last_group = self._last_parent = None
 
     def add_toolbar(self):
-        """ Adds a toolbar to the dialog.
-        """
+        """Adds a toolbar to the dialog."""
         toolbar = self.ui.view.toolbar
+        if isinstance(toolbar, ToolBarSchema):
+            builder = self.ui.view.action_manager_builder
+            toolbar = builder.create_action_manager(toolbar)
         if toolbar is not None:
             self._last_group = self._last_parent = None
             self.control.SetToolBar(
@@ -183,8 +180,7 @@ class BaseDialog(_BasePanel):
         name=None,
         default=False,
     ):
-        """ Creates a button.
-        """
+        """Creates a button."""
         ui = self.ui
         if (action.defined_when != "") and (
             not ui.eval_when(action.defined_when)
