@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   11/01/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Creates a wxPython user interface for a specified UI object.
 """
@@ -21,13 +14,15 @@
 
 import wx
 
+from pyface.api import SystemMetrics
+
 from .helper import save_window, TraitsUIScrolledPanel
 
 from .ui_base import BaseDialog
 
 from .ui_panel import panel
 
-from .constants import DefaultTitle, WindowColor, screen_dy, scrollbar_dx
+from .constants import DefaultTitle, WindowColor, scrollbar_dx
 
 from traitsui.menu import (
     ApplyButton,
@@ -39,19 +34,17 @@ from traitsui.menu import (
 
 
 def ui_modal(ui, parent):
-    """ Creates a modal wxPython user interface for a specified UI object.
-    """
+    """Creates a modal wxPython user interface for a specified UI object."""
     _ui_dialog(ui, parent, BaseDialog.MODAL)
 
 
 def ui_nonmodal(ui, parent):
-    """ Creates a non-modal wxPython user interface for a specified UI object.
-    """
+    """Creates a non-modal wxPython user interface for a specified UI object."""
     _ui_dialog(ui, parent, BaseDialog.NONMODAL)
 
 
 def _ui_dialog(ui, parent, style):
-    """ Creates a wxPython dialog box for a specified UI object.
+    """Creates a wxPython dialog box for a specified UI object.
 
     Changes are not immediately applied to the underlying object. The user must
     click **Apply** or **OK** to apply changes. The user can revert changes by
@@ -64,8 +57,7 @@ def _ui_dialog(ui, parent, style):
 
 
 class ModalDialog(BaseDialog):
-    """ Modal dialog box for Traits-based user interfaces.
-    """
+    """Modal dialog box for Traits-based user interfaces."""
 
     def init(self, ui, parent, style):
         self.is_modal = style == self.MODAL
@@ -126,7 +118,7 @@ class ModalDialog(BaseDialog):
             tsdx += 8
             tsdy += 8
             sw.SetScrollRate(16, 16)
-            max_dy = (2 * screen_dy) // 3
+            max_dy = (2 * SystemMetrics().screen_height) // 3
             sw.SetSizer(sizer)
             sw.SetSize(
                 wx.Size(
@@ -168,9 +160,7 @@ class ModalDialog(BaseDialog):
                     self.apply = self.add_button(
                         button, b_sizer, self._on_apply, apply, default=default
                     )
-                    ui.on_trait_change(
-                        self._on_applyable, "modified", dispatch="ui"
-                    )
+                    ui.observe(self._on_applyable, "modified", dispatch="ui")
 
                 elif self.is_button(button, "Revert"):
                     self.revert = self.add_button(
@@ -185,7 +175,7 @@ class ModalDialog(BaseDialog):
                     self.ok = self.add_button(
                         button, b_sizer, self._on_ok, default=default
                     )
-                    ui.on_trait_change(self._on_error, "errors", dispatch="ui")
+                    ui.observe(self._on_error, "errors", dispatch="ui")
 
                 elif self.is_button(button, "Cancel"):
                     self.add_button(
@@ -211,8 +201,7 @@ class ModalDialog(BaseDialog):
         window.SetSizerAndFit(sw_sizer)
 
     def close(self, rc=wx.ID_OK):
-        """ Closes the dialog window.
-        """
+        """Closes the dialog window."""
         ui = self.ui
         ui.result = rc == wx.ID_OK
         save_window(ui)
@@ -226,8 +215,7 @@ class ModalDialog(BaseDialog):
         self.ui = self.apply = self.revert = self.help = self.control = None
 
     def _copy_context(self, context):
-        """ Creates a copy of a *context* dictionary.
-        """
+        """Creates a copy of a *context* dictionary."""
         result = {}
         for name, value in context.items():
             if value is not None:
@@ -238,8 +226,7 @@ class ModalDialog(BaseDialog):
         return result
 
     def _apply_context(self, from_context, to_context):
-        """ Applies the traits in the *from_context* to the *to_context*.
-        """
+        """Applies the traits in the *from_context* to the *to_context*."""
         for name, value in from_context.items():
             if value is not None:
                 to_context[name].copy_traits(value)
@@ -252,36 +239,31 @@ class ModalDialog(BaseDialog):
                 on_apply()
 
     def _on_close_page(self, event):
-        """ Handles the user clicking the window/dialog "close" button/icon.
-        """
+        """Handles the user clicking the window/dialog "close" button/icon."""
         if self.ui.view.close_result:
             self._on_ok(event)
         else:
             self._on_cancel(event)
 
     def _on_ok(self, event=None):
-        """ Closes the window and saves changes (if allowed by the handler).
-        """
+        """Closes the window and saves changes (if allowed by the handler)."""
         if self.ui.handler.close(self.ui.info, True):
             self._apply_context(self.ui.context, self.ui._context)
             self.close(wx.ID_OK)
 
     def _on_cancel(self, event=None):
-        """ Closes the window and discards changes (if allowed by the handler).
-        """
+        """Closes the window and discards changes (if allowed by the handler)."""
         if self.ui.handler.close(self.ui.info, False):
             self._apply_context(self.ui._revert, self.ui._context)
             self.close(wx.ID_CANCEL)
 
     def _on_key(self, event):
-        """ Handles the user pressing the Escape key.
-        """
+        """Handles the user pressing the Escape key."""
         if event.GetKeyCode() == 0x1B:
             self._on_close_page(event)
 
     def _on_apply(self, event):
-        """ Handles a request to apply changes.
-        """
+        """Handles a request to apply changes."""
         ui = self.ui
         self._apply_context(ui.context, ui._context)
         if hasattr(self, "revert"):
@@ -290,8 +272,7 @@ class ModalDialog(BaseDialog):
         ui.modified = False
 
     def _on_revert(self, event):
-        """ Handles a request to revert changes.
-        """
+        """Handles a request to revert changes."""
         ui = self.ui
         self._apply_context(ui._revert, ui.context)
         self._apply_context(ui._revert, ui._context)
@@ -299,12 +280,12 @@ class ModalDialog(BaseDialog):
         ui.handler.revert(ui.info)
         ui.modified = False
 
-    def _on_applyable(self, state):
-        """ Handles a change to the "modified" state of the user interface .
-        """
+    def _on_applyable(self, event):
+        """Handles a change to the "modified" state of the user interface ."""
+        state = event.new
         self.apply.Enable(state)
 
-    def _on_error(self, errors):
-        """ Handles editing errors.
-        """
+    def _on_error(self, event):
+        """Handles editing errors."""
+        errors = event.new
         self.ok.Enable(errors == 0)
