@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   11/10/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Creates a wxPython specific modal dialog user interface that runs as a
     complete application, using information from the specified UI object.
@@ -43,8 +36,7 @@ KEEP_ALIVE_UIS = set()
 
 
 def on_ui_destroyed(object, name, old, destroyed):
-    """ Remove the UI object from KEEP_ALIVE_UIS.
-    """
+    """Remove the UI object from KEEP_ALIVE_UIS."""
     assert name == "destroyed"
     if destroyed:
         assert object in KEEP_ALIVE_UIS
@@ -58,7 +50,7 @@ def on_ui_destroyed(object, name, old, destroyed):
 
 
 def view_application(context, view, kind, handler, id, scrollable, args):
-    """ Creates a stand-alone wx Application to display a specified traits UI
+    """Creates a stand-alone wx Application to display a specified traits UI
         View.
 
     Parameters
@@ -115,12 +107,10 @@ def view_application(context, view, kind, handler, id, scrollable, args):
 
 
 class ViewApplication(wx.App):
-    """ Modal window that contains a stand-alone application.
-    """
+    """Modal window that contains a stand-alone application."""
 
     def __init__(self, context, view, kind, handler, id, scrollable, args):
-        """ Initializes the object.
-        """
+        """Initializes the object."""
         self.context = context
         self.view = view
         self.kind = kind
@@ -130,9 +120,9 @@ class ViewApplication(wx.App):
         self.args = args
 
         if redirect_filename.strip() != "":
-            super(ViewApplication, self).__init__(1, redirect_filename)
+            super().__init__(1, redirect_filename)
         else:
-            super(ViewApplication, self).__init__(0)
+            super().__init__(0)
 
         # Start the event loop in an IPython-conforming manner.
         try:
@@ -141,8 +131,7 @@ class ViewApplication(wx.App):
             logger.exception("Event loop failed to close cleanly:")
 
     def OnInit(self):
-        """ Handles application initialization.
-        """
+        """Handles application initialization."""
         self.ui = self.view.ui(
             self.context,
             kind=self.kind,
